SystemOrganization addCategory: #'Arduino-Model'!
SystemOrganization addCategory: #'Arduino-Firmata'!
SystemOrganization addCategory: #'Arduino-Model-Devices'!
SystemOrganization addCategory: #'Arduino-Model-PinMode'!
SystemOrganization addCategory: #'Arduino-Etoys'!
SystemOrganization addCategory: #'Arduino-Etoys-Wiring'!
SystemOrganization addCategory: #'Arduino-Etoys-Devices'!

CircleMorph subclass: #AttachmentPointMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Wiring'!

!AttachmentPointMorph commentStamp: 'Richo 9/15/2009 12:32' prior: 0!
I exist only for esthetical purposes. I make sure that wires connecting devices are attached to the correct points (not the center) of the morphs.!

!AttachmentPointMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/1/2009 16:07'!
disconnectedFromBy: aConnector

owner disconnectedFromBy: aConnector.! !

Object subclass: #Arduino
	instanceVariableNames: 'protocol digitalPins analogPins'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model'!

!Arduino commentStamp: 'Richo 9/15/2009 13:28' prior: 0!
I represent the Arduino board. I have a collection of pins and a protocol (i.e. Firmata). 
Below you will find a code example using the Firmata protocol:

---------------------------------------------------------------------------------------
| arduino digitalPin analogPin led button ldr servo |

"Connection"
arduino := Arduino on: Firmata new.
arduino connectOnPort: 5.
arduino isConnected.
arduino disconnect. "Don't forget to disconnect me after finish using me"

"Digital pins - output"
digitalPin := arduino digitalPin: 4.
digitalPin setOutput.
digitalPin value: 1.

"Digital pins - input"
arduino activateDigitalReports.
digitalPin setInput.
digitalPin value.

"Analog pins (analog pins are input only)"
analogPin := arduino analogPin: 0.
analogPin activate.
analogPin value.

"To avoid configuring pins, you can also attach/detach devices:"

"Led (digital output)"
led := LightEmittingDiode new.
led attach: (arduino digitalPin: 13).
led value: 1.
led value: 0.

"Button (digital input)"
button := EButton new.
button attach: (arduino digitalPin: 2).
button value.

"Ldr (analog input)"
ldr := Photoresistor new.
ldr attach: (arduino analogPin: 5).
ldr value.

"Servo (currently servos can only be attached to pins 9-10)"
servo := Servo new.
servo attach: (arduino digitalPin: 9).
servo angle: 0.
servo angle: 90.
servo angle: 180.

"To see the current list of available devices evaluate:"
AttachableDevice allSubclasses!

!Arduino class methodsFor: 'just for testing' stamp: 'Richo 8/26/2009 16:27'!
instancesConnected
^self allInstances select: [:each| each isConnected]! !

!Arduino class methodsFor: 'as yet unclassified' stamp: 'Richo 8/24/2009 16:13'!
new
self shouldNotImplement! !

!Arduino class methodsFor: 'as yet unclassified' stamp: 'Richo 8/18/2009 16:31'!
on: aProtocol
^(self basicNew setProtocol: aProtocol) initialize! !

!Arduino methodsFor: 'connection' stamp: 'Richo 9/11/2009 17:21'!
activateDigitalReports
protocol activateDigitalPort: 0; activateDigitalPort: 1.
! !

!Arduino methodsFor: 'connection' stamp: 'Richo 9/11/2009 17:24'!
activateReports
self activateDigitalReports.
analogPins do: [:each | each activate]! !

!Arduino methodsFor: 'accessing' stamp: 'Richo 8/31/2009 16:07'!
analogPin: aSmallInteger 
	^ analogPins at: aSmallInteger ifAbsent: [self inaccessiblePinError ]! !

!Arduino methodsFor: 'connection' stamp: 'Richo 9/21/2009 13:26'!
connectOnPort: portName 
	protocol connectOnPort: portName.
	self activateReports; reconfigurePins! !

!Arduino methodsFor: 'connection' stamp: 'Richo 9/11/2009 17:21'!
deactivateDigitalReports
protocol deactivateDigitalPort: 0;deactivateDigitalPort: 1.
! !

!Arduino methodsFor: 'accessing' stamp: 'Richo 8/31/2009 16:06'!
digitalPin: aSmallInteger 
	^ digitalPins at: aSmallInteger ifAbsent: [self inaccessiblePinError]! !

!Arduino methodsFor: 'connection' stamp: 'Richo 8/31/2009 15:15'!
disconnect
	protocol disconnect.! !

!Arduino methodsFor: 'errors' stamp: 'Richo 8/31/2009 16:06'!
inaccessiblePinError
self error: 'Inaccessible pin'! !

!Arduino methodsFor: 'initialize-release' stamp: 'Richo 8/31/2009 16:44'!
initialize
	digitalPins := Dictionary newFrom: ((2 to: 13)
				collect: [:i | i-> (ArduinoDigitalPin on: protocol number: i)]).
	analogPins :=Dictionary newFrom: ( (0 to: 5)
				collect: [:i | i -> (ArduinoAnalogPin on: protocol number: i)])! !

!Arduino methodsFor: 'connection' stamp: 'Richo 8/24/2009 16:14'!
isConnected
^protocol isConnected! !

!Arduino methodsFor: 'accessing' stamp: 'Richo 8/18/2009 16:31'!
protocol
^protocol! !

!Arduino methodsFor: 'connection' stamp: 'Richo 9/8/2009 10:33'!
reconfigurePins
	digitalPins values , analogPins values
		do: [:each | each refresh]! !

!Arduino methodsFor: 'private' stamp: 'Richo 8/18/2009 16:31'!
setProtocol: aProtocol
protocol := aProtocol ! !

Object subclass: #ArduinoPin
	instanceVariableNames: 'number protocol'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model'!

!ArduinoPin commentStamp: 'Richo 9/15/2009 11:49' prior: 0!
Abstract class. I represent an ArduinoPin!

ArduinoPin subclass: #ArduinoAnalogPin
	instanceVariableNames: 'isActive'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model'!

!ArduinoAnalogPin commentStamp: 'Richo 9/15/2009 11:52' prior: 0!
I represent an Arduino analog pin. Analog pins are always input. Before I can access my value, I must be activated by sending #activate.!

!ArduinoAnalogPin methodsFor: 'as yet unclassified' stamp: 'Richo 8/31/2009 15:22'!
activate
isActive := true.
self refresh! !

!ArduinoAnalogPin methodsFor: 'as yet unclassified' stamp: 'Richo 8/31/2009 15:23'!
deactivate
	isActive := false.
self refresh.! !

!ArduinoAnalogPin methodsFor: 'initializing' stamp: 'Richo 8/31/2009 15:23'!
initialize
isActive := false.! !

!ArduinoAnalogPin methodsFor: 'as yet unclassified' stamp: 'Richo 8/31/2009 15:24'!
isActive
^isActive! !

!ArduinoAnalogPin methodsFor: 'initializing' stamp: 'Richo 8/31/2009 16:46'!
refresh
	isActive
		ifTrue: [ protocol activateAnalogPin: number]
		ifFalse: [ protocol deactivateAnalogPin: number] ! !

!ArduinoAnalogPin methodsFor: 'as yet unclassified' stamp: 'Richo 8/31/2009 16:46'!
value
^ protocol analogRead: number! !

ArduinoPin subclass: #ArduinoDigitalPin
	instanceVariableNames: 'mode value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model'!

!ArduinoDigitalPin commentStamp: 'Richo 9/15/2009 11:55' prior: 0!
I represent an Arduino digital pin. Digital pins can be input or output. To change my mode you must send #mode: with a PinMode as a parameter or you can use #setInput/#setOutput.!

!ArduinoDigitalPin methodsFor: 'initialize-release' stamp: 'Richo 9/7/2009 16:20'!
initialize
mode := OutputMode new.
value := 0.! !

!ArduinoDigitalPin methodsFor: 'mode' stamp: 'Richo 8/19/2009 16:02'!
mode
^mode! !

!ArduinoDigitalPin methodsFor: 'mode' stamp: 'Richo 9/1/2009 16:25'!
mode: aSmallInteger 
	mode := aSmallInteger.
self refreshMode! !

!ArduinoDigitalPin methodsFor: 'initialize-release' stamp: 'Richo 8/31/2009 15:21'!
refresh
self refreshMode; refreshValue! !

!ArduinoDigitalPin methodsFor: 'mode' stamp: 'Richo 9/11/2009 13:35'!
refreshMode
	protocol digitalPin: number mode: mode firmataValue .
! !

!ArduinoDigitalPin methodsFor: 'value' stamp: 'Richo 8/31/2009 16:46'!
refreshValue
 protocol digitalWrite: number value: value! !

!ArduinoDigitalPin methodsFor: 'mode' stamp: 'Richo 9/7/2009 16:36'!
setInput

	self mode: InputMode new! !

!ArduinoDigitalPin methodsFor: 'mode' stamp: 'Richo 9/7/2009 16:20'!
setOutput
self mode: OutputMode new! !

!ArduinoDigitalPin methodsFor: 'value' stamp: 'Richo 9/9/2009 17:01'!
value
^mode isOutput ifTrue: [value] ifFalse: [value :=  protocol digitalRead: number]
! !

!ArduinoDigitalPin methodsFor: 'value' stamp: 'Richo 8/31/2009 15:19'!
value: aNumber 
	value := aNumber.
self refreshValue! !

!ArduinoPin class methodsFor: 'instance creation' stamp: 'Richo 8/18/2009 17:29'!
new
self shouldNotImplement! !

!ArduinoPin class methodsFor: 'instance creation' stamp: 'Richo 8/31/2009 16:44'!
on: aProtocol number: pinNumber 
	^ (self basicNew setProtocol: aProtocol number: pinNumber) initialize! !

!ArduinoPin methodsFor: 'accessing' stamp: 'Richo 8/24/2009 16:51'!
number
^number! !

!ArduinoPin methodsFor: 'printing' stamp: 'Richo 8/19/2009 14:18'!
printOn: aStream
super printOn: aStream.
aStream nextPutAll: '(', number asString, ')'! !

!ArduinoPin methodsFor: 'accessing' stamp: 'Richo 8/31/2009 16:45'!
protocol
^protocol! !

!ArduinoPin methodsFor: 'initializing' stamp: 'Richo 8/31/2009 15:21'!
refresh
self subclassResponsibility! !

!ArduinoPin methodsFor: 'private' stamp: 'Richo 8/31/2009 16:44'!
setProtocol: aProtocol number: aSmallInteger 
	protocol := aProtocol.
	number := aSmallInteger! !

Object subclass: #ArduinoProtocol
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model'!

!ArduinoProtocol commentStamp: 'Richo 9/15/2009 11:50' prior: 0!
Abstract class. I define the interface for a protocol to communicate with an Arduino board.!

!ArduinoProtocol methodsFor: 'analog pins' stamp: 'Richo 8/26/2009 16:51'!
activateAnalogPin: pinNumber
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'digital pins' stamp: 'Richo 9/11/2009 13:46'!
activateDigitalPort: portNumber
self subclassResponsibility
! !

!ArduinoProtocol methodsFor: 'analog pins' stamp: 'Richo 8/26/2009 16:09'!
analogRead: pinNumber
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'servos' stamp: 'Richo 8/26/2009 16:54'!
attachServoToPin: pinNumber
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'connection' stamp: 'Richo 8/26/2009 16:08'!
connectOnPort: port
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'analog pins' stamp: 'Richo 8/26/2009 16:51'!
deactivateAnalogPin: pinNumber
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'digital pins' stamp: 'Richo 9/11/2009 13:47'!
deactivateDigitalPort: portNumber
self subclassResponsibility
! !

!ArduinoProtocol methodsFor: 'servos' stamp: 'Richo 9/7/2009 16:25'!
detachServoFromPin: pinNumber
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'digital pins' stamp: 'Richo 8/26/2009 16:53'!
digitalPin: pinNumber mode: mode
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'digital pins' stamp: 'Richo 8/26/2009 16:51'!
digitalRead: pinNumber
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'digital pins' stamp: 'Richo 8/26/2009 17:06'!
digitalWrite: pinNumber value: value
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'connection' stamp: 'Richo 8/26/2009 16:08'!
disconnect
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'connection' stamp: 'Richo 8/26/2009 16:09'!
isConnected
self subclassResponsibility! !

!ArduinoProtocol methodsFor: 'servos' stamp: 'Richo 8/26/2009 16:54'!
servoOnPin: pinNumber angle: degrees
self subclassResponsibility! !

ArduinoProtocol subclass: #Firmata
	instanceVariableNames: 'port analogInputData digitalInputData digitalOutputData parsingSysex storedInputData sysexBytesRead waitForData executeMultiByteCommand multiByteChannel majorVersion minorVersion steppingProcess portName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Firmata'!

!Firmata commentStamp: 'Richo 9/15/2009 12:00' prior: 0!
I am an implementation of the Firmata protocol for talking to an Arduino board. 
For more information: http://www.firmata.org/

This implementation is mostly based on FirmataVB by Andrew Craigie.
http://www.acraigie.com/programming/firmatavb/default.html!

!Firmata class methodsFor: 'instance creation' stamp: 'Richo 8/18/2009 12:42'!
onPort: portNumber 
^self new connectOnPort: portNumber! !

!Firmata methodsFor: 'analog pins' stamp: 'Richo 8/26/2009 17:03'!
activateAnalogPin: pinNumber
self	analogPinReport: pinNumber onOff: 1! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 9/11/2009 13:46'!
activateDigitalPort: n
			self digitalPortReport: n onOff: 1
! !

!Firmata methodsFor: 'analog pins' stamp: 'Richo 8/26/2009 16:23'!
analogPinReport: pin onOff: onOff 
	"Sends a message to turn Analog Pin reportng on or off for a pin"
self port 
		nextPutAll: (ByteArray
				with: (FirmataConstants reportAnalog  bitOr: pin)
				with: onOff)! !

!Firmata methodsFor: 'analog pins' stamp: 'Richo 8/18/2009 12:35'!
analogRead: pinNumber
"Returns an analog value for an individual Analog pin"
^analogInputData at: pinNumber + 1! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 8/25/2009 14:47'!
analogWrite: pin value: value 
	"Sends a PWM value to a digital pin. 0 - 255"
	| analogWriteBuffer |
	analogWriteBuffer := ByteArray new: 3 withAll: 0.
	analogWriteBuffer
		at: 1
		put: (FirmataConstants analogMessage
				bitOr: (pin bitAnd: 15));
		
		at: 2
		put: (value rounded bitAnd: 127);
		
		at: 3
		put: ((value rounded bitShift: -7)
				bitAnd: 127).
self port  nextPutAll: analogWriteBuffer! !

!Firmata methodsFor: 'servos' stamp: 'Richo 9/1/2009 11:35'!
attachServoToPin: pinNumber 
	self
		servoConfig: pinNumber
		minPulse: 544
		maxPulse: 2400
		angle: 0! !

!Firmata methodsFor: 'connection' stamp: 'Richo 9/21/2009 18:10'!
connectOnPort: aString 
	"If the port cant't be open it stores nil, this way we can know if it is
	connected by asking if port is nil.
	In windows we can't open a port using the port name, so I convert the
	string to an integer"
	port := SerialPort new baudRate: FirmataConstants defaultBaudRate.
	port := port
				openPort: (('COM*' match: aString)
						ifTrue: [aString asInteger]
						ifFalse: [aString]).
	(Delay forSeconds: 2) wait.
	self isConnected
		ifTrue: [portName := aString.
			self queryVersion.
			self startSteppingProcess]! !

!Firmata methodsFor: 'error control' stamp: 'Richo 8/18/2009 12:40'!
controlConnection
self isConnected ifFalse: [^self error: 'Serial port is not connected'].! !

!Firmata methodsFor: 'analog pins' stamp: 'Richo 8/26/2009 17:03'!
deactivateAnalogPin: pinNumber 
	self analogPinReport: pinNumber onOff: 0! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 9/11/2009 13:46'!
deactivateDigitalPort: n
			self digitalPortReport: n onOff: 0
! !

!Firmata methodsFor: 'servos' stamp: 'Richo 9/7/2009 16:45'!
detachServoFromPin: pinNumber 
	self pin: pinNumber mode: FirmataConstants pinModeOutput ! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 9/11/2009 13:35'!
digitalPin: pinNumber mode: mode
self pin: pinNumber mode: mode! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 8/31/2009 16:22'!
digitalPortReport: port1 onOff: onOff
"Sends a message to toggle reporting for a whole digital port"
	self port 
		nextPutAll: (ByteArray
				with: (FirmataConstants reportDigital bitOr: port1 )
				with: onOff)! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 9/14/2009 15:32'!
digitalRead: pinNumber 
	"Retuns On/Off data for an individual Digital Pin"
	^ ((digitalInputData at: (pinNumber bitShift: -3)
			+ 1)
		bitShift: (pinNumber bitAnd: 7) * -1)
		bitAnd: 1! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 8/18/2009 12:42'!
digitalWrite: pin value: value 
	"Sends an On or Off message to an individual Digital Pin"
	| portNumber adjustment digitalWriteBuffer |
	portNumber := (pin bitShift: -3)
				bitAnd: 15.
	adjustment := 1
				bitShift: (pin bitAnd: 7).
	digitalWriteBuffer := ByteArray new: 3 withAll: 0.
	value = 0
		ifTrue: [digitalOutputData
				at: portNumber + 1
				put: ((digitalOutputData at: portNumber + 1)
						bitAnd: adjustment bitInvert)]
		ifFalse: [digitalOutputData
				at: portNumber + 1
				put: ((digitalOutputData at: portNumber + 1)
						bitOr: adjustment)].
	digitalWriteBuffer
		at: 1
		put: (FirmataConstants digitalMessage bitOr: portNumber);
		at: 2
		put: ((digitalOutputData at: portNumber + 1)
				bitAnd: 127);
		at: 3
		put: ((digitalOutputData at: portNumber + 1)
				bitShift: -7).
	self port  nextPutAll: digitalWriteBuffer! !

!Firmata methodsFor: 'connection' stamp: 'Richo 9/21/2009 13:27'!
disconnect
	self isConnected
		ifTrue: [self stopSteppingProcess.
			port close.
			port := nil.
			portName := nil.
			self initializeVariables]! !

!Firmata methodsFor: 'other commands' stamp: 'Richo 8/18/2009 12:41'!
endSysex
"Sends an End Sysex message"
self port  nextPutAll: (ByteArray with: FirmataConstants endSysex  ).! !

!Firmata methodsFor: 'initialize-release' stamp: 'Richo 9/8/2009 12:40'!
initialize
self initializeVariables! !

!Firmata methodsFor: 'initialize-release' stamp: 'Richo 9/8/2009 12:40'!
initializeVariables
	digitalOutputData := Array new: 16 withAll: 0.
	digitalInputData := Array new: 16 withAll: 0.
	analogInputData := Array new: 16 withAll: 0.
	storedInputData := Array new: FirmataConstants maxDataBytes + 1 withAll: 0.
	parsingSysex := false.
	sysexBytesRead := waitForData := executeMultiByteCommand := multiByteChannel := majorVersion := minorVersion := 0! !

!Firmata methodsFor: 'connection' stamp: 'Richo 8/18/2009 12:40'!
isConnected
^port notNil! !

!Firmata methodsFor: 'accessing' stamp: 'Richo 8/18/2009 13:22'!
majorVersion: version1 minorVersion: version2
majorVersion := version1.
minorVersion := version2! !

!Firmata methodsFor: 'receiving' stamp: 'Richo 9/14/2009 18:10'!
parseCommandHeader: inputByte 
	"Debe fijarse si se encuentra el header de un comando y setear las
	variables en consecuencia para luego procesar los datos"
	| command |
	inputByte < 240
		ifTrue: [command := inputByte bitAnd: 240.
			multiByteChannel := inputByte bitAnd: 15.]
		ifFalse: [command := inputByte].
	command caseOf: {
		[FirmataConstants analogMessage] -> 
			[waitForData := 2.
			executeMultiByteCommand := command].
		[FirmataConstants digitalMessage] -> 
			[waitForData := 2.
			executeMultiByteCommand := command].
		[FirmataConstants setPinMode] -> 
			[waitForData := 2.
			executeMultiByteCommand := command].
		[FirmataConstants reportDigital] -> 
			[waitForData := 1.
			executeMultiByteCommand := command].
		[FirmataConstants startSysex] -> 
			[parsingSysex := true.
			sysexBytesRead := 0].
		[FirmataConstants reportVersion] -> 
			[waitForData := 2.
			executeMultiByteCommand := command]}
		 otherwise: []! !

!Firmata methodsFor: 'receiving' stamp: 'Richo 9/8/2009 10:03'!
parseData: inputByte 
"Debe chequear que haya datos disponibles de algn command que se haya mandado y setear las variables correspondientes"
	waitForData := waitForData - 1.
	storedInputData at: waitForData + 1 put: inputByte.

	(waitForData = 0
			and: [executeMultiByteCommand ~= 0])
		ifTrue: [executeMultiByteCommand caseOf: {
				[FirmataConstants analogMessage] -> [self setAnalogInput: multiByteChannel value: (storedInputData first bitShift: 7)
						+ storedInputData second].
				[FirmataConstants digitalMessage] -> [
						self setDigitalInputs: multiByteChannel data: (storedInputData first bitShift: 7)
						+ storedInputData second].
				[FirmataConstants reportVersion] -> [self majorVersion: storedInputData first minorVersion: storedInputData second]}
				 otherwise: [].
			executeMultiByteCommand := 0]! !

!Firmata methodsFor: 'receiving' stamp: 'Richo 9/8/2009 10:31'!
parseSysex: inputByte 
	inputByte = FirmataConstants endSysex
		ifTrue: [parsingSysex := false]
		ifFalse: [storedInputData at: sysexBytesRead + 1 put: inputByte.
			sysexBytesRead := sysexBytesRead + 1
				]! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 8/26/2009 14:27'!
pin: pin mode: mode
"Sends an individual Pin Mode message"

self port nextPutAll: (ByteArray with: FirmataConstants setPinMode with: pin with: mode).! !

!Firmata methodsFor: 'accessing' stamp: 'Richo 8/18/2009 12:41'!
port
self controlConnection.
^port! !

!Firmata methodsFor: 'printing' stamp: 'Richo 8/24/2009 15:14'!
printOn: aStream
super printOn: aStream.
aStream nextPutAll: '(',self hash asString,')'! !

!Firmata methodsFor: 'receiving' stamp: 'Richo 9/14/2009 16:26'!
processInput
	| data |
	data := port readByteArray.

	data
		do: [:inputByte | 

parsingSysex
				ifTrue: [self parseSysex: inputByte]
				ifFalse: [(waitForData > 0
							and: [inputByte < 128])
						ifTrue: [self parseData: inputByte]
						ifFalse: [self parseCommandHeader: inputByte]]]! !

!Firmata methodsFor: 'other commands' stamp: 'Richo 8/18/2009 12:42'!
queryFirmware
"Send a Firmware Name and Version query"
self startSysex.
self port  nextPutAll: (ByteArray with: FirmataConstants reportFirmware ).! !

!Firmata methodsFor: 'other commands' stamp: 'Richo 8/18/2009 12:42'!
queryVersion
"Send a version report query"
self port  nextPutAll: (ByteArray with: FirmataConstants reportVersion ).! !

!Firmata methodsFor: 'connection' stamp: 'Richo 9/21/2009 13:27'!
resetConnection
	| tempPortName |
	self isConnected
		ifTrue: [tempPortName := portName.
			self disconnect.
			self connectOnPort: tempPortName.
]! !

!Firmata methodsFor: 'servos' stamp: 'Richo 8/26/2009 16:14'!
servoConfig: pin minPulse: minPulse maxPulse: maxPulse angle: angle
	"Default values: 
	minPulse 544 (LSB 32 MSB 4)
	maxPulse 2400 (LSB 96 MSB 18
	"
	| b |
	b := ByteArray new: 10.
	b at: 1 put: FirmataConstants startSysex;
		 at: 2 put: FirmataConstants servoConfig;
		 at: 3 put: pin;
		 at: 4 put:  (minPulse rounded bitAnd: 127);
		 at: 5 put: ((minPulse rounded bitShift: -7)
				bitAnd: 127);
		 at: 6 put: (maxPulse rounded bitAnd: 127);
		 at: 7 put: ((maxPulse rounded bitShift: -7)
				bitAnd: 127);
		 at: 8 put: (angle rounded bitAnd: 127);
		 at: 9 put: ((angle rounded bitShift: -7)
				bitAnd: 127);
		 at: 10 put: FirmataConstants endSysex.
	self port nextPutAll: b! !

!Firmata methodsFor: 'servos' stamp: 'Richo 8/26/2009 17:00'!
servoOnPin: pinNumber angle: degrees
self analogWrite: pinNumber value: degrees! !

!Firmata methodsFor: 'analog pins' stamp: 'Richo 8/18/2009 13:01'!
setAnalogInput: pin value: value
"Stores analog value data in array"
	analogInputData at: pin + 1 put: value! !

!Firmata methodsFor: 'digital pins' stamp: 'Richo 8/18/2009 13:01'!
setDigitalInputs: portNumber data: portData 
"Puts but masked On/Off data for a whole digital port into array"
	digitalInputData at: portNumber + 1 put: portData! !

!Firmata methodsFor: 'stepping' stamp: 'Richo 8/24/2009 15:14'!
startSteppingProcess
steppingProcess notNil ifTrue: [^self].
	steppingProcess := [[self step.
			(Delay forMilliseconds: self stepTime) wait] repeat]
				forkNamed: self asString! !

!Firmata methodsFor: 'other commands' stamp: 'Richo 8/18/2009 12:41'!
startSysex
"Sends a Start Sysex message"
self port  nextPutAll: (ByteArray with: FirmataConstants startSysex  ).! !

!Firmata methodsFor: 'stepping' stamp: 'Richo 9/9/2009 18:00'!
step
	[self processInput]
		on: Error
		do: [:err | 
			Transcript show: self asString , ': ' , err description;
				 cr. self initializeVariables.
			"self resetConnection"]! !

!Firmata methodsFor: 'stepping' stamp: 'Richo 8/31/2009 14:47'!
stepTime
	^ 1! !

!Firmata methodsFor: 'stepping' stamp: 'Richo 8/18/2009 15:23'!
stopSteppingProcess
	steppingProcess isNil
		ifTrue: [^ self].
	steppingProcess terminate. 
steppingProcess := nil.! !

Object subclass: #AttachableDevice
	instanceVariableNames: 'pin isConfigured'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-Devices'!

!AttachableDevice commentStamp: 'Richo 9/15/2009 12:06' prior: 0!
Abstract class. I represent a device that can be attached to an Arduino's pin. My protocol is very simple:

#attach: aPin
Attaches the device to the pin and sets the pin's configuration accordingly.

#isAttached
Checks if the device is attached to a pin.

#detach
Simply detachs the device from the pin and deletes the configuration. It raises an error if the device is not attached.

Subclasses should override #configure and #deleteConfiguration with the specific steps to configure the corresponding device.!

!AttachableDevice methodsFor: 'attaching' stamp: 'Richo 9/8/2009 12:44'!
attach: aPin 
	pin := aPin.
	[self configure.
	isConfigured := true]
		on: Error
		do: [isConfigured := false]! !

!AttachableDevice methodsFor: 'configuring' stamp: 'Richo 9/8/2009 12:46'!
configure
self subclassResponsibility! !

!AttachableDevice methodsFor: 'attaching' stamp: 'Richo 9/8/2009 12:52'!
controlAttaching
self isAttached
		ifFalse: [^ self unattachedError].! !

!AttachableDevice methodsFor: 'configuring' stamp: 'Richo 9/8/2009 12:46'!
deleteConfiguration
	self subclassResponsibility! !

!AttachableDevice methodsFor: 'attaching' stamp: 'Richo 9/9/2009 17:20'!
detach
	self controlAttaching.
	[self deleteConfiguration] on: Error do: ["The port may be disconnected"].
	pin := nil! !

!AttachableDevice methodsFor: 'attaching' stamp: 'Richo 9/7/2009 16:56'!
isAttached
^pin notNil! !

!AttachableDevice methodsFor: 'configuring' stamp: 'Richo 9/8/2009 12:48'!
reattachIfNecessary
"This method must be called every time we try to communicate with the device. This way we are sure that the device is properly configured"
	isConfigured
		ifFalse: [self attach: pin]! !

!AttachableDevice methodsFor: 'errors' stamp: 'Richo 9/7/2009 17:01'!
unattachedError
^self error: 'Unattached device: ', self asString.! !

AttachableDevice subclass: #EButton
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-Devices'!

!EButton commentStamp: 'Richo 9/15/2009 12:07' prior: 0!
I represent a button (digital input device).!

!EButton methodsFor: 'configuring' stamp: 'Richo 9/15/2009 11:55'!
configure
	pin mode: ButtonMode new! !

!EButton methodsFor: 'configuring' stamp: 'Richo 9/8/2009 12:59'!
deleteConfiguration
pin setOutput! !

!EButton methodsFor: 'accessing' stamp: 'Richo 9/8/2009 13:00'!
value
self controlAttaching ; reattachIfNecessary .
^pin value! !

AttachableDevice subclass: #LightEmittingDiode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-Devices'!

!LightEmittingDiode commentStamp: 'Richo 9/15/2009 12:08' prior: 0!
I represent a led (digital output device).!

!LightEmittingDiode methodsFor: 'configuring' stamp: 'Richo 9/15/2009 11:56'!
configure
	pin mode: LedMode new! !

!LightEmittingDiode methodsFor: 'configuring' stamp: 'Richo 9/8/2009 12:50'!
deleteConfiguration
	pin setOutput! !

!LightEmittingDiode methodsFor: 'accessing' stamp: 'Richo 9/8/2009 13:00'!
value
	self controlAttaching;  reattachIfNecessary.
	^ pin value! !

!LightEmittingDiode methodsFor: 'accessing' stamp: 'Richo 9/8/2009 13:00'!
value: aNumber 
	self controlAttaching;reattachIfNecessary.
	pin value: aNumber! !

AttachableDevice subclass: #Photoresistor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-Devices'!

!Photoresistor commentStamp: 'Richo 9/15/2009 12:08' prior: 0!
I represent an LDR (analog input device)!

!Photoresistor methodsFor: 'configuring' stamp: 'Richo 9/8/2009 16:48'!
configure
pin activate! !

!Photoresistor methodsFor: 'configuring' stamp: 'Richo 9/8/2009 16:48'!
deleteConfiguration

	pin deactivate! !

!Photoresistor methodsFor: 'accessing' stamp: 'Richo 9/8/2009 16:12'!
value
	self controlAttaching; reattachIfNecessary.
	^ pin value! !

AttachableDevice subclass: #Potentiometer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-Devices'!

!Potentiometer commentStamp: 'Richo 9/15/2009 12:09' prior: 0!
I represent a Potentiometer (analog input device).!

!Potentiometer methodsFor: 'configuring' stamp: 'Richo 9/14/2009 16:01'!
configure
pin activate! !

!Potentiometer methodsFor: 'configuring' stamp: 'Richo 9/14/2009 16:01'!
deleteConfiguration

	pin deactivate! !

!Potentiometer methodsFor: 'accessing' stamp: 'Richo 9/14/2009 16:01'!
value
	self controlAttaching; reattachIfNecessary.
	^ pin value! !

AttachableDevice subclass: #Servo
	instanceVariableNames: 'angle'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-Devices'!

!Servo commentStamp: 'Richo 9/15/2009 12:11' prior: 0!
I represent a servo motor.!

!Servo methodsFor: 'accessing' stamp: 'Richo 8/25/2009 14:57'!
angle
^angle! !

!Servo methodsFor: 'accessing' stamp: 'Richo 9/8/2009 13:00'!
angle: aSmallInteger 
	self controlAttaching; reattachIfNecessary.
	angle := aSmallInteger min: 180 max: 0.
	pin protocol servoOnPin: pin number angle: angle! !

!Servo methodsFor: 'configuring' stamp: 'Richo 9/8/2009 12:47'!
configure
pin protocol attachServoToPin: pin number.
	pin mode: ServoMode new.! !

!Servo methodsFor: 'configuring' stamp: 'Richo 9/8/2009 12:49'!
deleteConfiguration
	pin protocol detachServoFromPin: pin number.
	pin setOutput.! !

!Servo methodsFor: 'initialize-release' stamp: 'Richo 8/25/2009 14:57'!
initialize
super initialize.
angle := 0.! !

Object subclass: #FirmataConstants
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Firmata'!

!FirmataConstants commentStamp: 'Richo 9/15/2009 12:00' prior: 0!
See class side. I collect a bunch of constants for the Firmata protocol.!

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:35'!
analogMessage
"0xE0 send data for an analog pin (or PWM)"
^16rE0! !

!FirmataConstants class methodsFor: 'as yet unclassified' stamp: 'Richo 8/18/2009 10:49'!
defaultBaudRate
^57600! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:35'!
digitalMessage
"0x90 send data for digital pin"
^16r90! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:39'!
endSysex
"0xF7 end a MIDI Sysex message"
^16rF7! !

!FirmataConstants class methodsFor: 'version numbers' stamp: 'Richo 8/18/2009 10:33'!
firmataMajorVersion
"for non-compatible changes"
^2! !

!FirmataConstants class methodsFor: 'version numbers' stamp: 'Richo 8/18/2009 10:33'!
firmataMinorVersion
"for backward compatible changes"
^0! !

!FirmataConstants class methodsFor: 'extended command set using Sysex' stamp: 'Richo 8/18/2009 10:41'!
firmataString
"0x71 a string message with 14-bits per character"
^16r71! !

!FirmataConstants class methodsFor: 'as yet unclassified' stamp: 'Richo 8/18/2009 10:34'!
maxDataBytes
"Maximum number of data bytes in non-Sysex messages"
^32 ! !

!FirmataConstants class methodsFor: 'pin modes' stamp: 'Richo 9/7/2009 16:16'!
pinModeAnalog
"analog pin in analogInput mode"
^2! !

!FirmataConstants class methodsFor: 'pin modes' stamp: 'Richo 9/7/2009 16:16'!
pinModeInput
^0! !

!FirmataConstants class methodsFor: 'pin modes' stamp: 'Richo 9/7/2009 16:16'!
pinModeOutput
^1! !

!FirmataConstants class methodsFor: 'pin modes' stamp: 'Richo 9/7/2009 16:17'!
pinModePwm
"digital pin in PWM output mode"
^3! !

!FirmataConstants class methodsFor: 'pin modes' stamp: 'Richo 9/7/2009 16:17'!
pinModeServo 
"digital pin in Servo output mode"
^4! !

!FirmataConstants class methodsFor: 'pin modes' stamp: 'Richo 9/11/2009 14:37'!
pinModeUnavailable
	^ -1! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:36'!
reportAnalog
"0xC0 enable analog input by pin number"
^16rC0! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:36'!
reportDigital
"0xD0 enable digital input by port pair"
^16rD0! !

!FirmataConstants class methodsFor: 'extended command set using Sysex' stamp: 'Richo 8/18/2009 10:41'!
reportFirmware
"0x79 report name and version of the firmware"
^16r79! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:38'!
reportVersion
"0xF9 report protocol version"
^16rF9! !

!FirmataConstants class methodsFor: 'extended command set using Sysex' stamp: 'Richo 8/18/2009 10:40'!
servoConfig
"0x70 set maximum angle, minPulse, maxPulse, frequency"
^16r70! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:37'!
setPinMode
"0xF4 set a pin to INPUT/OUTPUT/ANALOG/PWM/SERVO - 0/1/2/3/4"
^16rF4! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:38'!
startSysex
"0xF0 start a MIDI Sysex message"
^16rF0! !

!FirmataConstants class methodsFor: 'extended command set using Sysex' stamp: 'Richo 8/18/2009 10:41'!
sysexNonRealtime
"0x7E MIDI reserved for non-realtime messages"
^16r7E! !

!FirmataConstants class methodsFor: 'extended command set using Sysex' stamp: 'Richo 8/18/2009 10:42'!
sysexRealtime
"0x7F MIDI reserved for realtime messages"
^16r7F! !

!FirmataConstants class methodsFor: 'message commands' stamp: 'Richo 8/18/2009 10:38'!
systemReset
"0xFF reset from MIDI"
^16rFF! !

!FirmataConstants class methodsFor: 'version numbers' stamp: 'Richo 8/18/2009 10:33'!
versionBlickPin
"digital pin to blick version on"
^13! !

Object subclass: #PinMode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-PinMode'!

PinMode class
	instanceVariableNames: 'uniqueInstance'!

!PinMode commentStamp: 'Richo 9/15/2009 12:15' prior: 0!
Abstract class. I represent the mode of an Arduino digital pin. Tipically, I would just need input/output mode, other subclasses were made for practical purposes (i.e. ButtonMode, LedMode).!

PinMode class
	instanceVariableNames: 'uniqueInstance'!

PinMode subclass: #InputMode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-PinMode'!

!InputMode commentStamp: 'Richo 9/15/2009 12:13' prior: 0!
I represent the input mode of an Arduino digital pin.!

InputMode subclass: #ButtonMode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-PinMode'!

!ButtonMode commentStamp: 'Richo 9/15/2009 12:13' prior: 0!
I represent the button mode of an Arduino digital pin.!

!ButtonMode methodsFor: 'accessing' stamp: 'Richo 9/8/2009 12:58'!
nameSymbol
^#button! !

!InputMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:18'!
firmataValue
^FirmataConstants pinModeInput ! !

!InputMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:35'!
nameSymbol
	^#input! !

PinMode subclass: #OutputMode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-PinMode'!

!OutputMode commentStamp: 'Richo 9/15/2009 12:13' prior: 0!
I represent the output mode of an Arduino digital pin.!

OutputMode subclass: #LedMode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-PinMode'!

!LedMode commentStamp: 'Richo 9/15/2009 12:14' prior: 0!
I represent the led mode of an Arduino digital pin.!

!LedMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:35'!
nameSymbol
	^#led! !

!OutputMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:19'!
firmataValue
^FirmataConstants pinModeOutput ! !

!OutputMode methodsFor: 'testing' stamp: 'Richo 9/7/2009 16:29'!
isOutput
^true! !

!OutputMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:34'!
nameSymbol
	^#output! !

!PinMode class methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2009 16:23'!
new
^uniqueInstance ifNil: [uniqueInstance := self basicNew]! !

!PinMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:19'!
firmataValue
^self subclassResponsibility! !

!PinMode methodsFor: 'testing' stamp: 'Richo 9/7/2009 16:29'!
isOutput
^false! !

!PinMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:33'!
nameSymbol
^#undefined! !

PinMode subclass: #ServoMode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Model-PinMode'!

!ServoMode commentStamp: 'Richo 9/15/2009 12:13' prior: 0!
I represent the servo mode of an Arduino digital pin.!

!ServoMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:19'!
firmataValue
^FirmataConstants pinModeServo ! !

!ServoMode methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:35'!
nameSymbol
	^#servo! !

PhysicalEtoysWireMorph subclass: #ArduinoWireMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Wiring'!

!ArduinoWireMorph commentStamp: 'Richo 9/15/2009 12:29' prior: 0!
I am the Etoys that represents the Arduino wire which connects devices to pins.!

!ArduinoWireMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/15/2009 12:24'!
validConnectionClasses
	"Devuelve una coleccin de clases vlidas para conectarse"
	^ {AttachmentPointMorph. ArduinoPinMorph. AttachableDeviceMorph}! !

!ArduinoWireMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/1/2009 15:46'!
enterHandlingDrop
"Pequeo cambio con respecto a la superclase para evitar que considere que shift est siempre apretado y poder conectar a los pines (que son submorphs)"
	| potentialConnections nextConnection potentialTargets firstTarget |
	self log: #debug items: { 'enterHandlingDrop' }.
	
	"Find which ends we should potentially try to connect"
	potentialConnections := constraints select: [:ea | ea input isNil].
	potentialTargets := potentialConnections collect: [ :constraint |
		| localPoint targets |
		localPoint := self griddedPoint: constraint targetPoint.
		targets := self connectionTargetsAt: localPoint for: constraint.

		targets notEmpty 
			ifTrue: [ { ("Sensor shiftPressed " true
						ifFalse: [targets first ]
						ifTrue: [ targets last]). localPoint } ]
				ifFalse: [ { nil. nil } ]].

	self isWiring ifTrue: [
		potentialConnections size = 2 ifTrue: [
			firstTarget := potentialTargets findFirst: [ :arr | arr first notNil ].
			firstTarget = 0 ifTrue: [ firstTarget := 1 ].
			nextConnection := potentialConnections atWrap: firstTarget + 1.
			potentialConnections := potentialConnections copyFrom: firstTarget to: firstTarget.
			potentialTargets := potentialTargets copyFrom: firstTarget to: firstTarget
		]].

	potentialConnections with: potentialTargets do: 
			[:constraint :targetAndPoint | 
			| localPoint target |
			target := targetAndPoint first.
			localPoint := targetAndPoint second.
			target isNil
				ifFalse: [ constraint attachTo: target at: localPoint ]
				ifTrue: [ constraint connectToNothing; forceRedraw]].
	self
		changed;
		layoutChanged.

	(self isWiring and: [nextConnection notNil]) 
		ifTrue: 
			[| evt pos |
			evt := ActiveHand lastEvent.
			pos := self griddedPoint: (self globalPointToLocal: evt position).
			potentialConnections first lastTargetPoint: pos.
			nextConnection center: pos.
			self setProperty: #triggeredWireFinish toValue: pos.
			self trigger: #wireFinish
				withArguments: { 
						nextConnection.
						evt}].
! !

!ArduinoWireMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/1/2009 15:47'!
monitorDestinationForEnds
"Pequeo cambio con respecto a la superclase para evitar que considere que shift est siempre apretado y poder conectar a los pines (que son submorphs)"
	| targets cTargets |
	targets := IdentitySet new.
	constraints
		do: [:aConstraint | 
			| constraintInput | 
			constraintInput := aConstraint input.
			(constraintInput isNil
					or: [constraintInput isHandMorph])
				ifTrue: [cTargets := self
								connectionTargetsAt: (self visible
										ifTrue: [aConstraint center]
										ifFalse: [ActiveHand position])
								for: aConstraint.
					cTargets isEmpty
						ifFalse: [targets
								add: ("ActiveHand lastEvent shiftPressed"true
										ifTrue: [cTargets last]
										ifFalse: [cTargets first])]]].
	self
		newCursor: (targets isEmpty
				ifTrue: [Cursor crossHair]
				ifFalse: [Cursor webLink]).
	self
		valueOfProperty: #highlightedTargets
		ifPresentDo: [:ht | (ht difference: targets)
				do: [:ea | ea highlightForConnection: false]].
	targets
		do: [:ea | ea highlightedForConnection
				ifFalse: [ea highlightForConnection: true]].
	self setProperty: #highlightedTargets toValue: targets.
	^ targets isEmpty not! !

!ArduinoWireMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2009 15:59'!
step
super step.

isControllingConnections ifTrue: [self controlConnections].! !

!ArduinoWireMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2009 15:55'!
stepTime
^50! !

!ArduinoWireMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 17:15'!
wantsToAttachEnd: index toMorph: aMorph 
	(super wantsToAttachEnd: index toMorph: aMorph)
		ifFalse: [^ false].
	^ aMorph canBeAttachedTo: self sourceMorph owner! !

Player subclass: #ArduinoPlayer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys'!

!ArduinoPlayer methodsFor: 'commands' stamp: 'Richo 9/18/2009 16:56'!
connect
^ self costume renderedMorph connect! !

!ArduinoPlayer methodsFor: 'commands' stamp: 'Richo 8/19/2009 13:36'!
disconnect
^ self costume renderedMorph disconnect! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 13:36'!
getAnalogPin0
^ self costume renderedMorph analogPin0! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 13:36'!
getAnalogPin1
^ self costume renderedMorph analogPin1! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 13:36'!
getAnalogPin2
^ self costume renderedMorph analogPin2! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 13:36'!
getAnalogPin3
^ self costume renderedMorph analogPin3! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 13:36'!
getAnalogPin4
^ self costume renderedMorph analogPin4! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 13:54'!
getAnalogPin5
	^ self costume renderedMorph analogPin5! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin10
^ self costume renderedMorph digitalPin10! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
getDigitalPin10Mode
^ self costume renderedMorph digitalPin10Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin11
^ self costume renderedMorph digitalPin11! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
getDigitalPin11Mode
^ self costume renderedMorph digitalPin11Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin12
^ self costume renderedMorph digitalPin12! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
getDigitalPin12Mode
^ self costume renderedMorph digitalPin12Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin13
^ self costume renderedMorph digitalPin13! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
getDigitalPin13Mode
^ self costume renderedMorph digitalPin13Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:00'!
getDigitalPin14
^ self costume renderedMorph getDigitalPin14! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin2
^ self costume renderedMorph digitalPin2! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin2Mode
^ self costume renderedMorph digitalPin2Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin3
^ self costume renderedMorph digitalPin3! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin3Mode
^ self costume renderedMorph digitalPin3Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin4
^ self costume renderedMorph digitalPin4! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin4Mode
^ self costume renderedMorph digitalPin4Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin5
^ self costume renderedMorph digitalPin5! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin5Mode
^ self costume renderedMorph digitalPin5Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin6
^ self costume renderedMorph digitalPin6! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin6Mode
^ self costume renderedMorph digitalPin6Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin7
^ self costume renderedMorph digitalPin7! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin7Mode
^ self costume renderedMorph digitalPin7Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin8
^ self costume renderedMorph digitalPin8! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin8Mode
^ self costume renderedMorph digitalPin8Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 14:03'!
getDigitalPin9
^ self costume renderedMorph digitalPin9! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:20'!
getDigitalPin9Mode
^ self costume renderedMorph digitalPin9Mode! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:52'!
getIsAnalogPin0Active
^ self costume renderedMorph isAnalogPin0Active! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:53'!
getIsAnalogPin1Active
^ self costume renderedMorph isAnalogPin1Active! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:53'!
getIsAnalogPin2Active
^ self costume renderedMorph isAnalogPin2Active! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:53'!
getIsAnalogPin3Active
^ self costume renderedMorph isAnalogPin3Active! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:53'!
getIsAnalogPin4Active
^ self costume renderedMorph isAnalogPin4Active! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:53'!
getIsAnalogPin5Active
^ self costume renderedMorph isAnalogPin5Active! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 13:36'!
getIsConnected
^ self costume renderedMorph isConnected! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/11/2009 17:18'!
getIsReadingDigitalPins
^self costume renderedMorph isReadingDigitalPins! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/18/2009 16:56'!
getPortName
 ^ self costume renderedMorph portName! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:28'!
setDigitalPin10:aBoolean
^ self costume renderedMorph digitalPin10:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:22'!
setDigitalPin10Mode: aSymbol
^ self costume renderedMorph digitalPin10Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:28'!
setDigitalPin11:aBoolean
^ self costume renderedMorph digitalPin11:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:22'!
setDigitalPin11Mode: aSymbol
^ self costume renderedMorph digitalPin11Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:28'!
setDigitalPin12:aBoolean
^ self costume renderedMorph digitalPin12:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:22'!
setDigitalPin12Mode: aSymbol
^ self costume renderedMorph digitalPin12Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:28'!
setDigitalPin13:aBoolean
^ self costume renderedMorph digitalPin13:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:22'!
setDigitalPin13Mode: aSymbol
^ self costume renderedMorph digitalPin13Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin2:aBoolean
^ self costume renderedMorph digitalPin2:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
setDigitalPin2Mode: aSymbol
^ self costume renderedMorph digitalPin2Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin3:aBoolean
^ self costume renderedMorph digitalPin3:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
setDigitalPin3Mode: aSymbol
^ self costume renderedMorph digitalPin3Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin4:aBoolean
^ self costume renderedMorph digitalPin4:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
setDigitalPin4Mode: aSymbol
^ self costume renderedMorph digitalPin4Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin5:aBoolean
^ self costume renderedMorph digitalPin5:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
setDigitalPin5Mode: aSymbol
^ self costume renderedMorph digitalPin5Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin6:aBoolean
^ self costume renderedMorph digitalPin6:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
setDigitalPin6Mode: aSymbol
^ self costume renderedMorph digitalPin6Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin7:aBoolean
^ self costume renderedMorph digitalPin7:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
setDigitalPin7Mode: aSymbol
^ self costume renderedMorph digitalPin7Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin8:aBoolean
^ self costume renderedMorph digitalPin8:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:21'!
setDigitalPin8Mode: aSymbol
^ self costume renderedMorph digitalPin8Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:29'!
setDigitalPin9:aBoolean
^ self costume renderedMorph digitalPin9:aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 8/19/2009 16:22'!
setDigitalPin9Mode: aSymbol
^ self costume renderedMorph digitalPin9Mode: aSymbol! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:53'!
setIsAnalogPin0Active: aBoolean
^ self costume renderedMorph isAnalogPin0Active: aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:54'!
setIsAnalogPin1Active: aBoolean
^ self costume renderedMorph isAnalogPin1Active: aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:54'!
setIsAnalogPin2Active: aBoolean
^ self costume renderedMorph isAnalogPin2Active: aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:54'!
setIsAnalogPin3Active: aBoolean
^ self costume renderedMorph isAnalogPin3Active: aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:54'!
setIsAnalogPin4Active: aBoolean
^ self costume renderedMorph isAnalogPin4Active: aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/8/2009 16:54'!
setIsAnalogPin5Active: aBoolean
^ self costume renderedMorph isAnalogPin5Active: aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/11/2009 17:18'!
setIsReadingDigitalPins: aBoolean
^self costume renderedMorph isReadingDigitalPins: aBoolean! !

!ArduinoPlayer methodsFor: 'slots' stamp: 'Richo 9/21/2009 12:50'!
setPortName: aSymbol 
	^ self costume renderedMorph
		portName: aSymbol! !

Player subclass: #AttachableDevicePlayer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:01'!
getDegrees
^ self costume renderedMorph angle! !

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:47'!
getIsOn
^self costume renderedMorph value ! !

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:47'!
getIsPressed
^self costume renderedMorph value ! !

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 16:20'!
getLightValue
	^ self costume renderedMorph value! !

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/21/2009 13:07'!
getPotentiometerValue
	^ self costume renderedMorph value! !

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:01'!
getValue
^self costume renderedMorph value! !

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:01'!
setDegrees: aNumber
^ self costume renderedMorph angle: aNumber! !

!AttachableDevicePlayer methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:01'!
setValue: aBoolean
^self costume renderedMorph value: aBoolean! !

Morph subclass: #ArduinoMorph
	instanceVariableNames: 'arduino isReadingDigitalPins portName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys'!

ArduinoMorph class
	instanceVariableNames: 'form'!

!ArduinoMorph commentStamp: 'Richo 9/15/2009 12:23' prior: 0!
I am the Etoy that represents the Arduino board.!

ArduinoMorph class
	instanceVariableNames: 'form'!

!ArduinoMorph class methodsFor: 'viewer categories' stamp: 'Richo 9/21/2009 13:29'!
additionsToViewerCategories
^ #(
(#'arduino - connection' (
#(command connect '' )
#(command disconnect '' )
#(slot isConnected '' Boolean readOnly Player getIsConnected Player unused )
#(slot portName '' ArduinoPort readWrite Player getPortName Player setPortName: )
))

(#'arduino - digital pins mode' (
#(slot #'is reading digital pins' '' Boolean readWrite Player getIsReadingDigitalPins Player setIsReadingDigitalPins:  )

#(slot #'digitalPin 2Mode' '' ArduinoPinMode readWrite Player getDigitalPin2Mode Player setDigitalPin2Mode:  )
#(slot #'digitalPin 3Mode' '' ArduinoPinMode readWrite Player getDigitalPin3Mode Player setDigitalPin3Mode:  )
#(slot #'digitalPin 4Mode' '' ArduinoPinMode readWrite Player getDigitalPin4Mode Player setDigitalPin4Mode:  )
#(slot #'digitalPin 5Mode' '' ArduinoPinMode readWrite Player getDigitalPin5Mode Player setDigitalPin5Mode:  )
#(slot #'digitalPin 6Mode' '' ArduinoPinMode readWrite Player getDigitalPin6Mode Player setDigitalPin6Mode:  )
#(slot #'digitalPin 7Mode' '' ArduinoPinMode readWrite Player getDigitalPin7Mode Player setDigitalPin7Mode:  )
#(slot #'digitalPin 8Mode' '' ArduinoPinMode readWrite Player getDigitalPin8Mode Player setDigitalPin8Mode:  )
#(slot #'digitalPin 9Mode' '' ArduinoPinMode readWrite Player getDigitalPin9Mode Player setDigitalPin9Mode:  )
#(slot #'digitalPin 10Mode' '' ArduinoPinMode readWrite Player getDigitalPin10Mode Player setDigitalPin10Mode:  )
#(slot #'digitalPin 11Mode' '' ArduinoPinMode readWrite Player getDigitalPin11Mode Player setDigitalPin11Mode:  )
#(slot #'digitalPin 12Mode' '' ArduinoPinMode readWrite Player getDigitalPin12Mode Player setDigitalPin12Mode:  )
#(slot #'digitalPin 13Mode' '' ArduinoPinMode readWrite Player getDigitalPin13Mode Player setDigitalPin13Mode:  )
))

(#'arduino - digital pins' (
#(slot #'digitalPin 10' '' Boolean readWrite Player getDigitalPin10 Player setDigitalPin10: )
#(slot #'digitalPin 11' '' Boolean readWrite Player getDigitalPin11 Player setDigitalPin11: )
#(slot #'digitalPin 12' '' Boolean readWrite Player getDigitalPin12 Player setDigitalPin12: )
#(slot #'digitalPin 13' '' Boolean readWrite Player getDigitalPin13 Player setDigitalPin13: )
#(slot #'digitalPin 2' '' Boolean readWrite Player getDigitalPin2 Player setDigitalPin2: )
#(slot #'digitalPin 3' '' Boolean readWrite Player getDigitalPin3 Player setDigitalPin3: )
#(slot #'digitalPin 4' '' Boolean readWrite Player getDigitalPin4 Player setDigitalPin4: )
#(slot #'digitalPin 5' '' Boolean readWrite Player getDigitalPin5 Player setDigitalPin5: )
#(slot #'digitalPin 6' '' Boolean readWrite Player getDigitalPin6 Player setDigitalPin6: )
#(slot #'digitalPin 7' '' Boolean readWrite Player getDigitalPin7 Player setDigitalPin7: )
#(slot #'digitalPin 8' '' Boolean readWrite Player getDigitalPin8 Player setDigitalPin8: )
#(slot #'digitalPin 9' '' Boolean readWrite Player getDigitalPin9 Player setDigitalPin9: )
))

(#'arduino - analog pins' (
#(slot #'isAnalogPin 0Active' '' Boolean readWrite Player getIsAnalogPin0Active Player setIsAnalogPin0Active: )
#(slot #'isAnalogPin 1Active' '' Boolean readWrite Player getIsAnalogPin1Active Player setIsAnalogPin1Active: )
#(slot #'isAnalogPin 2Active' '' Boolean readWrite Player getIsAnalogPin2Active Player setIsAnalogPin2Active: )
#(slot #'isAnalogPin 3Active' '' Boolean readWrite Player getIsAnalogPin3Active Player setIsAnalogPin3Active: )
#(slot #'isAnalogPin 4Active' '' Boolean readWrite Player getIsAnalogPin4Active Player setIsAnalogPin4Active: )
#(slot #'isAnalogPin 5Active' '' Boolean readWrite Player getIsAnalogPin5Active Player setIsAnalogPin5Active: )

#(slot #'analogPin 0' '' Number readOnly Player getAnalogPin0 Player unused )
#(slot #'analogPin 1' '' Number readOnly Player getAnalogPin1 Player unused )
#(slot #'analogPin 2' '' Number readOnly Player getAnalogPin2 Player unused )
#(slot #'analogPin 3' '' Number readOnly Player getAnalogPin3 Player unused )
#(slot #'analogPin 4' '' Number readOnly Player getAnalogPin4 Player unused )
#(slot #'analogPin 5' '' Number readOnly Player getAnalogPin5 Player unused )
))

)! !

!ArduinoMorph class methodsFor: 'parts bin' stamp: 'Richo 8/24/2009 17:34'!
descriptionForPartsBin
	"Answer a description for use in parts bins"
	^ self
		partName: 'Arduino board'
		categories: #('Electronics' )
		documentation: ''! !

!ArduinoMorph class methodsFor: 'form' stamp: 'Richo 8/18/2009 16:12'!
form
^form ifNil: [self initializeForm]! !

!ArduinoMorph class methodsFor: 'initialize' stamp: 'Richo 9/21/2009 13:27'!
initialize

	super initialize.
	Vocabulary addStandardVocabulary: (SymbolListType new vocabularyName: #ArduinoPinMode;
			 symbols: #(#input #output ))! !

!ArduinoMorph class methodsFor: 'form' stamp: 'Richo 8/18/2009 16:12'!
initializeForm
^(Form
	extent: 387@270
	depth: 32
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278615194 4278484636 4278615194 4278680473 4278484636 4278549915 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281617492 4281226078 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278680473 4278615194 4279072147 4279202705 4279202705 4279202705 4279202705 4279137426 4278745752 4278549915 4279072147 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278484636 4279072147 4279202705 4279202705 4279202705 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278549915 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279072147 4278549915 4279202705 4279202705 4279202705 4279202705 4279202706 4278941332 4278941589 4279137426 4279202705 4279202705 4279202705 4279202705 4278811031 4278811031 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4278811031 4278876310 4279202705 4279202705 4279202705 4279072147 4278550172 4278354078 4278354078 4278419357 4278941589 4279202705 4279202705 4279202705 4279137426 4278549915 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4278615194 4279072147 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278419358 4279137682 4279202705 4279202705 4279202705 4278484636 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4278484636 4279202705 4279202705 4279202705 4279202705 4278354077 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4278615194 4279072147 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4278549915 4279137426 4279202705 4279202705 4279202705 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278941332 4279202705 4279202705 4279202705 4278615194 4279137426 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279703319 4282861383 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4278680473 4279006868 4279202705 4279202705 4279202705 4278745751 4278354078 4278354078 4278354078 4278354078 4278549916 4279202961 4279202705 4279202705 4279202705 4278484636 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4278876310 4278811031 4279202705 4279202705 4279202705 4279202961 4278745496 4278419101 4278419358 4278615194 4279072147 4279202705 4279202705 4279202705 4279072147 4278615194 4279202705 4279202705 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279137426 4278484636 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4279006868 4279202705 4279202705 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278680473 4279202705 4279202705 4279202705 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281878604 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278549915 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278549915 4279137426 4279202705 4279202705 4279202705 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4280116602 4279920510 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278484636 4278811031 4279006868 4279137426 4279202705 4279006868 4278876310 4278549915 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278876310 4278680473 4278549915 4278484636 4278680473 4278811031 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286887878 4281830308 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280122263 4286887878 4292471278 4292208364 4286099649 4279728277 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4282289831 4287479243 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282815402 4293193714 4287873229 4280976286 4281436065 4288661459 4292799728 4281764515 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4283669424 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288989909 4287873229 4282684073 4282684073 4282684073 4282684073 4288792788 4287413450 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4291157476 4291551719 4291551719 4290303711 4280516506 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728277 4290763490 4291551719 4291551719 4290500576 4280976286 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4290303711 4291551719 4287282122 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288070351 4291551719 4291551719 4291091684 4282552744 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289384152 4291551719 4291551719 4291551719 4285114554 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289384152 4291551719 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286034113 4291551719 4291551719 4291551719 4290369247 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285377212 4286428099 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286493892 4291551719 4291551719 4290040796 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287282122 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281041822 4291420390 4291551719 4291551719 4290106589 4279925398 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4291157476 4291551719 4291551719 4290237918 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279596692 4290566368 4291551719 4286953671 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288201680 4291551719 4291551719 4291026147 4282421415 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4286822342 4286822342 4290763490 4283669424 4283669424 4283669424 4280384921 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4291683048 4290566368 4290566368 4290566368 4290566368 4292077035 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281304736 4281698722 4281698722 4289581017 4284523190 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281107614 4281698722 4281698722 4288727251 4285311420 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280976286 4285377212 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4293719286 4281698722 4281698722 4286690757 4288004558 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294113273 4281698722 4281698722 4285377212 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294113273 4283734960 4291551719 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283866289 4282027173 4281698722 4282027173 4293522165 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4284326325 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4286231234 4281698722 4280910493 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294047737 4279202705 4281370272 4288267472 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281567393 4281698722 4281698722 4290369247 4283012524 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281304736 4281698722 4281698722 4289186774 4284326325 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281041822 4285836991 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280056727 4293325043 4281698722 4281698722 4287085000 4287479243 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286033856 4289581017 4289581017 4289581017 4289581017 4289581017 4289581017 4283340974 4279202705 4279202705 4279202705 4279202705 4279202705 4283340974 4279990935 4279202705 4279202705 4279202705 4279202705 4280910493 4282946731 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4284588983 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287610572 4285574333 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4293522165 4279202705 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294244602 4285639870 4285639870 4288201680 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294047737 4281698722 4291551719 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280779164 4293456629 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284654519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294047737 4279202705 4282684073 4290566368 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4283078316 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288135887 4284588983 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280779164 4288989909 4289121238 4294507516 4281107614 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286756550 4289121238 4289121238 4292274156 4283932082 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4293522165 4279202705 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285574333 4287610572 4287610572 4289646810 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284720311 4294573308 4290040796 4293522165 4282946731 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279990935 4290632161 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4291157476 4289121238 4285902528 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294047737 4279202705 4282684073 4290566368 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281567393 4289055446 4289187031 4294441980 4280253592 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4287150793 4289121238 4289121238 4292405485 4282946731 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280122263 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 4280647835 4283669424 4283669424 4283669424 4283669424 4283669424 4283669424 4281830051 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4283997875 4284129204 4293128178 4282815402 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281632930 4292339692 4284129204 4284129204 4283078316 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4283078316 4283866289 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4293522165 4279202705 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293259507 4284457654 4284129204 4286493892 4290237918 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290237918 4287676108 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4293325043 4292537070 4292537070 4291223269 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282092965 4284129204 4284129204 4293193714 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294441723 4292537070 4293062386 4293325043 4279596692 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279793813 4284063411 4284260532 4293587958 4281501601 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282618281 4291617256 4284129204 4284129204 4282880938 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4289121238 4283603632 4283078316 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289186774 4283209645 4279202705 4279202705 4279202705 4279202705 4284194740 4288136144 4279202705 4279202705 4279202705 4279202705 4279202705 4283932082 4289581017 4289581017 4289581017 4289581017 4291551719 4294967295 4288530130 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284654519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282158502 4291091684 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4293522165 4279202705 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293522165 4279728020 4279202705 4282684073 4290566368 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292537070 4280779164 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4285114554 4280713371 4280713371 4294113273 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292537070 4280713371 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280647835 4280713371 4283800753 4290632161 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283143853 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283143853 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4289121238 4286625221 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4279202705 4280713371 4280319385 4279202705 4284654519 4288595667 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283340974 4290106589 4292602607 4286099649 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4286165442 4286625221 4286625221 4291551719 4283866289 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282158502 4292931057 4286625221 4286625221 4286559428 4280516506 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4285639870 4288989909 4292142827 4290237918 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4293719286 4286625221 4286625221 4289778139 4287282122 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285377212 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292865264 4286887878 4286625221 4288398801 4289909468 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292537070 4280713371 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288924117 4289187031 4286625221 4286625221 4294376187 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283340974 4289581017 4286625221 4286625221 4293456629 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4290566368 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280122263 4286493892 4286625221 4286625221 4292142827 4282486952 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283143853 4292339949 4286625221 4286625221 4286493892 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4285836991 4289187031 4291880169 4290500576 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728277 4293587958 4286625221 4286625221 4290040796 4286953671 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4279202705 4287085000 4286034113 4279202705 4284654519 4288595667 4279202705 4279202705 4279202705 4279202705 4279202705 4279859606 4285705662 4292339692 4290697697 4283932082 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4286165442 4286625221 4286625221 4285377212 4279531155 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280582042 4286625221 4286625221 4286625221 4286559428 4280516506 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4285639870 4286625221 4286625221 4286625221 4281107614 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283537839 4286625221 4286625221 4286099649 4280384921 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282946731 4282027173 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282880938 4286559428 4286625221 4286428099 4281567393 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282618281 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280976286 4286625221 4286625221 4286625221 4283800753 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4284129204 4286625221 4286625221 4283734960 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279596692 4282289831 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280122263 4286493892 4286625221 4286625221 4285114554 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281041822 4286625221 4286625221 4286625221 4286493892 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4285836991 4286625221 4286625221 4286559428 4280713371 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4286625221 4286625221 4286034113 4280384921 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4290369247 4288595667 4291814377 4291354598 4288595667 4290763490 4288595667 4279202705 4279202705 4279202705 4279202705 4279202705 4289909468 4294967295 4291157476 4288595667 4288595667 4288595667 4288595667 4282749610 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282749610 4284654519 4284654519 4284654519 4284654519 4284654519 4284654519 4282421415 4279202705 4279202705 4279202705 4279202705 4279202705 4282881195 4284654519 4284654519 4284654519 4284654519 4284654519 4284654519 4280779164 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279925398 4286231234 4286428099 4279990935 4279202705 4279202705 4282421415 4282684073 4279202705 4279202705 4279202705 4279202705 4279202705 4282946731 4280056727 4279202705 4279202705 4285574333 4288135887 4285771199 4279793813 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280056727 4288661459 4289121238 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4288398801 4289121238 4285048762 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4288135887 4289121238 4285705662 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287413450 4289121238 4286296771 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286034113 4287610572 4285508541 4279334034 4279202705 4279202705 4280647835 4287479243 4287610572 4287610572 4287150793 4279728277 4279202705 4279202705 4279202705 4282224294 4287413450 4285245883 4279202705 4279202705 4285574333 4287610572 4287610572 4287610572 4282684073 4279202705 4281304736 4287610572 4287610572 4287610572 4287610572 4282027173 4279202705 4279202705 4279202705 4283143853 4279728277 4279202705 4279202705 4279202705 4283472303 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282881195 4279465363 4279202705 4279202705 4279202705 4279202705 4283012524 4279531155 4279202705 4279202705 4279202705 4279202705 4280188056 4282289831 4279202705 4279202705 4279202705 4279202705 4279990935 4282552744 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287085000 4290040796 4289909468 4287282122 4279465363 4287150793 4292471278 4281961636 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283143853 4279202705 4279202705 4290566368 4287282122 4290894819 4285771199 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4283734960 4288924117 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283472303 4287873229 4288595667 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283209645 4287150793 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282749610 4286493892 4290566368 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285442749 4292996593 4291289062 4286493892 4279202705 4279202705 4279925398 4285508541 4290566368 4289384152 4285180091 4279399826 4279202705 4279202705 4285639870 4292405485 4286034113 4283472303 4279202705 4279202705 4283734960 4286822342 4293259507 4285639870 4281501601 4279202705 4282684073 4291288805 4289384152 4290303711 4290697697 4284129204 4279202705 4279202705 4279268497 4293456629 4285180091 4279202705 4279202705 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288136144 4292339692 4283472303 4279202705 4281632930 4290500576 4290960355 4279925398 4279202705 4279202705 4279202705 4279202705 4280976286 4292274156 4289121238 4280713371 4279268497 4285048762 4292996593 4285771199 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4283669424 4291354598 4291617256 4288792788 4279925398 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286822342 4287479243 4279202705 4279202705 4285114554 4280450714 4284654519 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284654519 4288595667 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4290566368 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4291551719 4280647835 4293325043 4280056727 4279202705 4279202705 4279202705 4287610572 4285639870 4279202705 4279202705 4279202705 4281764515 4293193714 4280779164 4279202705 4279202705 4279202705 4279202705 4279202705 4281173407 4292077035 4279202705 4279202705 4279202705 4279202705 4279859606 4285639870 4287085000 4279859606 4279268497 4279202705 4279202705 4282289831 4294441723 4289712346 4279202705 4279202705 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282815402 4292142827 4291485927 4293259507 4284785848 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4286165442 4293456629 4292011498 4290500576 4281370272 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137425 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137169 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4283669424 4293850615 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280122263 4292011498 4287741901 4280188056 4279202705 4279202705 4285311420 4287479243 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284654519 4288595667 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4290566368 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4291551719 4279202705 4288727251 4284983226 4279202705 4279202705 4279202705 4287610572 4285639870 4279202705 4279202705 4279202705 4287873229 4286428099 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281173407 4292077035 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4287085000 4279202705 4279202705 4279202705 4279202705 4286887878 4287544779 4293522165 4279465363 4279202705 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4285968320 4293325043 4288530130 4293062386 4287938766 4280122263 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280844957 4289318360 4292339949 4289186774 4292733935 4284194740 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278680472 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4293587958 4293587958 4294376187 4293062386 4293062386 4293062386 4284260532 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728277 4287873229 4293587958 4293522165 4293522165 4292537070 4282289831 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4283472303 4281107614 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284654519 4288595667 4282881195 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4281961636 4282618281 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4290566368 4281436065 4283209645 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4291551719 4279202705 4287544779 4285902528 4279202705 4279202705 4279202705 4287610572 4285639870 4279202705 4279202705 4279202705 4290106589 4283275181 4280910493 4288464338 4288004558 4279202705 4279202705 4279202705 4281173407 4292077035 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4287085000 4279202705 4279202705 4279202705 4279202705 4291354598 4282289831 4290697697 4282946731 4279202705 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290763490 4289646810 4281107614 4279202705 4279925398 4287544779 4292996593 4280253592 4279202705 4279202705 4279202705 4279202705 4281830308 4293325043 4286099649 4279465363 4279202705 4282224294 4291288805 4288070351 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278745496 4278549658 4278615451 4278746009 4278941590 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278615451 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202706 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279531155 4279728020 4279728020 4279728020 4279728020 4279728020 4279728020 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4279728020 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4288595667 4284654519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284654519 4288595667 4287610572 4285639870 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283669424 4289581017 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4290566368 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4291551719 4279859606 4293259507 4280779164 4279202705 4279202705 4279202705 4287610572 4285639870 4279202705 4279202705 4279202705 4290106589 4283078316 4279728020 4284523190 4294047737 4279202705 4279202705 4279202705 4281173407 4292077035 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4287085000 4279202705 4279202705 4279202705 4280319385 4294770174 4292142827 4293653494 4287544779 4279202705 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280253592 4279202705 4279202705 4279202705 4279202705 4279202705 4280319385 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4280122263 4279202705 4279202705 4279202705 4279202705 4279202705 4280319385 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006611 4278550171 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941846 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4283734960 4288924117 4289581017 4290566368 4284654519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283472303 4287873229 4290566368 4289909468 4285639870 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283209645 4287150793 4291288805 4288924117 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282749610 4286493892 4291945706 4288201680 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283537839 4292339692 4288989909 4288201680 4279202705 4279202705 4279334034 4282552744 4289187031 4287676108 4282224294 4279202705 4279202705 4288135887 4287019207 4282684073 4284982969 4292339692 4279202705 4279202705 4281304736 4284194740 4292668399 4282684073 4280056727 4279202705 4279202705 4279202705 4285639870 4287085000 4279202705 4279202705 4279202705 4284654519 4289252567 4281173407 4283209645 4292077035 4279202705 4279202705 4293062386 4283406510 4282684073 4282684073 4280516506 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941846 4278354077 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614938 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4285114554 4289712346 4284260532 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280056727 4288661459 4289121238 4289121238 4288989909 4280910493 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4288398801 4289121238 4289121238 4289055446 4281501601 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4288135887 4289121238 4289121238 4289121238 4282355623 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287413450 4289121238 4289121238 4289121238 4282946731 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4288989909 4290500576 4288333009 4279793813 4279202705 4279202705 4281304736 4290435040 4290566368 4290566368 4290172125 4279990935 4279202705 4281041822 4288595667 4290566368 4289581017 4282881195 4279202705 4279202705 4288004558 4290566368 4290566368 4290566368 4283997875 4279202705 4279202705 4279202705 4282092965 4283209645 4279202705 4279202705 4279202705 4283734960 4281830308 4279202705 4279202705 4286559428 4279202705 4279202705 4289186774 4290566368 4290566368 4290566368 4285442749 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290566368 4285114554 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4287150793 4289909468 4282815402 4279202705 4279202705 4282421415 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876566 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279334034 4282815402 4287347658 4291880169 4293128178 4294573308 4284129204 4279596692 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293850615 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283866289 4291289062 4285048762 4291880169 4279399826 4286887878 4292733935 4282815402 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278615195 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279071890 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137169 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137425 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4285377212 4294967295 4294113273 4286362563 4279728020 4293522165 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294835966 4293062386 4293062386 4293062386 4293062386 4293062386 4292405485 4280188056 4279202705 4279202705 4279202705 4279202705 4285639870 4287610572 4279728020 4294113273 4291420390 4289187031 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280910493 4285508541 4290106589 4293587958 4294704637 4285639870 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293653494 4280319385 4280188056 4280188056 4280188056 4280188056 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4287807437 4280122263 4294573308 4284982969 4279728020 4279728020 4279399826 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941846 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614938 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279071891 4278941588 4279006869 4279006869 4279006869 4279006869 4279006869 4279006869 4279006869 4279006869 4279006869 4279006869 4279006869 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4283537839 4288136144 4283866289 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4283143853 4283143853 4283143853 4283143853 4283143853 4283012524 4279399826 4279202705 4279202705 4279202705 4279202705 4279202705 4281567393 4283143853 4283143853 4283143853 4283143853 4283143853 4283143853 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4280450714 4283143853 4283143853 4283143853 4283143853 4283143853 4283143853 4281567393 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4283143853 4283143853 4283143853 4283143853 4283143853 4283143853 4282486952 4279202705 4279202705 4279202705 4279202705 4279202705 4282027173 4283143853 4283143853 4283143853 4283143853 4283143853 4283143853 4279925398 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281567393 4283143853 4283143853 4283143853 4283143853 4283143853 4283143853 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293522165 4286231234 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284983226 4293522165 4293522165 4293522165 4293522165 4293522165 4293522165 4288070351 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811030 4278615451 4278484636 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278549916 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292996593 4292996593 4290106589 4290106589 4290106589 4290106589 4289975260 4281173407 4279202705 4279202705 4279202705 4279202705 4279202705 4288530130 4294376187 4290172125 4290106589 4290106589 4290106589 4290106589 4284194740 4279202705 4279202705 4279202705 4279202705 4279202705 4284063411 4294967295 4291026147 4290106589 4290106589 4290106589 4290106589 4287216329 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280122263 4294967295 4292077035 4290106589 4290106589 4290106589 4290106589 4289318360 4279596692 4279202705 4279202705 4279202705 4279202705 4290500576 4293916408 4290106589 4290106589 4290106589 4290106589 4290106589 4282880938 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288530130 4294376187 4290172125 4290106589 4290106589 4290106589 4290106589 4284194740 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283132532 4279595662 4279595662 4279595662 4279595662 4279595662 4279595662 4279595662 4279138710 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278746778 4278942873 4279595662 4279595662 4279595662 4279595662 4279595662 4279595662 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279530126 4279399055 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282552744 4292405485 4288201680 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280516506 4289975260 4290829026 4281764515 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4286953671 4292865264 4284063411 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284326325 4293128178 4286296771 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281304736 4291157476 4289975260 4280910493 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280516506 4289975260 4291026147 4281764515 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281173407 4291223269 4290237918 4280779164 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4288004558 4292339949 4283078316 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284982969 4293259507 4285968320 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282618281 4292602607 4288267472 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280253592 4289384152 4291683048 4282027173 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4288004558 4292471278 4283078316 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811288 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292602607 4292865264 4288135887 4288135887 4288135887 4288135887 4288004558 4280779164 4279202705 4279202705 4279202705 4279202705 4279202705 4288136144 4294376187 4288530130 4288135887 4288135887 4288135887 4288135887 4283275181 4279202705 4279202705 4279202705 4279202705 4279202705 4283734960 4294967295 4290040796 4288135887 4288135887 4288135887 4288135887 4285771199 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279990935 4294770174 4291551719 4288135887 4288135887 4288135887 4288135887 4287413450 4279596692 4279202705 4279202705 4279202705 4279202705 4290172125 4293916408 4288267472 4288135887 4288135887 4288135887 4288135887 4282158502 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288136144 4294376187 4288595667 4288135887 4288135887 4288135887 4288135887 4283275181 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876311 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283932082 4284654519 4284654519 4284654519 4284654519 4284654519 4284523190 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4282421415 4284654519 4284654519 4284654519 4284654519 4284654519 4284654519 4281107614 4279202705 4279202705 4279202705 4279202705 4279202705 4280844957 4284654519 4284654519 4284654519 4284654519 4284654519 4284654519 4282684073 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279531155 4284654519 4284654519 4284654519 4284654519 4284654519 4284654519 4283932082 4279202705 4279202705 4279202705 4279202705 4279202705 4283078316 4284654519 4284654519 4284654519 4284654519 4284654519 4284654519 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282421415 4284654519 4284654519 4284654519 4284654519 4284654519 4284654519 4281107614 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072146 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278745751 4278549658 4278484636 4278615451 4278745752 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279007124 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284785848 4287610572 4287610572 4287610572 4287610572 4287610572 4284851640 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4282421415 4287610572 4287610572 4287610572 4287610572 4287610572 4286362563 4280122263 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4287347658 4287610572 4287610572 4287610572 4287610572 4287150793 4281764515 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4286362563 4287610572 4287610572 4287610572 4287610572 4287479243 4283275181 4279202705 4279202705 4279202705 4279202705 4279202705 4283472303 4287610572 4287610572 4287610572 4287610572 4287610572 4285836991 4279728277 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282421415 4287610572 4287610572 4287610572 4287610572 4287610572 4286362563 4280122263 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278615194 4278615193 4278941589 4279072146 4279202705 4279137426 4279007124 4278680216 4278615451 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137682 4278941589 4278811031 4278810774 4278810774 4278810774 4278810774 4278810774 4278810774 4278810774 4278810774 4278810774 4278810774 4278810774 4278941845 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282815402 4285114554 4285114554 4285114554 4285114554 4285114554 4291551719 4283997875 4279202705 4279202705 4279202705 4279202705 4279202705 4281107614 4285114554 4285114554 4285114554 4285114554 4285114554 4288792788 4288464338 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4284982969 4285114554 4285114554 4285114554 4285114554 4286033856 4293062386 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283997875 4285114554 4285114554 4285114554 4285114554 4285311420 4293128178 4280779164 4279202705 4279202705 4279202705 4279202705 4281830308 4285114554 4285114554 4285114554 4285114554 4285114554 4289778139 4286625221 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281107614 4285114554 4285114554 4285114554 4285114554 4285114554 4288792788 4288464338 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278549915 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278550171 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282224294 4290500576 4290566368 4290566368 4293916408 4282027173 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279793813 4289712346 4290566368 4290566368 4292668399 4286493892 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286953671 4290566368 4290566368 4291420390 4290960355 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284457654 4290566368 4290566368 4290763490 4293456629 4279925398 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280516506 4290237918 4290566368 4290566368 4293193714 4284785848 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4289646810 4290566368 4290566368 4292668399 4286493892 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278549916 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278549915 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4282618281 4282684073 4282684073 4290697697 4284457654 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281895844 4282684073 4282684073 4287150793 4288924117 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280844957 4282684073 4282684073 4283734960 4293390836 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280122263 4282684073 4282684073 4282880938 4292799728 4281107614 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282289831 4282684073 4282684073 4288398801 4287019207 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281830308 4282684073 4282684073 4287150793 4288924117 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745753 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288201680 4293062386 4293062386 4293062386 4293062386 4293062386 4292799728 4281173407 4279202705 4279202705 4279202705 4279202705 4279202705 4284326325 4293062386 4293062386 4293062386 4293062386 4293062386 4293522165 4284260532 4279202705 4279202705 4279202705 4279202705 4279202705 4280779164 4292733935 4293062386 4293062386 4293062386 4293062386 4293587958 4288333009 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4290960355 4293062386 4293062386 4293062386 4293062386 4293259507 4291289062 4279596692 4279202705 4279202705 4279202705 4279202705 4286034113 4293062386 4293062386 4293062386 4293062386 4293062386 4293325043 4282946731 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284326325 4293062386 4293062386 4293062386 4293062386 4293062386 4293522165 4284260532 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4279202961 4279202705 4279202705 4279202705 4279006868 4278549915 4278353822 4278484636 4278941589 4279202705 4279202705 4279202705 4279202705 4278549659 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279333777 4283006606 4285499278 4286417036 4286482829 4286745225 4287992693 4287992693 4287992693 4287992693 4287992693 4287992693 4287204738 4286482829 4286482829 4285761165 4281695120 4279202705 4279202705 4279202705 4279202705 4284194740 4286165442 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4280188056 4280188056 4280188056 4280188056 4280188056 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4280188056 4280188056 4280188056 4280188056 4280188056 4279596692 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280056727 4280188056 4280188056 4280188056 4280188056 4279793813 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279793813 4280188056 4280188056 4280188056 4280188056 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4280188056 4280188056 4280188056 4280188056 4280188056 4279465363 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4280188056 4280188056 4280188056 4280188056 4280188056 4279596692 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006867 4278615194 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278353822 4279007124 4279202705 4279202705 4279202705 4278745752 4278941846 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284908942 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4284974478 4279202705 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876311 4278811031 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278614938 4279202705 4279202705 4279202705 4279007124 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281497999 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4280711312 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283537839 4291091684 4292537070 4290040796 4281238943 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281173407 4289581017 4292471278 4291288805 4283866289 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4287741901 4292274156 4292077035 4286822342 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285377212 4291748585 4292405485 4289055446 4279728277 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281961636 4290237918 4292537070 4290763490 4282684073 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281173407 4289581017 4292471278 4291288805 4283866289 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278876310 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279006868 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283334799 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4283597199 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291814377 4282880938 4280713371 4286428099 4287347658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287347658 4286887878 4280713371 4282158502 4292208364 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282815402 4290960355 4280779164 4280910493 4291880169 4280910493 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279596692 4293128178 4281173407 4280713371 4289121238 4284391861 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289187031 4285245883 4280713371 4283800753 4290237918 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287347658 4286887878 4280713371 4282158502 4292208364 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006869 4278680217 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4278810774 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282744207 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4282481807 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4280188056 4279202705 4284129204 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284654519 4279202705 4279202705 4294047737 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4289121238 4279202705 4279202705 4290566368 4282684073 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4292537070 4279202705 4279202705 4287085000 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290566368 4282684073 4279202705 4281173407 4292077035 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284654519 4279202705 4279202705 4294047737 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278549915 4279202705 4279202705 4279202705 4279202705 4278745751 4278354078 4278354078 4278354078 4278614937 4279202961 4279202705 4279202705 4279202705 4278614938 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280186512 4287138700 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287204236 4279661712 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4282946731 4282158502 4286165442 4290237918 4282158502 4282027173 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4286559428 4282158502 4282158502 4294244602 4282158502 4282158502 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4290237918 4282158502 4282158502 4291354598 4284982969 4282158502 4280844957 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4292996593 4282158502 4282158502 4288595667 4287807437 4282158502 4281567393 4279202705 4279202705 4279202705 4279202705 4279202705 4290566368 4284982969 4282158502 4283800753 4292602607 4282158502 4282158502 4279662484 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4286559428 4282158502 4282158502 4294244602 4282158502 4282158502 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549658 4279007125 4279202705 4279202705 4279202705 4279202705 4279072147 4278941589 4279006612 4279202705 4279202705 4279202705 4279202705 4279072147 4278549916 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281825935 4287007629 4287466636 4287466636 4287466636 4288254335 4292193593 4292193593 4292193593 4292193593 4292193593 4292193593 4289698661 4287466636 4287466636 4287466636 4286351500 4281826191 4279202705 4279202705 4279202705 4285639870 4292931057 4290566368 4290566368 4289909468 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4291091684 4291091684 4291091684 4291091684 4291091684 4290960355 4281304736 4279202705 4279202705 4279202705 4279202705 4279202705 4286231234 4291091684 4291091684 4291091684 4291091684 4291091684 4291091684 4284588983 4279202705 4279202705 4279202705 4279202705 4279202705 4282881195 4291091684 4291091684 4291091684 4291091684 4291091684 4291091684 4287938766 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279925398 4291091684 4291091684 4291091684 4291091684 4291091684 4291091684 4290237918 4279596692 4279202705 4279202705 4279202705 4279202705 4287741901 4291091684 4291091684 4291091684 4291091684 4291091684 4291091684 4283078316 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286231234 4291091684 4291091684 4291091684 4291091684 4291091684 4291091684 4284588983 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278549916 4279137425 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278549914 4278941332 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279924369 4282022799 4283072142 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4282416271 4279399313 4279202705 4279202705 4279202705 4279202705 4280384921 4282158502 4282158502 4282158502 4281632930 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278549658 4279137682 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137169 4278680217 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278550171 4278941846 4279202961 4279202705 4279202705 4279202705 4279202961 4279006868 4278549916 4278876566 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278745752 4278549916 4278549916 4278615193 4278549915 4278550171 4278680474 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279006612 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278549659 4278484636 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278484637 4278549916 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876311 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072146 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278353822 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285705662 4288858580 4281632930 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293390836 4293390836 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290960355 4284654519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292865264 4294967295 4285968320 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137682 4278941590 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278876310 4279202706 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282158502 4294967295 4294967295 4282158502 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294441980 4287544779 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284523190 4287347658 4280976286 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286756550 4294967295 4294967295 4286690757 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4294507516 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291289062 4292865264 4293259507 4291223269 4279202705 4279202705 4279202705 4279202705 4279202705 4280976286 4290369247 4280188056 4282880938 4290369247 4292471278 4288989909 4281501601 4279202705 4279202705 4279202705 4279202705 4279202705 4283143853 4289975260 4292537070 4290040796 4281698722 4294507516 4287610572 4279202705 4279202705 4279202705 4282880938 4289187031 4279202705 4279202705 4279202705 4279202705 4283866289 4288595667 4279202705 4279202705 4279202705 4279202705 4281173407 4291617256 4292537070 4291748585 4282158502 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285048762 4287150793 4279990935 4286690757 4292011498 4291814377 4286362563 4279334034 4279202705 4279202705 4279202705 4279202705 4279596692 4286953671 4291485927 4292537070 4291288805 4286099649 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280319385 4294770174 4288333009 4288661459 4294704637 4280122263 4279202705 4279202705 4279202705 4279202705 4283997875 4294967295 4289121238 4294835966 4293850615 4290632161 4294244602 4290632161 4279202705 4279202705 4279202705 4279202705 4284785848 4294901503 4292996593 4290106589 4293587958 4294507516 4294835966 4287610572 4279202705 4279202705 4279202705 4286887878 4294901503 4279334034 4279202705 4279202705 4279202705 4288004558 4294441723 4279202705 4279202705 4279202705 4279202705 4280582042 4289318360 4290500576 4294967295 4286033856 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289975260 4293850615 4293259507 4294770174 4290763490 4292537070 4294967295 4285114554 4279202705 4279202705 4279202705 4279334034 4290435040 4294967295 4292274156 4290106589 4292733935 4294967295 4289186774 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268241 4282744463 4285236621 4286154893 4286155149 4286352010 4287468153 4287468153 4287468153 4287468153 4287468153 4287468153 4286745732 4286155149 4286155149 4285564813 4281564048 4279202705 4279202705 4279202705 4279202705 4284194740 4291551719 4291551719 4291551719 4291551719 4281501601 4279202705 4285705662 4281764515 4279202705 4280319385 4287150793 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284654519 4294967295 4283932082 4284063411 4294967295 4284391861 4279202705 4279202705 4279202705 4279202705 4284063411 4294967295 4294967295 4290894819 4280319385 4279202705 4285574333 4294901503 4280122263 4279202705 4279202705 4279202705 4292274156 4292602607 4279728277 4279202705 4280056727 4290632161 4294967295 4287610572 4279202705 4279202705 4279202705 4286493892 4294967295 4279859606 4279202705 4279202705 4279202705 4288135887 4294441723 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4294967295 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4294967295 4292077035 4282421415 4279202705 4279399826 4294507516 4288530130 4279202705 4279202705 4279202705 4282092965 4294967295 4288136144 4279202705 4279202705 4279268497 4289581017 4294967295 4280647835 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284777614 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4284777614 4279202705 4279202705 4279202705 4283472303 4286428099 4289186774 4286690757 4288267472 4280844957 4279202705 4283932082 4291354598 4279202705 4288464338 4286953671 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289187031 4294507516 4279859606 4279925398 4294573308 4288924117 4279202705 4279202705 4279202705 4279202705 4284063411 4294967295 4288727251 4279465363 4279202705 4279202705 4280516506 4285836991 4279268497 4279202705 4279202705 4279202705 4293522165 4289449689 4279202705 4279202705 4279202705 4280122263 4294704637 4287610572 4279202705 4279202705 4279202705 4285968320 4294967295 4280384921 4279202705 4279202705 4279202705 4288135887 4294376187 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4294967295 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4293062386 4279465363 4279202705 4279202705 4279202705 4293193714 4289449689 4279202705 4279202705 4279202705 4283669424 4294967295 4283143853 4279202705 4279202705 4279202705 4284654519 4294967295 4282158502 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281432720 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4280579984 4279202705 4279202705 4279202705 4279202705 4288135887 4285114554 4279202705 4279202705 4279202705 4279202705 4290566368 4287610572 4292799728 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4293653494 4293653494 4288135887 4288135887 4293719286 4293390836 4279202705 4279202705 4279202705 4279202705 4284063411 4294967295 4282618281 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293522165 4289121238 4279202705 4279202705 4279202705 4279202705 4294507516 4287610572 4279202705 4279202705 4279202705 4285442749 4294967295 4280910493 4279202705 4279202705 4279202705 4288135887 4294244602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4294967295 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4292537070 4279202705 4279202705 4279202705 4279202705 4292537070 4289975260 4279202705 4279202705 4279202705 4283669424 4294967295 4283143853 4279202705 4279202705 4279202705 4284654519 4294967295 4282158502 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283334542 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4283596942 4279202705 4279202705 4279202705 4279202705 4288135887 4285114554 4279202705 4279202705 4279202705 4279202705 4281698722 4294901503 4284523190 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282552744 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4282158502 4279202705 4279202705 4279202705 4284063411 4294967295 4282618281 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293456629 4289646810 4279202705 4279202705 4279202705 4280779164 4294770174 4287610572 4279202705 4279202705 4279202705 4284917433 4294967295 4281501601 4279202705 4279202705 4279334034 4289712346 4294179065 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4294967295 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4292537070 4279202705 4279202705 4279202705 4279202705 4291945706 4290435040 4279202705 4279202705 4279202705 4283603632 4294967295 4283209645 4279202705 4279202705 4279202705 4284720311 4294967295 4282092965 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282744207 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4282547855 4279202705 4279202705 4279202705 4279202705 4288135887 4285114554 4279202705 4279202705 4279202705 4279202705 4284194740 4294507516 4287150793 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287085000 4294967295 4281567393 4279202705 4279202705 4281830051 4294967295 4286690757 4279202705 4279202705 4279202705 4284063411 4294967295 4282618281 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291880169 4293128178 4280582042 4279202705 4281107614 4292011498 4294967295 4287610572 4279202705 4279202705 4279202705 4283932082 4294967295 4283866289 4279202705 4282027173 4291485927 4294967295 4294113273 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4294967295 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4292537070 4279202705 4279202705 4279202705 4279202705 4291289062 4291026147 4279202705 4279202705 4279202705 4281436065 4294967295 4289581017 4279596692 4279202705 4279793813 4290829026 4294967295 4280253592 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279661712 4279727505 4279727505 4279727505 4279727505 4279727505 4279727505 4279727505 4279727505 4279727505 4279727505 4279727505 4279530384 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280252305 4287138957 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287204236 4279727505 4279202705 4279202705 4279202705 4279202705 4288135887 4285114554 4279202705 4279202705 4279202705 4279728020 4292733935 4283078316 4293128178 4281107614 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291617256 4292142827 4279202705 4279202705 4279202705 4279202705 4292931057 4291157476 4279202705 4279202705 4279202705 4283932082 4294967295 4282421415 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283340974 4294441980 4294113273 4292077035 4294507516 4293850615 4294638845 4287413450 4279202705 4279202705 4279202705 4280582042 4294047737 4294704637 4292339949 4294770174 4293653494 4291485927 4293916408 4279202705 4279202705 4279202705 4279202705 4281173407 4291289062 4292339692 4294967295 4293390836 4291748585 4284326325 4279202705 4279202705 4279202705 4279202705 4289843675 4292339949 4279202705 4279202705 4279202705 4279202705 4290566368 4291223269 4279202705 4279202705 4279202705 4279202705 4288333009 4294967295 4293850615 4292077035 4294113273 4294967295 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279727505 4284187534 4286876300 4287466636 4287466636 4287729287 4290158428 4290158428 4290158428 4290158428 4290158428 4290158428 4288976497 4287466636 4287466636 4287204493 4283596942 4279661969 4279202705 4279202705 4279202705 4279202705 4286493892 4288595667 4288595667 4287085000 4280779164 4279202705 4279465363 4284260532 4279202705 4279202705 4281567393 4282092965 4279202705 4282749610 4288595667 4288595667 4288398801 4283603632 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282023056 4287072908 4287466636 4287466636 4287466636 4288254335 4292193593 4292193593 4292193593 4292193593 4292193593 4292193593 4289698661 4287466636 4287466636 4287466636 4286351500 4281826191 4279202705 4279202705 4279202705 4279202705 4279202705 4288135887 4285114554 4279202705 4279202705 4279202705 4286690757 4288267472 4279202705 4285311420 4289646810 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286493892 4283340974 4279202705 4279202705 4279202705 4279202705 4283800753 4286165442 4279202705 4279202705 4279202705 4280647835 4288333009 4279793813 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4288595667 4290566368 4288004558 4280582042 4287085000 4282486952 4279202705 4279202705 4279202705 4279202705 4282027173 4288595667 4290500576 4286756550 4280384921 4282552744 4286690757 4279202705 4279202705 4279202705 4279202705 4280582042 4289646810 4290566368 4290566368 4290566368 4290237918 4283012524 4279202705 4279202705 4279202705 4279202705 4283800753 4285836991 4279202705 4279202705 4279202705 4279202705 4284457654 4284982969 4279202705 4279202705 4279202705 4279202705 4279202705 4285114554 4289712346 4290566368 4289515481 4284260532 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279268497 4285499278 4287466636 4287466636 4287466636 4287466636 4288188800 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4291536965 4287466636 4287466636 4287466636 4287466636 4286613900 4279399313 4279202705 4279202705 4279202705 4291551719 4285968320 4284654519 4287216329 4289055446 4279202705 4280713371 4292537070 4279202705 4279202705 4286099649 4287085000 4279202705 4285114554 4290172125 4284654519 4285377212 4293259507 4280779164 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279989648 4282153871 4283072142 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4282416271 4279399313 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281567393 4280319385 4279202705 4279202705 4279202705 4282421415 4279728020 4279202705 4279202705 4282881195 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279137426 4279202705 4279202705 4279202705 4281432720 4287466636 4287466636 4287466636 4287466636 4287466636 4288188800 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4291536965 4287466636 4287466636 4287466636 4287466636 4287466636 4281957520 4279202705 4279202705 4279202705 4291551719 4281173407 4279202705 4281173407 4292011498 4279202705 4280713371 4292537070 4279202705 4279662484 4286099649 4287085000 4279202705 4285114554 4288989909 4282158502 4282880938 4292733935 4281370272 4279202705 4279202705 4279202705 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4282875791 4287466636 4287466636 4287466636 4287466636 4287466636 4288188800 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4291536965 4287466636 4287466636 4287466636 4287466636 4287466636 4284580750 4279202705 4279202705 4279202705 4291551719 4281173407 4279202705 4282684073 4290763490 4279202705 4280713371 4292537070 4282815402 4288727251 4286099649 4287085000 4279202705 4285114554 4293587958 4294835966 4290435040 4286033856 4279202705 4279202705 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4281826191 4287466636 4287466636 4287466636 4287466636 4287466636 4288188800 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4291536965 4287466636 4287466636 4287466636 4287466636 4287466636 4282547855 4279202705 4279202705 4279202705 4291551719 4294179065 4294047737 4292077035 4283537839 4279202705 4280713371 4292537070 4283669424 4289581017 4286099649 4287085000 4279202705 4285114554 4288135887 4289843675 4285968320 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279990935 4281173407 4281173407 4280910493 4279202705 4279202705 4279202705 4279465363 4279202705 4279202705 4279202705 4279465363 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279530384 4286351757 4287466636 4287466636 4287466636 4287466636 4288188800 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4291536965 4287466636 4287466636 4287466636 4287466636 4287204236 4279661712 4279202705 4279202705 4279202705 4291551719 4281173407 4279202705 4279202705 4279202705 4279202705 4280713371 4292537070 4283669424 4289581017 4286099649 4287085000 4279202705 4285114554 4288135887 4280384921 4292931057 4281830308 4279202705 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268241 4282744463 4285236621 4286154893 4286155149 4286352010 4287468153 4287468153 4287468153 4287468153 4287468153 4287468153 4286745732 4286155149 4286155149 4285564557 4281432463 4279202705 4279202705 4279202705 4279202705 4285639870 4293587958 4292077035 4292733935 4291551719 4279334034 4279202705 4288070351 4284654519 4279202705 4282224294 4290500576 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4280514448 4285761421 4287466636 4287466636 4287466636 4287794823 4290880337 4290880337 4290880337 4290880337 4290880337 4290880337 4289370475 4287466636 4287466636 4287466636 4285302157 4280645776 4279202705 4279202705 4279202705 4279202705 4291551719 4281173407 4279202705 4279202705 4279202705 4279202705 4279793813 4293456629 4287741901 4291945706 4289449689 4285836991 4279202705 4285114554 4288135887 4279202705 4283734960 4292077035 4279531155 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284711821 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4284711821 4279202705 4279202705 4279202705 4285639870 4287610572 4279202705 4279202705 4291354598 4281895844 4279202705 4281304736 4293062386 4280122263 4291354598 4283800753 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279006868 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280186256 4281236112 4281235856 4281235856 4281235856 4281235856 4281235856 4281235856 4281235856 4281235856 4281235856 4281235856 4281235856 4280908176 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284720311 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4284851640 4288792788 4286559428 4288136144 4279793813 4279202705 4281501601 4283012524 4279202705 4279202705 4285639870 4280253592 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281367184 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4280579984 4279202705 4279202705 4285639870 4293193714 4291091684 4291748585 4292668399 4279465363 4279202705 4279202705 4287413450 4292077035 4290369247 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283334542 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4283596942 4279202705 4279202705 4285639870 4289646810 4293653494 4284129204 4279399826 4279202705 4279202705 4279202705 4280582042 4294901503 4283472303 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282744463 4287466636 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287466636 4282547855 4279202705 4279202705 4285639870 4287610572 4284391861 4291420390 4279399826 4279202705 4279202705 4279202705 4287413450 4292077035 4290369247 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280317841 4287204236 4287466636 4287466636 4287466636 4287466636 4288582776 4294688270 4294688270 4294688270 4294688270 4294688270 4294688270 4290880337 4287466636 4287466636 4287466636 4287466636 4287204236 4279727505 4279202705 4279202705 4285639870 4287610572 4279202705 4289186774 4286953671 4279202705 4279202705 4281304736 4293062386 4280122263 4291354598 4283800753 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282023056 4287072908 4287466636 4287466636 4287466636 4288254334 4292455989 4292455989 4292455989 4292455989 4292455989 4292455989 4289829988 4287466636 4287466636 4287466636 4286482829 4281891984 4279202705 4279202705 4279202705 4284654519 4286625221 4279202705 4280056727 4292405485 4280253592 4279202705 4288070351 4284654519 4279202705 4282224294 4290500576 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279989648 4282153871 4283072142 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4283072399 4282482063 4279464848 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4279202705 4279202705 4279531155 4279202705 4279202705 4279465363 4279202705 4279202705 4279202705 4279465363 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278876311 4278549658 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278615451 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615193 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614937 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811287 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745751 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285442749 4294047737 4294179065 4287019207 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876311 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280450714 4281173407 4281173407 4281173407 4281173407 4281173407 4285508541 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354077 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4292602607 4291551719 4291551719 4291551719 4291551719 4292602607 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941846 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484893 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289121238 4284129204 4279202705 4279202705 4279202705 4279202705 4284129204 4289121238 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284769895 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4283198067 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279071890 4278876310 4278811288 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278876566 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283406510 4280779164 4279202705 4279202705 4279202705 4279202705 4280779164 4283406510 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284966502 4284835431 4282608503 4282608503 4282608503 4282608503 4282608503 4282608503 4282608503 4282478202 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282282365 4282347643 4282608503 4282608503 4282608503 4282608503 4282608503 4282608503 4282543224 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4282608504 4281560704 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680472 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280377715 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4281551956 4280573038 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615193 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280442481 4282335296 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280834922 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137682 4279202706 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137169 4279137682 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279071890 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278876310 4278549659 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278615451 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280573552 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335296 4280834408 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549916 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419358 4279072146 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941846 4278484893 4278354078 4278353822 4278614937 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278549658 4278353822 4278354078 4278484636 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876311 4278419357 4278354078 4278419357 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278615451 4278353822 4278354078 4278550171 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278614938 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614937 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335297 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335296 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072403 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278550171 4278354078 4278354078 4278354078 4278354078 4278354077 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278680217 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137425 4278484636 4278354078 4278354078 4278354078 4278354078 4278419357 4279137682 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278680473 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278680473 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278811031 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278745753 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278941845 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4285492577 4288320633 4288320633 4288320633 4285821027 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284899921 4288254571 4288320108 4288320108 4286280793 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876566 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549658 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006611 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4278876311 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811287 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745751 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680472 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278353822 4278745496 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4288320633 4288715387 4287926134 4286346851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281048 4288319593 4288714861 4288188777 4286543961 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419358 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941845 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137169 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006869 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876311 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941332 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484893 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4287860082 4287399523 4287136617 4286281571 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281048 4287990884 4287399523 4287201887 4286478169 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278876310 4278680217 4278549915 4278549915 4278614937 4278810774 4279072146 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354077 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072403 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4287202669 4286084447 4286150242 4286346851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281048 4287464800 4286083921 4286083921 4286478168 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941846 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484893 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811287 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876311 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4284834649 4284834388 4284768852 4284768852 4284702807 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284439628 4284899911 4284768327 4284768327 4284833865 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072146 4278876310 4278811288 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278876566 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006867 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354077 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279399569 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279465105 4279268241 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419358 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006867 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614938 4279137425 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006612 4278876310 4278811031 4278811031 4278811031 4278811031 4285630606 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4282876562 4278811031 4278811031 4278811031 4278941845 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282139975 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335811 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006867 4278811287 4278680473 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278745496 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278745752 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137682 4278876311 4278680472 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4278680217 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278680472 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4287466636 4287400843 4286085240 4286479998 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4286413948 4286216826 4287466636 4287466636 4282615446 4278354078 4278354078 4278354078 4278354078 4278419101 4279007124 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279464075 4282139461 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335811 4279725447 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876311 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4286874756 4283124555 4282400832 4282400832 4283716692 4287400843 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287335050 4283453520 4282400832 4282400832 4283256141 4287137671 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279464075 4282139461 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335811 4279725447 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280450714 4279202705 4279202705 4279263866 4280165414 4280165414 4280230435 4280295714 4280295714 4280295714 4280295714 4280295714 4280295714 4280295714 4280165157 4280165414 4279580995 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278876311 4278615194 4278550171 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549659 4279006869 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549658 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4284835173 4282400832 4282400832 4282400832 4282400832 4285887604 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4285558639 4282400832 4282400832 4282400832 4282400832 4285229931 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280443252 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4281682769 4280704366 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282486952 4288989909 4279202705 4279202705 4279262580 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4279774516 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419358 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876309 4279202705 4279202705 4279202705 4279202705 4279202705 4278745495 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278614938 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614937 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549916 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4283782485 4282400832 4282400832 4282400832 4282400832 4284703587 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4284374622 4282400832 4282400832 4282400832 4282400832 4284111193 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280377718 4282401089 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335296 4280704365 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4289121238 4279202705 4279202705 4279262579 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4279839794 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4278941845 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614937 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278484637 4278354078 4278354078 4278354078 4278354078 4278354078 4278353822 4279072146 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072403 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680472 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4285624432 4282400832 4282400832 4282400832 4282400832 4286611327 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4286348155 4282400832 4282400832 4282400832 4282400832 4286019190 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278353822 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280377718 4282401089 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335296 4280704365 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4289121238 4279202705 4279202705 4279588972 4280690214 4280690214 4280558628 4280098077 4280098077 4280098077 4280098077 4280098077 4280098077 4280295456 4280690214 4280690214 4280100651 4279202705 4286690757 4292537070 4292537070 4282881195 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941332 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354077 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941845 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278484892 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811287 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745751 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278941589 4278811031 4278615194 4278484636 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278419357 4278745752 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137682 4278484893 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4287335050 4285032295 4282992712 4283321934 4285558896 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287203464 4286216826 4285229931 4285690225 4286677120 4287400843 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4285361260 4283256141 4283124555 4285229674 4287400843 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335297 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335296 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288136144 4292537070 4292537070 4292537070 4292537070 4292537070 4287544779 4279202705 4279202705 4279588972 4280690214 4280690214 4280229663 4284503855 4281808169 4282268720 4282268720 4282137136 4278979339 4279111182 4280690214 4280690214 4280100651 4279202705 4288135887 4294967295 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278419357 4278354078 4278353822 4278549914 4279072146 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278549916 4278354078 4278354078 4278419101 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278680473 4278419357 4278354078 4278353822 4278549659 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278484636 4278354078 4278354078 4278484637 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876311 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278745752 4278549915 4278484636 4278484636 4278484636 4278484636 4285499791 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4286150776 4283256141 4282400832 4282400832 4282400832 4282400832 4282400832 4282664004 4284308572 4287137671 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287400843 4287466636 4287466636 4282680724 4278484636 4278484636 4278484380 4278549659 4278941846 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4285163356 4287597428 4287597428 4287597428 4285492320 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284703065 4287662708 4287597428 4287597428 4285887333 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279588972 4280690214 4280690214 4280229663 4284898610 4286149203 4287465321 4287596906 4285952345 4279900438 4279111182 4280690214 4280690214 4280100651 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202706 4279007124 4279072146 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4279007125 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137425 4278941589 4279137682 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278941332 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278353822 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354077 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137682 4278811030 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278615193 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287269257 4284571744 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282927176 4286019447 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807658 4288452218 4288846973 4288123254 4286346851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281317 4288386167 4288846973 4288517753 4286544228 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280319385 4279202705 4279202705 4279202705 4279202705 4279202705 4280384921 4279202705 4279202705 4279588972 4280690214 4280690214 4280229663 4284898610 4286346326 4287004769 4287399523 4285820758 4279900438 4279111182 4280690214 4280690214 4280100651 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484893 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549659 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287400843 4283585106 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4285690482 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4287860082 4287399523 4287136617 4286281571 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281317 4287991410 4287399523 4287202409 4286478691 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291683048 4279202705 4279202705 4279202705 4279202705 4282421415 4288924117 4279202705 4279202705 4279588972 4280690214 4280690214 4280229663 4284898610 4286280276 4285294673 4285228880 4285294673 4279900438 4279111182 4280690214 4280690214 4280100651 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072146 4278876310 4278811288 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278745495 4278876566 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876567 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4285098345 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282729797 4286940549 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4287465327 4286347361 4286413156 4286281571 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281317 4287597169 4286347361 4286347364 4286544226 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4279202705 4279399826 4284391861 4279202705 4282684073 4289121238 4279202705 4279202705 4279588972 4280690214 4280690214 4280229663 4284898610 4282465837 4282400043 4282400043 4282268716 4279242766 4279111182 4280690214 4280690214 4280100651 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4281501601 4282684073 4279202705 4279202705 4284194740 4279925398 4279202705 4281830308 4288989909 4289581017 4288989909 4282749610 4279202705 4279202705 4289121238 4289121238 4288595667 4283800753 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278550171 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4286611327 4282532418 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4283914071 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4285097820 4284900435 4284834642 4284900179 4284966233 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284900442 4285032020 4284834642 4284834642 4285097819 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4279202705 4280188056 4291551719 4279202705 4282684073 4289121238 4279202705 4279202705 4279523951 4279900698 4279900698 4279571733 4284898610 4280097550 4281676058 4281676058 4280821012 4278190080 4278848010 4279900698 4279900698 4279904300 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4291091684 4282158502 4279202705 4288661459 4288136144 4283669424 4285180091 4290106589 4279202705 4279202705 4294310394 4283669424 4284063411 4291091684 4283800753 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278550171 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4284637794 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286874499 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291288805 4292537070 4292537070 4292931057 4292537070 4292602607 4287873229 4279202705 4279202705 4279133309 4278190080 4278190080 4278190080 4284898610 4279176455 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278989115 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4291091684 4282158502 4279202705 4282158502 4292996593 4280779164 4279202705 4279334034 4279202705 4279202705 4294047737 4279202705 4279202705 4285771199 4287150793 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4283585106 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4285822068 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282204997 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335554 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279068031 4278190080 4278190080 4278190080 4284898610 4279176455 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278662724 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4291091684 4282158502 4279202705 4279202705 4285245883 4291289062 4279531155 4279202705 4279202705 4279202705 4294441980 4286625221 4287019207 4292733935 4282027173 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941332 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287400843 4282664004 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284834916 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279594376 4282204739 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335554 4279790210 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279531155 4280319385 4279202705 4279202705 4279202705 4281173407 4279399826 4279202705 4279202705 4279068031 4278190080 4278190080 4278190080 4284898610 4279176455 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278662724 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4291091684 4282158502 4279202705 4279202705 4279202705 4288792788 4288135887 4279202705 4279202705 4279202705 4294441980 4286099649 4286625221 4292602607 4281632930 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278811287 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4278615194 4279007124 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4286940292 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284111193 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279594376 4282204739 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335554 4279790210 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4284785848 4279202705 4279465363 4287873229 4292602607 4287479243 4279202705 4279202705 4279068031 4278190080 4278190080 4278190080 4284898610 4279176455 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278662724 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4291091684 4282158502 4279202705 4279399826 4279202705 4279662484 4291748585 4284523190 4279202705 4279202705 4294047737 4279202705 4279202705 4285705662 4286887878 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4282729797 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284966502 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280246902 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4281617235 4280573552 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4279202705 4280647835 4290894819 4286822342 4282749610 4289121238 4279202705 4279202705 4279068031 4278190080 4278190080 4278190080 4284898610 4279176455 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278662724 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4283275181 4291223269 4284129204 4284391861 4292865264 4280056727 4279202705 4287873229 4286822342 4284129204 4286493892 4291748585 4279202705 4279202705 4294376187 4284129204 4284523190 4291485927 4283406510 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4283782485 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286019190 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280116345 4282400833 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280442994 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4282880938 4292142827 4283472303 4279202705 4283209645 4288792788 4279202705 4279202705 4279068031 4278190080 4278190080 4278190080 4284898610 4279176455 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278793024 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4279334034 4284785848 4288530130 4288136144 4282881195 4279202705 4279202705 4281173407 4287873229 4289121238 4288858580 4283472303 4279202705 4279202705 4288595667 4288595667 4288135887 4283603632 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4284834916 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4287071878 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280116345 4282400833 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280442994 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286953671 4290369247 4281041822 4279202705 4279202705 4288004558 4283275181 4279202705 4279202705 4279459187 4279176975 4279176975 4279045389 4284898610 4279768331 4280229135 4280229135 4279768588 4278190080 4278584838 4279176975 4279176975 4279707694 4279202705 4281107614 4289187031 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4286940292 4282729797 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284374622 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335554 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279523950 4280690214 4280690214 4280229663 4284898610 4281676066 4282465318 4282465318 4282071077 4278782217 4279111182 4280690214 4280690214 4280166186 4279202705 4288135887 4294967295 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4285624432 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282992969 4287203464 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4284703065 4286873453 4286873453 4286873453 4285163355 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4284374101 4286873453 4286873453 4286873453 4285426528 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279523950 4280690214 4280690214 4280229663 4284898610 4286083411 4287728491 4287925869 4286149467 4279900438 4279111182 4280690214 4280690214 4280166186 4279202705 4284457654 4288595667 4288595667 4281830051 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4284045657 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282532418 4286150776 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4288649339 4289175679 4288452217 4286346851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286215782 4288518010 4289175679 4288715387 4286544485 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279523950 4280690214 4280690214 4280229663 4284898610 4286346326 4286939232 4287399523 4285820758 4279900438 4279111182 4280690214 4280690214 4280166186 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278680473 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278876310 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285695885 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287400843 4285229931 4282598211 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4283387727 4286611327 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4283072399 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4287860082 4287399523 4287136617 4286281571 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281317 4287991410 4287399523 4287202409 4286478691 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279523950 4280690214 4280690214 4280229663 4284898610 4286280533 4285689429 4285689429 4285491795 4279900438 4279111182 4280690214 4280690214 4280166186 4279202705 4281961636 4284129204 4284129204 4280582042 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006612 4278484893 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278353822 4278680473 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278745495 4278549658 4278549915 4278549915 4278549915 4278549915 4285565327 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4286742913 4284045657 4282927176 4282400832 4282400832 4282400832 4282532161 4283387727 4285032552 4287400843 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4282746004 4278549915 4278549915 4278549915 4278614937 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4286807659 4287596912 4286676323 4286610534 4286281571 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4286281317 4287794033 4286676323 4286545253 4286478691 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279523950 4280690214 4280690214 4280229663 4284898610 4283057717 4282729012 4282729012 4282597940 4279439889 4279111182 4280690214 4280690214 4280166186 4279202705 4288135887 4294967295 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137425 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4287466636 4287466636 4286742913 4287071878 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287006085 4286084983 4286479741 4287335050 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4286940292 4286808706 4287466636 4287466636 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4285492576 4285032017 4284834384 4284834640 4285163868 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4285229405 4285163604 4284834384 4284768847 4285360476 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279523950 4280690214 4280690214 4280492835 4279900438 4279505940 4279440147 4279440147 4279440147 4279440147 4279900698 4280690214 4280690214 4280166186 4279202705 4283669424 4291289062 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278615194 4278550171 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549916 4278549915 4278941332 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4287137671 4283782228 4282466625 4282466625 4284374365 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287400843 4284111193 4282466625 4282400832 4283979607 4287269257 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072146 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282335296 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279328116 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4279970350 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614937 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4285164138 4282400832 4282400832 4282400832 4282400832 4286150776 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4285821811 4282400832 4282400832 4282400832 4282400832 4285493103 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941846 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282204739 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335553 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4279596692 4279202705 4279202705 4279268497 4279925398 4279202705 4279202705 4279197559 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4279840051 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941588 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072403 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278811031 4278615194 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4278876310 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278419101 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615195 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4283716692 4282400832 4282400832 4282400832 4282400832 4284703330 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4284374365 4282400832 4282400832 4282400832 4282400832 4284045657 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279659396 4282335811 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335553 4279920510 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288924117 4290894819 4292405485 4279268497 4281173407 4291091684 4284982969 4279202705 4279202705 4279197559 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4279840051 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4280976286 4283669424 4283669424 4283669424 4282946731 4279202705 4279202705 4280582042 4279202705 4279202705 4279202705 4280647835 4279202705 4279202705 4283669424 4283669424 4283669424 4283669424 4281830051 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811287 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745751 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007124 4278354077 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4285427310 4282400832 4282400832 4282400832 4282400832 4286413948 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4286084983 4282400832 4282400832 4282400832 4282400832 4285756018 4282615446 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279659396 4282335811 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282335553 4279920510 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292208364 4279334034 4291289062 4286493892 4292142827 4282881195 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280377459 4281030243 4281030243 4281030243 4281030243 4281030243 4281030243 4280899685 4279398540 4279202705 4279202705 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4292274156 4289121238 4289121238 4288464338 4279728020 4279202705 4287873229 4286690757 4279202705 4283800753 4290763490 4279202705 4279202705 4294638845 4290369247 4293785079 4291288805 4288530130 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876311 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006867 4278680216 4278549915 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278549915 4278941845 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278614937 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4285499792 4287269514 4284374622 4282598211 4282795590 4284966759 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287466636 4287400843 4284703587 4282729797 4282664004 4284572001 4287400843 4282615446 4278354078 4278354078 4278354078 4278354078 4278419357 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279725447 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4280573038 4279790210 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4279202705 4291091684 4289121238 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280638829 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281682769 4279398540 4279202705 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4280450714 4293259507 4281304736 4292537070 4282421415 4279202705 4279202705 4282224294 4281698722 4291551719 4279859606 4281436065 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278353822 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278353822 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006869 4278811031 4278745752 4278745752 4278745752 4278745752 4284712592 4286417549 4286417549 4286219913 4286351756 4286417549 4286417549 4286417549 4286417293 4286482829 4286482829 4286482829 4286482829 4286482829 4286482829 4286482829 4286482829 4286482829 4286482829 4286482829 4286482829 4286417549 4286417549 4286417549 4286417549 4286417549 4286285706 4286220169 4286417549 4286417549 4282352019 4278745752 4278745752 4278745752 4278876310 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4292077035 4293522165 4292668399 4292537070 4292537070 4284720311 4279202705 4279202705 4279202705 4280638829 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281682769 4279398540 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4288530130 4281041822 4279202705 4279202705 4279202705 4279202705 4279202705 4285968320 4293456629 4288924117 4279202705 4279202705 4279202705 4279202705 4281698722 4291551719 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419101 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279528840 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280834407 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4293390836 4291420390 4281304736 4279202705 4279202705 4279202705 4279202705 4280779164 4294901503 4283669424 4279202705 4279202705 4279202705 4279202705 4281698722 4291551719 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278876311 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278811031 4279137425 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4281698722 4281698722 4281698722 4280976286 4279202705 4279202705 4279202705 4279202705 4280582042 4281698722 4280188056 4279202705 4279202705 4279728277 4281632930 4281698722 4280188056 4279202705 4279202705 4280122263 4281698722 4281698722 4281436065 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280516506 4281698722 4281698722 4281698722 4281698722 4280779164 4279202705 4279202705 4279202705 4279594375 4282400832 4282400832 4282400832 4282400832 4284374096 4284900181 4284900181 4284834388 4282992452 4282400832 4282400832 4282400832 4280899686 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288858580 4290172125 4291683048 4279268497 4279202705 4279202705 4279202705 4281698722 4291551719 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282880938 4291551719 4293785079 4292471278 4290237918 4279334034 4279202705 4279202705 4286099649 4293522165 4291551719 4286690757 4279202705 4279399826 4292339692 4291157476 4291091684 4293587958 4282946731 4279202705 4285114554 4293390836 4291551719 4291814377 4291814377 4279268497 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286822342 4290106589 4290106589 4290106589 4290106589 4291683048 4285902528 4279202705 4279202705 4279594375 4282400832 4282400832 4282400832 4282400832 4287004515 4288189040 4288320369 4286346845 4283716168 4282400832 4282400832 4282400832 4280899686 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285639870 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4282355623 4292471278 4279596692 4290040796 4285180091 4279202705 4279202705 4279202705 4281698722 4291551719 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4279202705 4279202705 4279202705 4280516506 4293193714 4280253592 4279202705 4279202705 4279202705 4279202705 4292011498 4283209645 4279202705 4281436065 4281632930 4279202705 4285114554 4287610572 4279202705 4279202705 4290894819 4282092965 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283406510 4287085000 4287085000 4289449689 4287150793 4279202705 4279202705 4279594375 4282400832 4282400832 4282400832 4282400832 4287596391 4287004769 4287399523 4285820758 4283716168 4282400832 4282400832 4282400832 4280899686 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4285377212 4294507516 4294507516 4294507516 4293128178 4279728277 4279202705 4287216329 4283078316 4279202705 4281107614 4289187031 4279202705 4279202705 4279202705 4280647835 4288661459 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4279202705 4279202705 4279202705 4287216329 4286953671 4279202705 4279202705 4279202705 4279202705 4279202705 4281830308 4292931057 4280910493 4279202705 4279202705 4279202705 4285114554 4287610572 4279202705 4279202705 4290632161 4282421415 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281632930 4284654519 4284654519 4287610572 4288135887 4279202705 4279202705 4279594375 4282400832 4282400832 4282400832 4282400832 4287596390 4286215001 4286347098 4285623380 4283716168 4282400832 4282400832 4282400832 4280899686 4279202705 4279202705 4287610572 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4279202705 4279202705 4279202705 4290500576 4282749610 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284654519 4291551719 4279596692 4279202705 4279202705 4285114554 4292011498 4288595667 4288858580 4293062386 4279596692 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287807437 4292077035 4292077035 4292077035 4292077035 4292471278 4284129204 4279202705 4279202705 4279594375 4282400832 4282400832 4282400832 4282400832 4285097297 4284110915 4284110915 4283979331 4283387462 4282400832 4282400832 4282400832 4280899686 4279202705 4285574333 4292931057 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4279202705 4279202705 4279202705 4286953671 4287479243 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288136144 4288661459 4279202705 4279202705 4285114554 4290172125 4284654519 4284129204 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279594375 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280899686 4279202705 4288135887 4294967295 4294967295 4283669424 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283669424 4279202705 4279202705 4279202705 4280384921 4293325043 4280779164 4279202705 4279202705 4279202705 4279334034 4284785848 4279202705 4279531155 4291354598 4283537839 4279202705 4285114554 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280384921 4280910493 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279333005 4281943883 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280247159 4279202705 4279990935 4280713371 4280713371 4279596692 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278876310 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282946731 4292537070 4294179065 4293259507 4290960355 4279334034 4279202705 4279202705 4285836991 4293981944 4292537070 4287085000 4279202705 4279202705 4290829026 4292865264 4292537070 4293390836 4283537839 4279202705 4283997875 4286559428 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287807437 4291026147 4290632161 4291157476 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279528840 4281943883 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280442738 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4280713371 4280713371 4280713371 4280188056 4279202705 4279202705 4279202705 4279202705 4279728020 4280188056 4279596692 4279202705 4279202705 4279202705 4280450714 4280713371 4279859606 4279202705 4279202705 4279202705 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4279202705 4279202705 4289778139 4281370272 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279528840 4281943883 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280442738 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292077035 4279202705 4279202705 4289581017 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279333262 4279529097 4279529097 4279529097 4279529097 4279529097 4279529097 4279463819 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292865264 4292537070 4292537070 4294179065 4292931057 4292537070 4284851640 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278615194 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278811031 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4279137682 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419358 4278811288 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202706 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941590 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615193 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278550171 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278550172 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278680473 4278549915 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278484636 4278549915 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941845 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876566 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278615195 4278549915 4278941845 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4278745752 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278941332 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615193 4279137425 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615195 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278549658 4278549658 4278549658 4278549658 4278549658 4278549658 4278419101 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615195 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615193 4279137425 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278614937 4278941332 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190594 4278528307 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278257417 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278256903 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4278999665 4279135111 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268497 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279531155 4289449689 4281173407 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283275181 4288201680 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4286493892 4280384921 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282027173 4279202705 4279202705 4280976286 4280122263 4279202705 4279596692 4281501601 4279202705 4279202705 4281895844 4279202705 4279202705 4281567393 4279728020 4279202705 4279202705 4281895844 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279859606 4286493892 4286559428 4281698722 4279202705 4279202705 4281895844 4280384921 4283932082 4286625221 4281238943 4279202705 4279202705 4279465363 4284851640 4286690757 4285245883 4288595667 4279202705 4279268497 4282946731 4279202705 4279202705 4281632930 4279728277 4279202705 4279202705 4284391861 4286887878 4280516506 4279202705 4279202705 4279202705 4282881195 4280122263 4285639870 4285968320 4280056727 4279202705 4279202705 4279728020 4284720311 4286559428 4281436065 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280647835 4285639870 4287085000 4283406510 4279202705 4279202705 4279202705 4282224294 4286559428 4287085000 4281041822 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293390836 4279202705 4279202705 4287216329 4284785848 4279202705 4283275181 4288727251 4279202705 4279202705 4291683048 4280319385 4279202705 4288201680 4284260532 4279202705 4280779164 4291223269 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4284523190 4285771199 4292733935 4279399826 4279202705 4286559428 4292996593 4290763490 4286362563 4291026147 4279202705 4279202705 4286953671 4289318360 4286099649 4293719286 4288595667 4279202705 4279990935 4292208364 4279202705 4279202705 4288530130 4284063411 4279202705 4279202705 4282618281 4291026147 4283603632 4279202705 4279202705 4279202705 4290040796 4293719286 4287741901 4289187031 4286231234 4279202705 4279202705 4289449689 4288136144 4285639870 4292668399 4280910493 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280779164 4292865264 4286690757 4285114554 4281830308 4279202705 4279202705 4284457654 4292339692 4285508541 4285048762 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278811031 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293587958 4281370272 4286887878 4288004558 4284260532 4279202705 4282815402 4289449689 4285311420 4282552744 4292405485 4279793813 4279202705 4287741901 4284983226 4288595667 4281895844 4290697697 4279202705 4279202705 4279202705 4281830051 4285180091 4279728277 4279202705 4279202705 4279202705 4284523190 4288858580 4289121238 4293719286 4280910493 4279202705 4286625221 4289186774 4279334034 4279202705 4282224294 4279202705 4279202705 4291485927 4281501601 4279202705 4284720311 4288595667 4279202705 4279728020 4292799728 4279202705 4279202705 4288595667 4284129204 4279202705 4279202705 4279202705 4288595667 4283669424 4279202705 4279202705 4279202705 4290106589 4283866289 4279202705 4283012524 4289252567 4279202705 4279202705 4293522165 4279202705 4279202705 4286756550 4285508541 4279202705 4279202705 4279202705 4284326325 4283340974 4279202705 4279202705 4279202705 4286953671 4285114554 4279202705 4279202705 4279202705 4279202705 4279202705 4291880169 4280713371 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293193714 4285377212 4290960355 4289318360 4283340974 4279202705 4281830308 4290829026 4289121238 4286165442 4293390836 4279268497 4279202705 4286822342 4286690757 4293587958 4285311420 4289778139 4279202705 4279202705 4279202705 4288792788 4294967295 4282421415 4279202705 4279202705 4280779164 4292865264 4284063411 4283932082 4292931057 4281436065 4279202705 4286625221 4285639870 4279202705 4279202705 4279202705 4279202705 4279202705 4291485927 4281501601 4279202705 4284720311 4288595667 4279202705 4279334034 4293390836 4279202705 4279202705 4289712346 4284129204 4279202705 4279202705 4279202705 4288595667 4283669424 4279202705 4279202705 4279202705 4290106589 4282684073 4279202705 4282684073 4289843675 4279202705 4279202705 4293522165 4279202705 4279202705 4286756550 4285508541 4279202705 4279202705 4279202705 4294770174 4292339692 4279202705 4279202705 4279202705 4286953671 4285114554 4279202705 4279202705 4279202705 4279202705 4279202705 4291880169 4280713371 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4287019207 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288924117 4294244602 4292537070 4293653494 4279728277 4279202705 4279268497 4292931057 4292733935 4293785079 4290369247 4279202705 4279202705 4282486952 4294441980 4292339692 4294441980 4285442749 4279202705 4279202705 4279202705 4280976286 4283734960 4279531155 4279202705 4279202705 4280122263 4292733935 4285508541 4287282122 4294244602 4281895844 4279202705 4286559428 4285574333 4279202705 4279202705 4279202705 4279202705 4279202705 4286953671 4289318360 4286099649 4293587958 4288464338 4279202705 4279202705 4291748585 4285968320 4290697697 4294179065 4284063411 4279202705 4279202705 4282618281 4291026147 4287873229 4280516506 4279202705 4279202705 4290040796 4282618281 4279202705 4282224294 4290303711 4279202705 4279202705 4289055446 4288136144 4285639870 4292537070 4280844957 4279202705 4279202705 4279202705 4282881195 4282158502 4279202705 4279202705 4279202705 4280844957 4292931057 4286493892 4285114554 4281830308 4279202705 4279202705 4284720311 4292142827 4285442749 4285048762 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4285771199 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280779164 4284260532 4281107614 4283932082 4279202705 4279202705 4279202705 4283143853 4281830308 4283537839 4281567393 4279202705 4279202705 4279202705 4285114554 4279990935 4285377212 4279596692 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282684073 4286887878 4285639870 4283209645 4279531155 4279202705 4280844957 4280384921 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4285048762 4286625221 4281173407 4281567393 4279202705 4279202705 4281895844 4286887878 4283472303 4281567393 4280582042 4279202705 4279202705 4284391861 4287085000 4287085000 4281567393 4279202705 4279202705 4281895844 4279399826 4279202705 4279334034 4283012524 4279202705 4279202705 4279728020 4284785848 4286559428 4281632930 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4286033856 4287610572 4283669424 4279202705 4279202705 4279202705 4282289831 4287019207 4287544779 4281173407 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278604648 4278941846 4279072403 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4292077035 4291091684 4291091684 4291091684 4291091684 4291091684 4283472303 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278419358 4278549915 4279006612 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4285377212 4282158502 4282158502 4282158502 4282158502 4282158502 4279728277 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278353822 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4291091684 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279531155 4279465363 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614938 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941846 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286559428 4281304736 4279202705 4279202705 4279202705 4279202705 4282749610 4285114554 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4283143853 4279202705 4279202705 4279202705 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278876310 4278811031 4278680473 4278680473 4278745752 4278811031 4278941589 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278876310 4278811031 4278745752 4278680473 4278745752 4278811031 4278941589 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4283143853 4279202705 4286165442 4283866289 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745753 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278680473 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4278811031 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278680473 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4278745752 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4285771199 4282684073 4289187031 4287282122 4282684073 4287282122 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287019207 4290566368 4290566368 4290566368 4290566368 4290566368 4290566368 4285574333 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280910493 4281173407 4281173407 4279925398 4279202705 4279202705 4279202705 4279202705 4279202705 4279531155 4279202705 4279202705 4279202705 4279334034 4279334034 4279202705 4279202705 4279465363 4279202705 4279202705 4280713371 4281173407 4281173407 4281173407 4280056727 4279202705 4279334034 4281173407 4281173407 4281173407 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285705662 4280910493 4279202705 4279202705 4279202705 4289187031 4285902528 4279202705 4280056727 4285705662 4279202705 4279202705 4279202705 4281501601 4285048762 4279202705 4279202705 4279202705 4282684073 4283340974 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4288267472 4281895844 4279202705 4279202705 4279202705 4279202705 4280844957 4288267472 4291091684 4283472303 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284194740 4291091684 4291091684 4291091684 4288267472 4279202705 4279202705 4290303711 4284851640 4279202705 4280779164 4284983226 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280056727 4279202705 4279202705 4279202705 4279202705 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728277 4282092965 4282027173 4279399826 4280976286 4282158502 4280976286 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4291748585 4291551719 4292799728 4284326325 4279202705 4279202705 4279596692 4289975260 4292011498 4281830051 4279202705 4279202705 4285639870 4285639870 4279202705 4279202705 4290697697 4280647835 4279202705 4291091684 4292077035 4291551719 4291551719 4287085000 4279202705 4280188056 4294638845 4292077035 4292077035 4293850615 4282486952 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4293916408 4286625221 4279202705 4279202705 4279202705 4292537070 4293522165 4279596692 4281698722 4291551719 4279202705 4279202705 4279202705 4287741901 4293062386 4279202705 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291485927 4286428099 4293390836 4279793813 4279202705 4279202705 4280319385 4292668399 4286033856 4282158502 4279728277 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279925398 4282158502 4292208364 4284129204 4280910493 4279202705 4279202705 4294047737 4292471278 4279268497 4283143853 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278614938 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285968320 4290960355 4279202705 4279202705 4279990935 4289581017 4293981944 4285048762 4279202705 4279202705 4279202705 4279202705 4279202705 4291683048 4291091684 4292077035 4293719286 4293522165 4291091684 4293325043 4282355623 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4280188056 4279202705 4282552744 4289909468 4279202705 4279202705 4285705662 4288595667 4284654519 4290435040 4279202705 4279202705 4286625221 4286625221 4279202705 4279202705 4292077035 4281173407 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4279202705 4279202705 4286493892 4287282122 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282946731 4293456629 4291091684 4279202705 4279202705 4279202705 4292537070 4290435040 4284982969 4281698722 4291551719 4279202705 4279202705 4279202705 4292339949 4293456629 4281698722 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4283603632 4290829026 4279202705 4288858580 4286165442 4279202705 4279202705 4288989909 4286756550 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291551719 4281698722 4279202705 4279202705 4279202705 4294047737 4290369247 4283669424 4283143853 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289975260 4282880938 4279202705 4281830051 4292339949 4286953671 4285180091 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4293522165 4279202705 4279202705 4291551719 4282158502 4279202705 4288595667 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4280188056 4279202705 4282224294 4290303711 4279202705 4279202705 4292865264 4281041822 4279334034 4292405485 4281830308 4279202705 4286625221 4286625221 4284523190 4280779164 4292077035 4281173407 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4280188056 4294507516 4291091684 4291091684 4294047737 4282881195 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287544779 4286559428 4293390836 4280056727 4279202705 4279202705 4292537070 4283669424 4291617256 4281698722 4291551719 4279202705 4279202705 4281173407 4292799728 4287413450 4286099649 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4288989909 4284063411 4279202705 4282092965 4291420390 4279202705 4279399826 4293916408 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291551719 4281698722 4279202705 4279202705 4279202705 4294047737 4283537839 4290435040 4283143853 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4282684073 4284523190 4293062386 4283603632 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4293522165 4279202705 4279202705 4291091684 4281698722 4279202705 4288595667 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4288530130 4288135887 4290632161 4286690757 4279202705 4280647835 4292142827 4279202705 4279202705 4288136144 4285048762 4279202705 4286625221 4286625221 4289581017 4283669424 4292077035 4281173407 4279202705 4291091684 4294179065 4290500576 4279202705 4279202705 4279202705 4280188056 4293390836 4290172125 4288595667 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4292208364 4281895844 4289318360 4284194740 4279202705 4279202705 4292537070 4280713371 4291223269 4284983226 4291551719 4279202705 4279202705 4285771199 4288333009 4282881195 4290632161 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4287873229 4284982969 4279202705 4282946731 4290303711 4279202705 4279728020 4293522165 4279202705 4285508541 4291551719 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291551719 4281698722 4279202705 4279202705 4279202705 4294047737 4279202705 4292339692 4285508541 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549658 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288858580 4291289062 4291814377 4281173407 4279202705 4279465363 4290369247 4285574333 4279202705 4279202705 4279202705 4279202705 4279202705 4293456629 4279202705 4279202705 4282749610 4279465363 4279202705 4288530130 4284063411 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4285771199 4285114554 4282880938 4279268497 4279202705 4279202705 4292471278 4281107614 4279334034 4292339949 4281501601 4279202705 4286625221 4286625221 4289581017 4283669424 4292077035 4281173407 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4280450714 4292996593 4281830051 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280976286 4294573308 4293522165 4293850615 4288661459 4279202705 4279202705 4292537070 4280713371 4284391861 4291814377 4291551719 4279202705 4279202705 4290369247 4293719286 4293522165 4294244602 4279728277 4279202705 4286099649 4287085000 4279202705 4279202705 4279202705 4279202705 4279202705 4281830308 4292274156 4279334034 4290566368 4284194740 4279202705 4279662484 4293522165 4279202705 4279793813 4286362563 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291551719 4281698722 4279202705 4279202705 4279202705 4294047737 4279202705 4285574333 4292208364 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279859606 4283866289 4279662484 4279202705 4279202705 4279202705 4283012524 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4281107614 4279728020 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4285771199 4288792788 4284851640 4290237918 4279202705 4279202705 4286428099 4286953671 4289909468 4283932082 4292339949 4280910493 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4279202705 4283734960 4291945706 4279596692 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4288136144 4279202705 4280450714 4292931057 4279202705 4279202705 4292537070 4280713371 4279399826 4293193714 4291551719 4279202705 4279728277 4293587958 4279596692 4279202705 4289646810 4283734960 4279202705 4286099649 4290566368 4286099649 4286099649 4285442749 4279334034 4279202705 4279202705 4289186774 4290237918 4291551719 4279268497 4279202705 4279202705 4292142827 4286690757 4286099649 4291617256 4285245883 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281830051 4286099649 4293062386 4287479243 4284129204 4279202705 4279202705 4294047737 4279202705 4279793813 4293850615 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941845 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4291289062 4279793813 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4289843675 4291683048 4281567393 4279202705 4279202705 4282027173 4293390836 4292733935 4293062386 4291289062 4279202705 4279202705 4291091684 4292931057 4292537070 4292537070 4287479243 4279202705 4279793813 4291289062 4279202705 4279202705 4288201680 4285114554 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281830051 4280647835 4279202705 4279202705 4283078316 4279202705 4279202705 4282946731 4279268497 4279202705 4283734960 4285377212 4279202705 4279465363 4282946731 4279202705 4279202705 4281304736 4280976286 4279202705 4282684073 4287085000 4287085000 4287085000 4286428099 4279465363 4279202705 4279202705 4279334034 4284326325 4279662484 4279202705 4279202705 4279202705 4281370272 4286493892 4287085000 4284523190 4279531155 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282355623 4287085000 4287085000 4287085000 4285048762 4279202705 4279202705 4283078316 4279202705 4279202705 4284194740 4284654519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282289831 4279728277 4279202705 4279202705 4279202705 4279202705 4280384921 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4284391861 4286625221 4284982969 4279859606 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279399826 4279202705 4279202705 4279202705 4279202705 4279925398 4279662484 4280122263 4279465363 4279202705 4279202705 4280319385 4280713371 4280713371 4280713371 4279793813 4279202705 4279202705 4279334034 4279202705 4279202705 4279202705 4279334034 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278278252 4278354078 4278354078 4278354078 4278354078 4278549658 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4283143853 4279202705 4279202705 4279202705 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4283866289 4286099649 4288989909 4293456629 4288727251 4282486952 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278277996 4278484893 4278615194 4278811287 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4283143853 4279202705 4282881195 4281501601 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279925398 4285311420 4292865264 4292011498 4280779164 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4283143853 4279202705 4287610572 4285114554 4279202705 4285114554 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279859606 4285180091 4291288805 4292339692 4286099649 4279399826 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4292799728 4292077035 4293587958 4293193714 4292077035 4293193714 4288135887 4279202705 4279202705 4279202705 4279202705 4279202705 4288333009 4292077035 4293456629 4288989909 4282815402 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281961636 4286099649 4286099649 4285836991 4279596692 4279202705 4281698722 4279793813 4279202705 4279202705 4282421415 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4284457654 4286033856 4280122263 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280319385 4286034113 4286099649 4286099649 4285442749 4279399826 4279202705 4281895844 4279465363 4279202705 4279202705 4282224294 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279793813 4285311420 4286099649 4286099649 4284260532 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279925398 4286033856 4286099649 4282224294 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4285771199 4286099649 4286099649 4284851640 4279465363 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279334034 4285311420 4286099649 4286099649 4285377212 4279925398 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281567393 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279662484 4286099649 4286099649 4286099649 4281830051 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4280582042 4281173407 4281173407 4281173407 4281173407 4281173407 4281173407 4280319385 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4281173407 4279793813 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4291026147 4286625221 4286296771 4279728277 4279202705 4289121238 4283669424 4279202705 4279202705 4294047737 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279990935 4292077035 4289384152 4287019207 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4287610572 4279202705 4279202705 4279202705 4279202705 4279202705 4285574333 4291091684 4286625221 4286625221 4292931057 4282092965 4279202705 4290500576 4282618281 4279202705 4279662484 4293456629 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285311420 4290829026 4286625221 4286625221 4292865264 4280976286 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4286493892 4290829026 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4286165442 4286625221 4286625221 4291551719 4283472303 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279465363 4285902528 4286625221 4286625221 4290829026 4285442749 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284654519 4279202705 4285180091 4279399826 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4293981944 4286625221 4286625221 4282158502 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4287347658 4279202705 4279202705 4279202705 4279202705 4288858580 4284391861 4279202705 4279728020 4293785079 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289318360 4287085000 4279202705 4279202705 4279202705 4279202705 4279793813 4279531155 4280319385 4282224294 4279334034 4279202705 4279202705 4279202705 4280450714 4282289831 4283143853 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4285639870 4288070351 4280188056 4280188056 4291289062 4282158502 4279202705 4290172125 4283406510 4279202705 4280450714 4293128178 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287085000 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284588983 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287085000 4286034113 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284654519 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4293062386 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4281764515 4290040796 4289843675 4281304736 4279202705 4279334034 4286493892 4284063411 4279202705 4279202705 4279202705 4279202705 4279202705 4286756550 4291485927 4291420390 4287938766 4290435040 4291551719 4290435040 4280516506 4279202705 4279202705 4279202705 4285639870 4289318360 4283669424 4281961636 4279202705 4279202705 4284457654 4289712346 4279202705 4284785848 4289384152 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4293062386 4279268497 4279202705 4279202705 4279202705 4279202705 4285377212 4290829026 4292931057 4290960355 4288595667 4279202705 4279202705 4283406510 4292602607 4290435040 4293062386 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4283078316 4292996593 4293062386 4293062386 4294441980 4282158502 4279202705 4285442749 4288727251 4279202705 4285771199 4288398801 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287085000 4286099649 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282027173 4283669424 4283669424 4290369247 4284063411 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283209645 4283669424 4291683048 4284523190 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4284654519 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280188056 4293587958 4283669424 4283143853 4279662484 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4288792788 4287085000 4287807437 4287807437 4281238943 4291289062 4289318360 4280056727 4279202705 4279202705 4279202705 4279202705 4279202705 4293390836 4281698722 4282618281 4293062386 4286099649 4281698722 4289581017 4283997875 4279202705 4279202705 4279202705 4283406510 4289581017 4289581017 4293128178 4281567393 4279202705 4279596692 4293325043 4280450714 4290894819 4283209645 4279202705 4279202705 4279202705 4279202705 4279202705 4283143853 4290303711 4279202705 4284851640 4287085000 4282158502 4279202705 4285639870 4290237918 4279990935 4279531155 4292799728 4279202705 4279202705 4290040796 4282946731 4279202705 4286296771 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290960355 4282158502 4279202705 4279990935 4293390836 4279859606 4291880169 4282224294 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287085000 4286099649 4282355623 4279793813 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281698722 4293193714 4289121238 4289121238 4287807437 4279925398 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280056727 4288727251 4289121238 4293916408 4282815402 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4288595667 4289843675 4287085000 4294047737 4282092965 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279793813 4289581017 4289581017 4291288805 4287479243 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876310 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4283143853 4284129204 4292602607 4293128178 4284588983 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293522165 4279202705 4279202705 4291091684 4281698722 4279202705 4288595667 4284129204 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4289581017 4283078316 4279202705 4279202705 4287873229 4288201680 4292668399 4279268497 4279202705 4279202705 4279202705 4279202705 4279202705 4283143853 4290106589 4279202705 4283932082 4291091684 4285114554 4279202705 4285639870 4286625221 4279202705 4279202705 4293259507 4279202705 4279202705 4290566368 4282158502 4279202705 4283209645 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290763490 4282158502 4279202705 4279202705 4288858580 4288135887 4291814377 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286099649 4287085000 4279202705 4279202705 4291091684 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287085000 4286099649 4289581017 4283143853 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283143853 4290106589 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287544779 4286034113 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283275181 4286099649 4286099649 4293916408 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284129204 4289055446 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278941589 4279202705 4279202705 4279202705 4279202705 4279202705 4290106589 4284654519 4285508541 4292931057 4282881195 4281173407 4281173407 4279531155 4279202705 4279202705 4279202705 4279202705 4279202705 4293522165 4279202705 4279202705 4287544779 4280450714 4279202705 4288595667 4284129204 4279202705 4279202705 4280516506 4285180091 4281238943 4281173407 4290237918 4282946731 4279202705 4279202705 4281698722 4294967295 4286625221 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281632930 4291880169 4281436065 4281370272 4291223269 4283734960 4279202705 4285639870 4286625221 4279202705 4279202705 4293390836 4279202705 4279202705 4288070351 4286559428 4281436065 4291026147 4289581017 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4290763490 4282158502 4279202705 4279202705 4282684073 4294967295 4285639870 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286034113 4288135887 4281173407 4281173407 4291551719 4281632930 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281041822 4288135887 4287216329 4290237918 4283143853 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4283143853 4290697697 4281173407 4281173407 4281041822 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280713371 4281173407 4281173407 4288135887 4286034113 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4293062386 4280188056 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284982969 4282027173 4281173407 4285508541 4288924117 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4288070351 4292077035 4292077035 4292077035 4292077035 4292077035 4292077035 4283734960 4279202705 4279202705 4279202705 4279202705 4279202705 4287479243 4279202705 4279202705 4279202705 4279202705 4279202705 4284982969 4281698722 4279202705 4279202705 4279793813 4288333009 4291485927 4291551719 4289646810 4279925398 4279202705 4279202705 4279202705 4287347658 4280450714 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4287019207 4291289062 4291485927 4288004558 4279399826 4279202705 4282158502 4282881195 4279202705 4279202705 4287085000 4279202705 4279202705 4280450714 4289186774 4291223269 4285705662 4284654519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279728020 4290172125 4280450714 4279202705 4279202705 4279202705 4287807437 4279990935 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4281501601 4290763490 4291551719 4291551719 4289712346 4279399826 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280976286 4291420390 4291551719 4291551719 4291157476 4280910493 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4282289831 4291551719 4291551719 4291551719 4291420390 4280976286 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279596692 4290500576 4291551719 4291551719 4290829026 4281698722 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4286953671 4279531155 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4284851640 4290960355 4291551719 4291026147 4283209645 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4278680473 4278876310 4279006868 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4278680473 4278811031 4278941589 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278484636 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278615194 4278745752 4278876310 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278680473 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278549915 4278680473 4278876310 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202704 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279267982 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333520 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279268241 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279268240 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279267982 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278865764 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4278680473 4278811031 4278941589 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278615194 4278745752 4278941589 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282008905 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282270018 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282204996 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074441 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943883 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281617491 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281682770 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281748048 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281813325 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943882 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278257160 4279134339 4279134339 4279134339 4279134339 4278677386 4278807944 4279134339 4279134339 4279134339 4279134339 4279069059 4278938502 4279003525 4279134339 4279134339 4279134339 4279134339 4279069316 4278547085 4279069060 4279134339 4279134339 4279134339 4279134339 4279134339 4279134339 4279134339 4279134339 4279134339 4279134339 4279134339 4278350735 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278350991 4278742665 4279134339 4279134339 4279201933 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278549915 4278680473 4278876310 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484636 4278680473 4278811031 4279006868 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282008905 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282270018 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282204996 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074441 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943883 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281617491 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281682770 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281748048 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281813325 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943882 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278324753 4279202705 4279202705 4279202705 4279202705 4278550171 4279202705 4279202705 4279202705 4279202705 4278941846 4278419357 4278354078 4278354078 4278615193 4279202961 4279202705 4279202705 4279202705 4278745752 4279007125 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278419101 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278876311 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278419357 4278354078 4278354078 4278354078 4278484636 4278615194 4278745752 4278941589 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615194 4278354078 4278354078 4278354078 4278419357 4278549915 4278745752 4278876310 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282400832 4281677108 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281216558 4282335039 4282400832 4282008905 4282400832 4282400832 4281808695 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4282335039 4282400832 4282270018 4282400832 4282400832 4281874488 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4282137659 4282400832 4282400832 4282204996 4282400832 4281874488 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4282137659 4282400832 4282400832 4282074441 4282400832 4281874488 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4282137659 4282400832 4282400832 4281943883 4282400832 4282006074 4281216557 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281940280 4282400832 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281874488 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4282137659 4282400832 4282400832 4281617491 4282400832 4282203453 4281479730 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281282350 4282400832 4282400832 4281682770 4282400832 4282269246 4281545522 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281282350 4282335039 4282400832 4281748048 4282400832 4282269246 4281611316 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281282350 4282335039 4282400832 4281813325 4282400832 4282335039 4281677108 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4282400832 4282400832 4281943882 4282400832 4282400832 4281742901 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4281150764 4282335039 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279071890 4278549658 4279202705 4279202705 4279202705 4279072147 4278353822 4278354078 4278354078 4278354078 4278354078 4278745751 4279202705 4279202705 4279202705 4278941590 4278745495 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549658 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278811031 4279006868 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278811031 4278941589 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282335039 4281808695 4281545522 4280953385 4280953385 4280953385 4280953385 4281084971 4282532417 4282729797 4282400832 4282008905 4282400832 4282400832 4281874488 4281677109 4280953385 4280953385 4280953385 4280953385 4280953385 4282335039 4282795590 4282400832 4282270018 4282400832 4282400832 4281940281 4281808695 4280953385 4280953385 4280953385 4280953385 4280953385 4282006073 4282861383 4282400832 4282400832 4282204996 4282400832 4281940281 4281808695 4280953385 4280953385 4280953385 4280953385 4280953385 4282006073 4282861383 4282400832 4282400832 4282074441 4282400832 4281940281 4281808695 4280953385 4280953385 4280953385 4280953385 4280953385 4282006073 4282861383 4282400832 4282400832 4281943883 4282400832 4282006074 4281808695 4281019178 4280953385 4280953385 4280953385 4280953385 4281742902 4282861383 4282466625 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281940281 4281808695 4280953385 4280953385 4280953385 4280953385 4280953385 4282006073 4282861383 4282400832 4282400832 4281617491 4282400832 4282269246 4281808695 4281348143 4280953385 4280953385 4280953385 4280953385 4281150764 4282664004 4282664004 4282400832 4281682770 4282400832 4282269246 4281808695 4281413936 4280953385 4280953385 4280953385 4280953385 4281084971 4282664004 4282664004 4282400832 4281748048 4282400832 4282335039 4281808695 4281413937 4280953385 4280953385 4280953385 4280953385 4281084971 4282598211 4282729797 4282400832 4281813325 4282400832 4282335039 4281808695 4281545522 4280953385 4280953385 4280953385 4280953385 4281019179 4282532418 4282729797 4282400832 4281943882 4282400832 4282400832 4281808695 4281611315 4280953385 4280953385 4280953385 4280953385 4280953385 4282400832 4282729797 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278745751 4279202705 4279202705 4279202705 4278876311 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279072147 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278745752 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282335039 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4279242768 4282861383 4282729797 4282400832 4282008905 4282400832 4282400832 4281874488 4281808695 4278190080 4278190080 4278190080 4278190080 4278453252 4282861383 4282795590 4282400832 4282270018 4282400832 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282204996 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282074441 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281943883 4282400832 4282006074 4281808695 4279703319 4278190080 4278190080 4278190080 4278190080 4282466625 4282861383 4282466625 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281617491 4282400832 4282269246 4281808695 4281348144 4278190080 4278190080 4278190080 4278190080 4280756007 4282861383 4282664004 4282400832 4281682770 4282400832 4282269246 4281808695 4281545523 4278190080 4278190080 4278190080 4278190080 4280361249 4282861383 4282664004 4282400832 4281748048 4282400832 4282335039 4281808695 4281677109 4278190080 4278190080 4278190080 4278190080 4279966491 4282861383 4282729797 4282400832 4281813325 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279440147 4282861383 4282729797 4282400832 4281943882 4282400832 4282400832 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4278979596 4282861383 4282729797 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278745752 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278549916 4279202705 4279202705 4279202705 4279006612 4278615194 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278550171 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282335039 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4279242768 4282861383 4282729797 4282400832 4282008905 4282400832 4282400832 4281874488 4281808695 4278190080 4278190080 4278190080 4278190080 4278453252 4282861383 4282795590 4282400832 4282270018 4282400832 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282204996 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282074441 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281943883 4282400832 4282006074 4281808695 4279703319 4278190080 4278190080 4278190080 4278190080 4282466625 4282861383 4282466625 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281617491 4282400832 4282269246 4281808695 4281348144 4278190080 4278190080 4278190080 4278190080 4280756007 4282861383 4282664004 4282400832 4281682770 4282400832 4282269246 4281808695 4281545523 4278190080 4278190080 4278190080 4278190080 4280361249 4282861383 4282664004 4282400832 4281748048 4282400832 4282335039 4281808695 4281677109 4278190080 4278190080 4278190080 4278190080 4279966491 4282861383 4282729797 4282400832 4281813325 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279440147 4282861383 4282729797 4282400832 4281943882 4282400832 4282400832 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4278979596 4282861383 4282729797 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278615195 4279202705 4279202705 4279202705 4279137426 4278419357 4278354078 4278354078 4278354078 4278354078 4278876566 4279202705 4279202705 4279202705 4278876309 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4279007124 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282335039 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4279242768 4282861383 4282729797 4282400832 4282008905 4282400832 4282400832 4281874488 4281808695 4278190080 4278190080 4278190080 4278190080 4278453252 4282861383 4282795590 4282400832 4282270018 4282400832 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282204996 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282074441 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281943883 4282400832 4282006074 4281808695 4279703319 4278190080 4278190080 4278190080 4278190080 4282466625 4282861383 4282466625 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281617491 4282400832 4282269246 4281808695 4281348144 4278190080 4278190080 4278190080 4278190080 4280756007 4282861383 4282664004 4282400832 4281682770 4282400832 4282269246 4281808695 4281545523 4278190080 4278190080 4278190080 4278190080 4280361249 4282861383 4282664004 4282400832 4281748048 4282400832 4282335039 4281808695 4281677109 4278190080 4278190080 4278190080 4278190080 4279966491 4282861383 4282729797 4282400832 4281813325 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279440147 4282861383 4282729797 4282400832 4281943882 4282400832 4282400832 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4278979596 4282861383 4282729797 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278550171 4279202961 4279202705 4279202705 4279202705 4279006868 4278484636 4278354078 4278419358 4278811288 4279202961 4279202705 4279202705 4279202705 4278680473 4279006868 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278680473 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282335039 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4279242768 4282861383 4282729797 4282400832 4282008905 4282400832 4282400832 4281874488 4281808695 4278190080 4278190080 4278190080 4278190080 4278453252 4282861383 4282795590 4282400832 4282270018 4282400832 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282204996 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282074441 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281943883 4282400832 4282006074 4281808695 4279703319 4278190080 4278190080 4278190080 4278190080 4282466625 4282861383 4282466625 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281617491 4282400832 4282269246 4281808695 4281348144 4278190080 4278190080 4278190080 4278190080 4280756007 4282861383 4282664004 4282400832 4281682770 4282400832 4282269246 4281808695 4281545523 4278190080 4278190080 4278190080 4278190080 4280361249 4282861383 4282664004 4282400832 4281748048 4282400832 4282335039 4281808695 4281677109 4278190080 4278190080 4278190080 4278190080 4279966491 4282861383 4282729797 4282400832 4281813325 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279440147 4282861383 4282729797 4282400832 4281943882 4282400832 4282400832 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4278979596 4282861383 4282729797 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278811031 4278745752 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279006868 4278549915 4279202961 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278876310 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278484637 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282335039 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4279242768 4282861383 4282729797 4282400832 4282008905 4282400832 4282400832 4281874488 4281808695 4278190080 4278190080 4278190080 4278190080 4278453252 4282861383 4282795590 4282400832 4282270018 4282400832 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282204996 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4282074441 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281943883 4282400832 4282006074 4281808695 4279703319 4278190080 4278190080 4278190080 4278190080 4282466625 4282861383 4282466625 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281940281 4281808695 4278782217 4278190080 4278190080 4278190080 4278190080 4282729797 4282861383 4282400832 4282400832 4281617491 4282400832 4282269246 4281808695 4281348144 4278190080 4278190080 4278190080 4278190080 4280756007 4282861383 4282664004 4282400832 4281682770 4282400832 4282269246 4281808695 4281545523 4278190080 4278190080 4278190080 4278190080 4280361249 4282861383 4282664004 4282400832 4281748048 4282400832 4282335039 4281808695 4281677109 4278190080 4278190080 4278190080 4278190080 4279966491 4282861383 4282729797 4282400832 4281813325 4282400832 4282335039 4281808695 4281742902 4278190080 4278190080 4278190080 4278190080 4279440147 4282861383 4282729797 4282400832 4281943882 4282400832 4282400832 4281808695 4281808695 4278190080 4278190080 4278190080 4278190080 4278979596 4282861383 4282729797 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278615451 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278549915 4279006867 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4278811031 4278419357 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278549915 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282335039 4281808695 4282861383 4284045657 4284045657 4284045657 4284045657 4283979864 4283190348 4282729797 4282400832 4282008905 4282400832 4282400832 4281874488 4282664004 4284045657 4284045657 4284045657 4284045657 4283979864 4283256141 4282795590 4282400832 4282270018 4282400832 4282400832 4281940281 4282335039 4283979864 4284045657 4284045657 4284045657 4284045657 4283453520 4282861383 4282400832 4282400832 4282204996 4282400832 4281940281 4282335039 4283979864 4284045657 4284045657 4284045657 4284045657 4283453520 4282861383 4282400832 4282400832 4282074441 4282400832 4281940281 4282335039 4283979864 4284045657 4284045657 4284045657 4284045657 4283453520 4282861383 4282400832 4282400832 4281943883 4282400832 4282006074 4282071867 4283914071 4284045657 4284045657 4284045657 4284045657 4283585106 4282861383 4282466625 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4281940281 4282335039 4283979864 4284045657 4284045657 4284045657 4284045657 4283453520 4282861383 4282400832 4282400832 4281617491 4282400832 4282269246 4281874488 4283387727 4284045657 4284045657 4284045657 4284045657 4283914071 4282927176 4282664004 4282400832 4281682770 4282400832 4282269246 4281874488 4283256141 4283979864 4283979864 4283979864 4283979864 4283914071 4283058762 4282664004 4282400832 4281748048 4282400832 4282335039 4281808695 4282992969 4284045657 4284045657 4284045657 4284045657 4283914071 4283124555 4282729797 4282400832 4281813325 4282400832 4282335039 4281808695 4282992969 4284045657 4284045657 4284045657 4284045657 4283979864 4283124555 4282729797 4282400832 4281943882 4282400832 4282400832 4281808695 4282795590 4284045657 4284045657 4284045657 4284045657 4283979864 4283190348 4282729797 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278549915 4278941846 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072146 4278549915 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279072147 4278549915 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278354078 4278419357 4278811031 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282400832 4282861383 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4282927176 4282400832 4282008905 4282400832 4282400832 4282598211 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283058762 4282400832 4282270018 4282400832 4282400832 4282466625 4283782485 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283256141 4282400832 4282400832 4282204996 4282400832 4282466625 4283782485 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283256141 4282400832 4282400832 4282074441 4282400832 4282466625 4283782485 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283256141 4282400832 4282400832 4281943883 4282400832 4282400832 4283782485 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283387727 4282400832 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4282466625 4283782485 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283256141 4282400832 4282400832 4281617491 4282400832 4282269246 4283190348 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283716692 4282729797 4282400832 4281682770 4282400832 4282335039 4283124555 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283782485 4282795590 4282400832 4281748048 4282400832 4282335039 4282992969 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283782485 4282795590 4282400832 4281813325 4282400832 4282335039 4282861383 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283782485 4282927176 4282400832 4281943882 4282400832 4282400832 4282664004 4283848278 4283848278 4283848278 4283848278 4283848278 4283848278 4283782485 4282992969 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279137426 4278615194 4278615194 4279007125 4279137682 4279202705 4279202706 4279006868 4278811031 4278550171 4279006869 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4278941589 4278745752 4278549915 4278419357 4278354078 4278484636 4278614937 4278811031 4279072147 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282008905 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282270018 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282204996 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074441 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943883 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281617491 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281682770 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281748048 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281813325 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943882 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279007125 4278680473 4278615451 4278484636 4278550171 4278614938 4278811031 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202961 4279137426 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279789954 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282008905 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282270018 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282204996 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074441 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943883 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4280116602 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4280703851 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281617491 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281682770 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281748048 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281813325 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281943882 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282074183 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202704 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333519 4279333519 4279333519 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279267982 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333262 4279333519 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 4279202705 0 0 0 0 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 8/19/2009 13:54'!
analogPin0
	^[ (arduino analogPin: 0) value]
		on: Error
		do: [-1]! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 8/19/2009 13:54'!
analogPin1
	^[ (arduino analogPin: 1) value]
		on: Error
		do: [-1]! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 8/19/2009 13:54'!
analogPin2
	^[ (arduino analogPin: 2) value]
		on: Error
		do: [-1]! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 8/19/2009 13:54'!
analogPin3
	^[ (arduino analogPin: 3) value]
		on: Error
		do: [-1]! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 8/19/2009 13:54'!
analogPin4
	^[ (arduino analogPin: 4) value]
		on: Error
		do: [-1]! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 8/19/2009 13:53'!
analogPin5
	^ [(arduino analogPin: 5) value]
		on: Error
		do: [-1]! !

!ArduinoMorph methodsFor: 'accessing' stamp: 'Richo 9/21/2009 13:36'!
availableSerialPortsForUnix

	| pattern1 pattern2 |
	pattern1 := 'ttyS*'.
	pattern2 := 'ttyUSB*'.
	 ^(FileDirectory on: '/dev') fileNames
		select: [:e | (pattern1 match: e)
				or: [pattern2 match: e]]
		thenCollect: [:e |( '/dev/' , e)  asSymbol]! !

!ArduinoMorph methodsFor: 'accessing' stamp: 'Richo 9/21/2009 13:23'!
availableSerialPortsForWindows
"It should return only the list of available serial ports. Since I don't know how to do it in windows, I just return a list from COM1 to COM9"
 ^ (1 to: 9)
					collect: [:n | ('com' , n asString) asSymbol]! !

!ArduinoMorph methodsFor: 'connection' stamp: 'Richo 9/21/2009 13:25'!
connect
	arduino connectOnPort: portName.
"	arduino isConnected
		ifTrue: [0 
				to: 5
				do: [:i | (arduino analogPin: i) activate]]"! !

!ArduinoMorph methodsFor: 'initialize-release' stamp: 'Richo 8/24/2009 14:41'!
delete
self isConnected ifTrue: [self disconnect].
super delete.! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:06'!
digitalPin10
^[(arduino digitalPin: 10) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:20'!
digitalPin10:  aBoolean
[(arduino digitalPin:10) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:30'!
digitalPin10Mode
^self digitalPinModeAt: 10! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:26'!
digitalPin10Mode: aSymbol 
[self digitalPin: 10 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:06'!
digitalPin11
^[(arduino digitalPin: 11) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:20'!
digitalPin11:  aBoolean
[(arduino digitalPin: 11) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 16:26'!
digitalPin11Mode
^self symbolFromPinMode: (arduino digitalPin: 11) mode! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin11Mode: aSymbol 
[self digitalPin: 11 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:06'!
digitalPin12
^[(arduino digitalPin: 12) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:21'!
digitalPin12:  aBoolean
[(arduino digitalPin: 12) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin12Mode
^self digitalPinModeAt: 12! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin12Mode: aSymbol 
[self digitalPin: 12 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:06'!
digitalPin13
^[(arduino digitalPin: 13) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:21'!
digitalPin13:  aBoolean
[(arduino digitalPin: 13) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin13Mode
^self digitalPinModeAt: 13! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin13Mode: aSymbol 
[self digitalPin: 13 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 16:40'!
digitalPin2

^[(arduino digitalPin: 2) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:21'!
digitalPin2:  aBoolean
[(arduino digitalPin: 2) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin2Mode
^self digitalPinModeAt: 2! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin2Mode: aSymbol 
[self digitalPin: 2 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:06'!
digitalPin3
^[(arduino digitalPin: 3) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:21'!
digitalPin3:  aBoolean
[(arduino digitalPin: 3) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin3Mode
^self digitalPinModeAt: 3! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin3Mode: aSymbol 
[self digitalPin: 3 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:07'!
digitalPin4
^[(arduino digitalPin: 4) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:22'!
digitalPin4:  aBoolean
[(arduino digitalPin: 4) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin4Mode
^self digitalPinModeAt: 4! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin4Mode: aSymbol 
[self digitalPin:4 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:07'!
digitalPin5
^[(arduino digitalPin: 5) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:22'!
digitalPin5:  aBoolean
[(arduino digitalPin: 5) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin5Mode
^self digitalPinModeAt: 5! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin5Mode: aSymbol 
[self digitalPin:5 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:07'!
digitalPin6
^[(arduino digitalPin: 6) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:22'!
digitalPin6: aBoolean
[(arduino digitalPin: 6) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin6Mode
^self digitalPinModeAt: 6! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin6Mode: aSymbol 
[self digitalPin:6 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:07'!
digitalPin7
^[(arduino digitalPin: 7) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:23'!
digitalPin7:  aBoolean
[(arduino digitalPin: 7) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin7Mode
^self digitalPinModeAt: 7! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin7Mode: aSymbol 
[self digitalPin:7 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:07'!
digitalPin8
^[(arduino digitalPin: 8) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:23'!
digitalPin8:  aBoolean
[(arduino digitalPin: 8) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin8Mode
^self digitalPinModeAt: 8! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin8Mode: aSymbol 
[self digitalPin:8 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:07'!
digitalPin9
^[(arduino digitalPin: 9) value = 1] on: Error do: [false]! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 8/19/2009 14:23'!
digitalPin9:  aBoolean
[(arduino digitalPin: 9) value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:31'!
digitalPin9Mode
^self digitalPinModeAt: 9! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:32'!
digitalPin9Mode: aSymbol 
[self digitalPin:9 mode: aSymbol] on: Error do: []! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:45'!
digitalPin: pinNumber mode: aSymbol 

(#(#output. #input) includes: (self digitalPinModeAt: pinNumber))
ifFalse: [^self].

	(arduino  digitalPin: pinNumber) mode: (self pinModeFromSymbol: aSymbol)! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/1/2009 16:28'!
digitalPinModeAt: pinNumber
^self symbolFromPinMode: (arduino digitalPin: pinNumber) mode! !

!ArduinoMorph methodsFor: 'connection' stamp: 'Richo 8/19/2009 13:47'!
disconnect
arduino protocol disconnect! !

!ArduinoMorph methodsFor: 'drawing' stamp: 'Richo 8/18/2009 16:15'!
drawOn: aCanvas
aCanvas translucentImage: self class form at: self bounds topLeft! !

!ArduinoMorph methodsFor: 'initialize-release' stamp: 'Richo 9/21/2009 13:22'!
initialize
	| |
	super initialize.
	self extent: self class form extent.
	arduino := Arduino on: Firmata new.
	isReadingDigitalPins := true.
self initializePortName.
	self initializePins! !

!ArduinoMorph methodsFor: 'initialize-release' stamp: 'Richo 9/4/2009 18:14'!
initializePins
	| pos |
	pos := 12 @ 125.
	6
		timesRepeat: [self
				addMorph: (ArduinoPinMorph justASketch center: self center + pos).
			pos := pos x + 13 @ pos y].
	pos := 104 @ 125.
	0
		to: 5
		do: [:i | 
			self
				addMorph: ((ArduinoAnalogPinMorph
						on: (arduino analogPin: i))
						center: self center + pos).
			pos := pos x + 13 @ pos y].
	pos := -40 @ -124.
	2
		timesRepeat: [self
				addMorph: (ArduinoPinMorph justASketch center: self center + pos).
			pos := pos x + 13 @ pos y].
	pos := -14 @ -124.
	13
		to: 8
		by: -1
		do: [:i | 
			self
				addMorph: ((ArduinoDigitalPinMorph
						on: (arduino digitalPin: i))
						center: self center + pos).
			pos := pos x + 13 @ pos y].
	pos := 78 @ -124.
	7
		to: 2
		by: -1
		do: [:i | 
			self
				addMorph: ((ArduinoDigitalPinMorph
						on: (arduino digitalPin: i))
						center: self center + pos).
			pos := pos x + 13 @ pos y].
	pos := 156 @ -124.
	1
		to: 0
		by: -1
		do: [:i | 
			self
				addMorph: (ArduinoPinMorph justASketch center: self center + pos).
			pos := pos x + 13 @ pos y]! !

!ArduinoMorph methodsFor: 'initialize-release' stamp: 'Richo 9/21/2009 13:21'!
initializePortName
	| availableSerialPorts |
	availableSerialPorts := SmalltalkImage current platformName caseOf: {
				['unix'] -> [self availableSerialPortsForUnix].
				['Win32'] -> [self availableSerialPortsForWindows]}
				 otherwise: [#(#undefined)].
	availableSerialPorts := availableSerialPorts, #(#'other...').
	Vocabulary addStandardVocabulary: (SymbolListType new vocabularyName: #ArduinoPort;
			 symbols: availableSerialPorts).
	portName := availableSerialPorts first! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:57'!
isAnalogPin0Active
^(arduino analogPin: 0) isActive! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:58'!
isAnalogPin0Active: aBoolean
| pin |
pin := arduino analogPin: 0.
[aBoolean ifTrue: [pin activate] ifFalse: [pin deactivate]] on: Error do: []
! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:57'!
isAnalogPin1Active
^(arduino analogPin: 1) isActive! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:58'!
isAnalogPin1Active: aBoolean
| pin |
pin := arduino analogPin:1.
[aBoolean ifTrue: [pin activate] ifFalse: [pin deactivate]] on: Error do: []
! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:57'!
isAnalogPin2Active
^(arduino analogPin: 2) isActive! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:59'!
isAnalogPin2Active: aBoolean
| pin |
pin := arduino analogPin:2.
[aBoolean ifTrue: [pin activate] ifFalse: [pin deactivate]] on: Error do: []
! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:57'!
isAnalogPin3Active
^(arduino analogPin: 3) isActive! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:59'!
isAnalogPin3Active: aBoolean
| pin |
pin := arduino analogPin:3.
[aBoolean ifTrue: [pin activate] ifFalse: [pin deactivate]] on: Error do: []
! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:57'!
isAnalogPin4Active
^(arduino analogPin: 4) isActive! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 17:00'!
isAnalogPin4Active: aBoolean
| pin |
pin := arduino analogPin: 4.
[aBoolean ifTrue: [pin activate] ifFalse: [pin deactivate]] on: Error do: []
! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 16:57'!
isAnalogPin5Active
^(arduino analogPin: 5) isActive! !

!ArduinoMorph methodsFor: 'analog pins' stamp: 'Richo 9/8/2009 17:00'!
isAnalogPin5Active: aBoolean
| pin |
pin := arduino analogPin: 5.
[aBoolean ifTrue: [pin activate] ifFalse: [pin deactivate]] on: Error do: []
! !

!ArduinoMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/1/2009 13:18'!
isConnectable
"Para evitar que el connector se pueda conectar a la placa y se conecte a los pines"
^false! !

!ArduinoMorph methodsFor: 'connection' stamp: 'Richo 8/19/2009 13:39'!
isConnected
^arduino protocol isConnected! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/11/2009 17:19'!
isReadingDigitalPins
^isReadingDigitalPins! !

!ArduinoMorph methodsFor: 'digital pins' stamp: 'Richo 9/11/2009 17:20'!
isReadingDigitalPins: aBoolean
isReadingDigitalPins := aBoolean.
isReadingDigitalPins ifTrue: [arduino activateDigitalReports  ] ifFalse: [arduino deactivateDigitalReports]! !

!ArduinoMorph methodsFor: 'initialize-release' stamp: 'Richo 8/19/2009 16:03'!
newPlayerInstance
^ ArduinoPlayer newUserInstance! !

!ArduinoMorph methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:38'!
pinModeFromSymbol: aSymbol
^aSymbol caseOf: {
	[#output] -> [OutputMode new].
	[#input] -> [InputMode new].
	}
! !

!ArduinoMorph methodsFor: 'accessing' stamp: 'Richo 9/18/2009 16:58'!
portName
 ^portName! !

!ArduinoMorph methodsFor: 'accessing' stamp: 'Richo 9/21/2009 13:37'!
portName: aSymbol

portName :=  (aSymbol = #'other...'
				ifTrue: [(FillInTheBlank request: 'Port name:')  asSymbol]
				ifFalse: [aSymbol]) ! !

!ArduinoMorph methodsFor: 'accessing' stamp: 'Richo 9/7/2009 16:21'!
symbolFromPinMode: aPinMode
"^aSmallInteger caseOf: {
	[PinMode output] -> [#output].
	[PinMode input] -> [#input].
	[PinMode servo] -> [#servo].
	}
otherwise: [#undefined]"
^aPinMode nameSymbol! !

!ArduinoMorph methodsFor: 'viewer category filter' stamp: 'Richo 9/15/2009 12:34'!
wantsConnectionVocabulary
	^ false! !

!ArduinoMorph methodsFor: 'viewer category filter' stamp: 'Richo 9/15/2009 12:34'!
wantsConnectorVocabulary
	^ false! !

!ArduinoMorph methodsFor: 'viewer category filter' stamp: 'Richo 9/15/2009 12:34'!
wantsEmbeddingsVocabulary
	^ false! !

Morph subclass: #ArduinoPinMorph
	instanceVariableNames: 'form pin attachmentPoint'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys'!

ArduinoPinMorph class
	instanceVariableNames: 'form'!

!ArduinoPinMorph commentStamp: 'Richo 9/15/2009 12:41' prior: 0!
Abstract class. I am the Etoy that represents a pin of an Arduino board. I am responsible of the attaching/detaching mechanism.!

ArduinoPinMorph class
	instanceVariableNames: 'form'!

ArduinoPinMorph subclass: #ArduinoAnalogPinMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys'!

!ArduinoAnalogPinMorph commentStamp: 'Richo 9/15/2009 12:42' prior: 0!
I am the Etoy that represents an analog pin of an Arduino board. !

!ArduinoAnalogPinMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 16:19'!
devices
	^ AttachableDeviceMorph analogSubclasses! !

ArduinoPinMorph subclass: #ArduinoDigitalPinMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys'!

!ArduinoDigitalPinMorph commentStamp: 'Richo 9/15/2009 12:42' prior: 0!
I am the Etoy that represents a digital pin of an Arduino board. !

!ArduinoDigitalPinMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/15/2009 12:40'!
devices
	^ AttachableDeviceMorph digitalSubclasses! !

!ArduinoPinMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/4/2009 18:13'!
devices
^self subclassResponsibility! !

!ArduinoPinMorph class methodsFor: 'form' stamp: 'Richo 8/25/2009 09:31'!
form
^ form ifNil: [form := (Form
	extent: 12@12
	depth: 32
	fromArray: #( 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4281742902 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4281479730 4282203453 4282400832 4282400832 4282335039 4281874488 4281282350 4280953385 4280953385 4280953385 4280953385 4280953385 4282137660 4282729797 4282400832 4282400832 4282335039 4281808695 4281742902 4279703318 4279703318 4279703318 4279703318 4280492835 4282861383 4282729797 4282400832 4282400832 4282335039 4281808695 4281742902 4278190081 4278190081 4278190081 4278190081 4279703319 4282861383 4282729797 4282400832 4282400832 4282335039 4281808695 4281742902 4278190081 4278190081 4278190081 4278190081 4279703319 4282861383 4282729797 4282400832 4282400832 4282335039 4281808695 4281742902 4278190081 4278190081 4278190081 4278190081 4279703319 4282861383 4282729797 4282400832 4282400832 4282335039 4281808695 4281742902 4278190081 4278190081 4278190081 4278190081 4279703319 4282861383 4282729797 4282400832 4282400832 4282335039 4281808695 4282335039 4283256141 4283256141 4283256141 4283256141 4283256141 4282992969 4282729797 4282400832 4282400832 4282335039 4282400832 4284045657 4284045657 4284045657 4284045657 4284045657 4284045657 4283848278 4282861383 4282400832 4282400832 4282335039 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282532418 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832 4282400832)
	offset: 0@0)]! !

!ArduinoPinMorph class methodsFor: 'instance creation' stamp: 'Richo 9/14/2009 17:57'!
justASketch
	^ SketchMorph withForm: self  form! !

!ArduinoPinMorph class methodsFor: 'instance creation' stamp: 'Richo 8/25/2009 14:15'!
on: anArduinoPin 
	^ self new initializeEventHandling setPin: anArduinoPin.! !

!ArduinoPinMorph methodsFor: 'attaching' stamp: 'Richo 9/18/2009 17:05'!
attach: aDevice 
	aDevice class newConnectorFromMorph: attachmentPoint toMorph: aDevice attachmentPoint.
	aDevice attach: pin.
	"aDevice moveTo: self center + (-68 @ -100)"
	aDevice center: self center + (-68 @ -100)! !

!ArduinoPinMorph methodsFor: 'attaching' stamp: 'Richo 9/4/2009 18:19'!
attachNewDevice
	| newDevice |

	newDevice := self newDevice.
	newDevice isNil ifTrue: [form := self class form.
self changed.^self].
	newDevice center: self center.
	newDevice openInWorld.
	self attach: newDevice! !

!ArduinoPinMorph methodsFor: 'testing' stamp: 'Richo 9/15/2009 12:40'!
canBeAttachedTo: aMorph 
	self class devices
		do: [:each | (aMorph isKindOf: each)
				ifTrue: [^ true]].
	^ false! !

!ArduinoPinMorph methodsFor: 'attaching' stamp: 'Richo 9/15/2009 12:24'!
connectedToBy: aConnector 
	"notification upon connection by a NCConnectorMorph"
	| device |
	aConnector connectFinishTo: attachmentPoint.
	aConnector startControllingConnections.
	device := aConnector sourceMorph owner.
	device attach: pin! !

!ArduinoPinMorph methodsFor: 'attaching' stamp: 'Richo 9/9/2009 17:20'!
disconnectedFromBy: aConnector
[
aConnector destinationMorph ifNotNilDo: [:m | m owner detach].
aConnector sourceMorph ifNotNilDo: [:m | m owner detach].]
on: Error do: []! !

!ArduinoPinMorph methodsFor: 'drawing' stamp: 'Richo 8/25/2009 11:14'!
drawOn: aCanvas
aCanvas drawImage: form at: self bounds topLeft! !

!ArduinoPinMorph methodsFor: 'initialization' stamp: 'Richo 9/15/2009 12:25'!
initialize
	super initialize.
	form := self class form.
	self extent: self class form extent.
	self initializeAttachmentPoint! !

!ArduinoPinMorph methodsFor: 'initialization' stamp: 'Richo 9/15/2009 12:25'!
initializeAttachmentPoint
	attachmentPoint := AttachmentPointMorph new color: Color transparent;
				 borderWidth: 0;
				 extent: 1 @ 1;
				 center: self center + (1 @ 0).
	self addMorph: attachmentPoint! !

!ArduinoPinMorph methodsFor: 'initialization' stamp: 'Richo 8/25/2009 12:20'!
initializeEventHandling


	self
		on: #mouseEnter
		send: #mouseEnter:forMorph:
		to: self;
		
		on: #mouseLeave
		send: #mouseLeave:forMorph:
		to: self.
	self on: #mouseDown send: #mouseDown:forMorph: to: self.! !

!ArduinoPinMorph methodsFor: 'event handling' stamp: 'Richo 8/25/2009 11:20'!
mouseDown: evt forMorph: aMorph 
self attachNewDevice.! !

!ArduinoPinMorph methodsFor: 'event handling' stamp: 'Richo 8/25/2009 11:17'!
mouseEnter: evt forMorph: aMorph 
form := self class form deepCopy reverse.
self changed! !

!ArduinoPinMorph methodsFor: 'event handling' stamp: 'Richo 8/25/2009 11:16'!
mouseLeave: evt forMorph: aMorph 
form := self class form.
self changed! !

!ArduinoPinMorph methodsFor: 'attaching' stamp: 'Richo 9/21/2009 13:43'!
newDevice

| devices str choice |
	devices := self class devices asSortedCollection: [:a :b| a asString <= b asString].
	devices size = 1 ifTrue: [^devices first new].
	str := devices
				collect: [:each | '  ' , each defaultNameStemForInstances  , '  '].
	choice := PopUpMenu withCaption: 'Device:' chooseFrom: str.
	choice = 0
		ifTrue: [^ nil].
	^ (devices at: choice) new! !

!ArduinoPinMorph methodsFor: 'private' stamp: 'Richo 8/25/2009 14:16'!
setPin: anArduinoPin
pin := anArduinoPin! !

!ArduinoPinMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/1/2009 13:17'!
wantsAttachmentFromEnd: endIndex ofConnector: aConnector
"Pequeo cambio con respecto a la superclase para evitar que considere que shift est siempre apretado y poder conectar a los pines (que son submorphs)"

	"Answer true if I would like the given end of aConnector attaching to me."
	"TODO: way too much policy in this one place!!"

	owner ifNil: [ ^false ].	
	self == aConnector ifTrue: [ ^false ].
	self isConnectable ifFalse: [ ^false ].
	(self firstOwnerSuchThat: [ :m | m == aConnector ]) ifNotNil: [ ^false ].
	(self isConstrainedBy: aConnector) ifTrue: [ ^false ].
	self isPartsDonor ifTrue: [ ^false ].

	"Allow connection to submorphs when the SHIFT key is pressed, but only to top-level morphs"
	("ActiveHand lastEvent shiftPressed not" false
		and: [ self topRendererOrSelf owner isPlayfieldLike not ])
			ifTrue: [ ^false ].

	"Avoid connecting from a different World (WiW exception)"
	aConnector pasteUpMorphOrWorld ifNotNilDo: [ :itsWorld |
		(itsWorld isPartsBin not
			and: [ itsWorld ~= World
			and: [ self pasteUpMorphOrWorld ~~ itsWorld ]])
				ifTrue: [ ^false ]].
^true
! !

Morph subclass: #AttachableDeviceMorph
	instanceVariableNames: 'device attachmentPoint'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

!AttachableDeviceMorph commentStamp: 'Richo 9/15/2009 12:43' prior: 0!
Abstract class. My subclasses are the Etoys of different devices that can be attached to an Arduino board.!

!AttachableDeviceMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 16:19'!
analogSubclasses
^(self allSubclasses select: [:each | each isAnalog]) asArray! !

!AttachableDeviceMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:22'!
digitalSubclasses
	^ (self allSubclasses
		select: [:each | each isDigital]) asArray! !

!AttachableDeviceMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 13:52'!
isAnalog
	^ false! !

!AttachableDeviceMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 13:52'!
isDigital
	^ false! !

!AttachableDeviceMorph class methodsFor: 'connectors' stamp: 'Richo 9/4/2009 16:06'!
newConnector
^ self subclassResponsibility! !

!AttachableDeviceMorph class methodsFor: 'connectors' stamp: 'Richo 9/4/2009 16:06'!
newConnectorFromMorph: m1 toMorph: m2
^ self subclassResponsibility! !

!AttachableDeviceMorph methodsFor: 'attaching' stamp: 'Richo 9/8/2009 13:10'!
attach: aPin 
device attach: aPin! !

!AttachableDeviceMorph methodsFor: 'accessing' stamp: 'Richo 9/15/2009 12:27'!
attachmentPoint
	^ attachmentPoint ! !

!AttachableDeviceMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:58'!
attachmentPointBorderColor
	^ Color yellow! !

!AttachableDeviceMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:58'!
attachmentPointCenter
	^ self center! !

!AttachableDeviceMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:58'!
attachmentPointColor
	^ Color blue! !

!AttachableDeviceMorph methodsFor: 'initialization' stamp: 'Richo 9/9/2009 17:20'!
delete
self detach.
^super delete! !

!AttachableDeviceMorph methodsFor: 'attaching' stamp: 'Richo 9/9/2009 17:21'!
detach
	self isAttached
		ifFalse: [^ self].
	[device detach]
		on: Error
		do: []! !

!AttachableDeviceMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/9/2009 17:20'!
disconnectedFromBy: aConnector

self detach! !

!AttachableDeviceMorph methodsFor: 'drawing' stamp: 'Richo 9/11/2009 17:44'!
drawOn: aCanvas 
	aCanvas translucentImage: self class form at: self bounds topLeft! !

!AttachableDeviceMorph methodsFor: 'initialization' stamp: 'Richo 9/15/2009 12:25'!
initialize
	super initialize.
	self extent: self class form extent.
	self initializeAttachmentPoint.
	device := self class device new! !

!AttachableDeviceMorph methodsFor: 'initialization' stamp: 'Richo 9/15/2009 12:59'!
initializeAttachmentPoint
	attachmentPoint := AttachmentPointMorph new extent: 10 @ 10;
				 center: self attachmentPointCenter;
				 color: self attachmentPointColor;
				 borderColor: self attachmentPointBorderColor;
				
				on: #mouseDown
				send: #mouseDown:evt:
				to: self.
	self addMorph: attachmentPoint! !

!AttachableDeviceMorph methodsFor: 'testing' stamp: 'Richo 9/8/2009 17:11'!
isAnalog
^self class isAnalog! !

!AttachableDeviceMorph methodsFor: 'attaching' stamp: 'Richo 9/8/2009 13:11'!
isAttached
^device isAttached! !

!AttachableDeviceMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/4/2009 15:55'!
isConnectable
^false! !

!AttachableDeviceMorph methodsFor: 'testing' stamp: 'Richo 9/8/2009 17:11'!
isDigital
^self class isDigital! !

!AttachableDeviceMorph methodsFor: 'event handling' stamp: 'Richo 9/15/2009 12:27'!
mouseDown: aMouseButtonEvent evt: aMorph 
	self isAttached
		ifTrue: [^ self].
	self class newConnector startWiringFrom: attachmentPoint! !

!AttachableDeviceMorph methodsFor: 'as yet unclassified' stamp: 'Richo 9/4/2009 15:54'!
moveTo: dest 
	| opuesto adyacente pasosOpuesto pasosAdyacente x y diff maxPasos |
	x := self center x.
	y := self center y.
	diff := self center - dest.
	opuesto := diff y abs.
	adyacente := diff x abs.
	maxPasos := 10.
	pasosOpuesto := opuesto / maxPasos * diff y sign.
	pasosAdyacente := adyacente / maxPasos * diff x sign.
	[maxPasos
		timesRepeat: [x := x - pasosAdyacente.
			y := y - pasosOpuesto.
			self center: x rounded @ y rounded.
			(Delay forMilliseconds: 1) wait]]
		forkNamed: self class asString, ' moveTo: ' , dest asString! !

!AttachableDeviceMorph methodsFor: 'initialization' stamp: 'Richo 9/8/2009 14:03'!
newPlayerInstance
^AttachableDevicePlayer newUserInstance! !

!AttachableDeviceMorph methodsFor: 'viewer category filter' stamp: 'Richo 9/4/2009 15:56'!
wantsConnectionVocabulary

^false! !

!AttachableDeviceMorph methodsFor: 'viewer category filter' stamp: 'Richo 9/4/2009 15:56'!
wantsConnectorVocabulary
	^ false! !

!AttachableDeviceMorph methodsFor: 'viewer category filter' stamp: 'Richo 9/4/2009 15:56'!
wantsEmbeddingsVocabulary
	^ false! !

AttachableDeviceMorph subclass: #EButtonMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

EButtonMorph class
	instanceVariableNames: 'form'!

!EButtonMorph commentStamp: 'Richo 9/15/2009 13:04' prior: 0!
Abstract class. I am the Etoys of a generic button. My subclasses define the form of specific buttons such as pushbuttons or switchs.!

EButtonMorph class
	instanceVariableNames: 'form'!

!EButtonMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/11/2009 17:44'!
device
^EButton! !

!EButtonMorph class methodsFor: 'form' stamp: 'Richo 9/8/2009 13:22'!
form
^form ifNil: [self initializeForm]! !

!EButtonMorph class methodsFor: 'form' stamp: 'Richo 9/8/2009 14:10'!
initializeForm
self subclassResponsibility! !

!EButtonMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:20'!
isDigital
^false! !

!EButtonMorph class methodsFor: 'connectors' stamp: 'Richo 9/8/2009 13:35'!
newConnector
	^ ArduinoWireMorph new beOrthogonal: false;
		 beSmoothCurve: true;
		 lineColor: Color red;
		 lineWidth: 4;
		 borderWidth: 1;
		 borderColor: Color gray;
		 yourself! !

!EButtonMorph class methodsFor: 'connectors' stamp: 'Richo 9/8/2009 13:35'!
newConnectorFromMorph: m1 toMorph: m2 
	^ (ArduinoWireMorph fromMorph: m1 toMorph: m2) beOrthogonal: false;
		 beSmoothCurve: true;
		 lineColor: Color red;
		 lineWidth: 4;
		 borderWidth: 1;
		 borderColor: Color gray;
		 yourself! !

!EButtonMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:59'!
attachmentPointBorderColor
	^ Color gray! !

!EButtonMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:59'!
attachmentPointCenter
	^ self center + (13 @ 29)! !

!EButtonMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:59'!
attachmentPointColor
	^ Color red! !

!EButtonMorph methodsFor: 'accessing' stamp: 'Richo 9/8/2009 14:47'!
value
	^ [device value = 1]
		on: Error
		do: [false]! !

EButtonMorph subclass: #PushButtonMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

!PushButtonMorph commentStamp: 'Richo 9/15/2009 13:03' prior: 0!
I am the Etoys of a push-button.!

!PushButtonMorph class methodsFor: 'viewer categories' stamp: 'Richo 9/14/2009 15:54'!
additionsToViewerCategories
^ #(
(#'pushbutton' (
#(slot isPressed '' Boolean readOnly Player getIsPressed Player unused  )
))

)! !

!PushButtonMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:13'!
defaultNameStemForInstances
	^ 'Pushbutton'! !

!PushButtonMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:13'!
descriptionForPartsBin
	"Answer a description for use in parts bins"
	^ self
		partName: 'Pushbutton'
		categories: {'Electronics'}
		documentation: ''! !

!PushButtonMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:10'!
initializeForm

	^ form := Form
				extent: 33 @ 52
				depth: 32
				fromArray: #(0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293537069 4292553772 4292553772 4293140769 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293075490 4292553772 4292553772 4293536041 0 0 0 0 4293342260 4291901753 4291901753 4292619051 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292618794 4291901753 4291901753 4293210931 0 0 0 0 4293342260 4291901753 4291901753 4292619051 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292618794 4291901753 4291901753 4293210931 0 0 0 0 4293342260 4291901753 4291901753 4292619051 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292618794 4291901753 4291901753 4293210931 0 0 0 0 4293471533 4292488236 4292488236 4293075233 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293075490 4292488236 4292488236 4293470505 0 0 0 4288124309 4286458667 4290728273 4291123031 4291253332 4288908428 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288451732 4290992730 4291123031 4291123031 4289414469 4288190616 0 0 4288124823 4288256409 4288256409 4288190616 4286348412 4286216826 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287730065 4286216826 4287598479 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4287861651 4281874488 4282269246 4278190081 4280295456 4287598479 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4285361517 4282006074 4279703319 4278519045 4284637794 4288256409 4288190616 0 0 4288190616 4288256409 4283979864 4282795590 4285624689 4278190081 4278190081 4283190348 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288124823 4280361249 4285756275 4281611316 4278190081 4278584838 4287730065 4288190616 0 0 4288190616 4288256409 4282729797 4278190081 4278453252 4278190081 4278190081 4281874488 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287664272 4278190081 4278321666 4278519045 4278190081 4278190081 4286743170 4288190616 0 0 4288190616 4288256409 4285756275 4278190081 4278190081 4278190081 4278190081 4285032552 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4280492835 4278190081 4278190081 4278190081 4279703319 4288124823 4288190616 0 0 4288190616 4288256409 4288256409 4284835173 4280361249 4280229663 4284374622 4288256409 4288256409 4288256409 4288256409 4288190616 4285690482 4283190348 4282269246 4282071867 4282137660 4282664004 4284177243 4287401100 4288256409 4288256409 4288256409 4288256409 4287269514 4281479730 4279308561 4281150765 4286808963 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4286216826 4282137660 4281677109 4284175443 4286148202 4286476395 4286147688 4285293408 4282729282 4281940281 4283782485 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4284966759 4281611316 4282793274 4287000937 4286669914 4285748040 4285748040 4285748040 4285813833 4286011470 4284172354 4282137146 4282532418 4287730065 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4285690482 4281611316 4283515453 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285156933 4282465596 4282598211 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287927444 4281742902 4283055931 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285025603 4282202939 4284374622 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4284243036 4281742644 4285419590 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4283580988 4282203453 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4282137660 4283121209 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285288004 4282071610 4285624689 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4281611316 4284039996 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4282267702 4283914071 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4287598479 4281545523 4284499774 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4282398258 4283321934 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4287927444 4281545523 4284368189 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4282069551 4283453520 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4281742902 4283382837 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4281281322 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4282729797 4281806379 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4284631103 4281019179 4286874756 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4285953654 4280887593 4284499518 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4281674535 4282269246 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4282598211 4280820513 4285419333 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4283514166 4280427042 4286414205 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287598479 4281479730 4280886049 4285025346 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4285748040 4283316788 4280032283 4284243036 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287466893 4281611316 4280097562 4282791215 4285091139 4285748040 4285748040 4285748040 4285682247 4284171067 4281345828 4279966491 4284177243 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4288256409 4288190616 4286808963 4286808963 4288190616 4288256409 4288256409 4288256409 4288190616 4284177243 4280558628 4279637526 4280426013 4281083170 4280886048 4280032026 4279769112 4281479730 4286677377 4288256409 4288256409 4288256409 4288256409 4287993237 4286808963 4287993237 4288256409 4288256409 4288190616 0 0 4288190616 4288256409 4287795858 4281874488 4281677109 4278190081 4281084972 4287927444 4288256409 4288256409 4288256409 4288256409 4288256409 4286348412 4283585106 4282664004 4282861383 4284506208 4287532686 4288256409 4288256409 4288256409 4288256409 4288256409 4285427310 4281874488 4279242768 4278913803 4285493103 4288256409 4288190616 0 0 4288190616 4288256409 4283585106 4283519313 4285361517 4278190081 4278190081 4283848278 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287993237 4280558628 4286151033 4281150765 4278190081 4278979596 4288059030 4288190616 0 0 4288190616 4288256409 4282137660 4278190081 4278782217 4278190081 4278190081 4282335039 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287137928 4278190081 4278584838 4278716424 4278190081 4278190081 4287203721 4288190616 0 0 4288190616 4288256409 4284900966 4278190081 4278190081 4278190081 4278190081 4285164138 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4279703319 4278190081 4278190081 4278190081 4279703319 4288190616 4288190616 0 0 4288190616 4288256409 4288190616 4283848278 4279637526 4279637526 4284045657 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4286743170 4280690214 4278650631 4280690214 4286743170 4288256409 4288190616 0 0 4288190616 4287137928 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 0 0 4288190616 4283452492 4285359718 4286017648 4286017648 4286677120 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4285952112 4286017648 4285886062 4284636252 4288190616 0 0 0 4293017664 4292684073 4292684073 4292944932 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292749609 4292684073 4292684073 4293210674 0 0 0 0 4293342260 4291901753 4291901753 4292619051 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292618794 4291901753 4291901753 4293210931 0 0 0 0 4293342260 4291901753 4291901753 4292619051 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292618794 4291901753 4291901753 4293210931 0 0 0 0 4293342260 4291901753 4291901753 4292619051 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292618794 4291901753 4291901753 4293210931 0 0 0 0 4293671482 4292625476 4292625476 4293145652 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293210931 4292625476 4292625476 4293605689 0 0 0 0 4294659919 4294658891 4294658891 4294721086 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294656578 4294658891 4294658891 4294656835 0 0 )
				offset: 0 @ 0! !

!PushButtonMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:21'!
isDigital
^true! !

!PushButtonMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:01'!
attachmentPointCenter
	^ self center + (13 @ 29)! !

EButtonMorph subclass: #SwitchMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

!SwitchMorph commentStamp: 'Richo 9/15/2009 13:03' prior: 0!
I am the Etoys of a switch.!

!SwitchMorph class methodsFor: 'viewer categories' stamp: 'Richo 9/14/2009 15:54'!
additionsToViewerCategories
^ #(
(#'switch' (
#(slot isOn '' Boolean readOnly Player getIsOn Player unused  )
))

)! !

!SwitchMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:42'!
defaultNameStemForInstances
	^ 'Switch'! !

!SwitchMorph class methodsFor: 'parts bin' stamp: 'Richo 9/8/2009 14:42'!
descriptionForPartsBin
	"Answer a description for use in parts bins"
	^ self
		partName: 'Switch'
		categories: {'Electronics'}
		documentation: ''! !

!SwitchMorph class methodsFor: 'form' stamp: 'Richo 9/8/2009 14:42'!
initializeForm
^form :=  (Form
	extent: 45@47
	depth: 32
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4284243036 4284243036 4284243036 4284243036 4284243036 4284243036 4284243036 4284243036 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4283585106 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4284440415 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4279045389 4278519045 4278519045 4278519045 4278519045 4278519045 4278519045 4278519045 4278519045 4278519045 4278716424 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4280756007 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4282861383 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4278782217 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278453252 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4280624421 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4282861383 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4278782217 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278453252 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4280624421 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4282861383 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4278782217 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278453252 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4280624421 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4282795590 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4278782217 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278453252 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4280624421 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281216558 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4279505940 4279111182 4279111182 4279111182 4279111182 4279111182 4279111182 4279111182 4279111182 4279111182 4279176975 4279505940 4279505940 4279505940 4279505940 4279505940 4279505940 4279505940 4279505940 4280887593 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281216558 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4279374354 4281019179 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4280756007 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4280756007 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4278913803 4282664004 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4279900698 4285164138 4281413937 4281413937 4281413937 4281413937 4281413937 4280887593 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4281413937 4281413937 4281413937 4281084972 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4281216558 4281413937 4281413937 4281282351 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4280690214 4281019179 4281413937 4281413937 4281413937 4281413937 4281413937 4286151033 0 0 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 0 0 0 0 0 0 0 0 0 0 4288585374 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4289045925 0 0 0 0 4288585374 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4289045925 0 0 0 0 4288585374 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4289045925 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288387995 4287401100 4287401100 4288782753 0 0 0 0 0 0 0 0 4288387995 4287401100 4287401100 4288782753 0 0 0 0 0 0 0 0 4288387995 4287401100 4287401100 4288782753 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4290822336 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4290822336 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4290822336 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4290822336 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4290822336 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4290822336 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4289371549 4288379514 4288379514 4290224288 0 0 0 0 0 0 0 0 4289371549 4288379514 4288379514 4290224288 0 0 0 0 0 0 0 0 4289371549 4288379514 4288379514 4290224288 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292231232 4292684073 4292619051 4293079859 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292687671 4292097590 4291901753 4293145138 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292687671 4292097590 4291901753 4293145138 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292687671 4292097590 4291901753 4293145138 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292687671 4292097590 4291901753 4293145138 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292687671 4292097590 4291901753 4293145138 0 0 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292490292 4292097590 4291901753 4292948016 0 0 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292424499 4292097590 4291901753 4292816430 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293477187 4292821056 4292691012 4293803068 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294474105 4294657092 4294657606 4294596439 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!SwitchMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 14:42'!
isDigital
^true! !

!SwitchMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:02'!
attachmentPointCenter
	^ self center + (-12 @ 27)! !

AttachableDeviceMorph subclass: #LightDiodeMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

LightDiodeMorph class
	instanceVariableNames: 'form'!

!LightDiodeMorph commentStamp: 'Richo 9/15/2009 13:02' prior: 0!
I am the Etoys of a LED.!

LightDiodeMorph class
	instanceVariableNames: 'form'!

!LightDiodeMorph class methodsFor: 'viewer categories' stamp: 'Richo 9/14/2009 15:51'!
additionsToViewerCategories
^ #(
(#'led' (
#(slot value '' Boolean readWrite Player getValue Player setValue:  )
)) 

)! !

!LightDiodeMorph class methodsFor: 'scripting' stamp: 'Richo 9/1/2009 17:28'!
defaultNameStemForInstances
^'Led'! !

!LightDiodeMorph class methodsFor: 'parts bin' stamp: 'Richo 9/1/2009 17:28'!
descriptionForPartsBin
	"Answer a description for use in parts bins"

	^ self partName: 	'Led'
		categories:		{'Electronics' }
		documentation:	''! !

!LightDiodeMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/15/2009 10:44'!
device
	^ LightEmittingDiode! !

!LightDiodeMorph class methodsFor: 'form' stamp: 'Richo 9/1/2009 17:07'!
form
^form ifNil: [self initializeForm].! !

!LightDiodeMorph class methodsFor: 'form' stamp: 'Richo 9/1/2009 17:16'!
initializeForm

^form := (Form
	extent: 37@76
	depth: 32
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 0 4290169276 4287284381 4285579402 4284924035 4284924035 4285973134 4288071334 4290956229 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288399017 4283612277 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281842274 4284792963 4289906873 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290890692 4284399485 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4282105189 4284467586 4282302056 4281580127 4281776737 4286366355 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290431680 4282825580 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281645664 4287879850 4288142509 4285648784 4282105189 4281580127 4284596351 4291480778 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290955717 4282891116 4281580127 4281908323 4286042516 4285386381 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4283352180 4286961055 4288273839 4287551911 4282695532 4281580127 4284989572 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284727170 4281580127 4281842530 4286829982 4288273839 4288273839 4284139646 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281645664 4285911187 4288273839 4287748777 4282498922 4281580127 4287612321 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288989103 4281580127 4281580127 4285911187 4288273839 4288273839 4288273839 4287026848 4281711200 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281645664 4284336256 4283220851 4281908323 4281580127 4282301286 4291152839 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284202620 4281580127 4283351924 4288273839 4288273839 4288273839 4286305176 4281842530 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4286956441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290824899 4281711200 4281580127 4286501786 4288273839 4288273839 4287223715 4281776993 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4283481716 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288071333 4281580127 4282105189 4288208046 4288273839 4288273839 4283745657 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281711200 4291153095 0 0 0 0 0 0 0 0 0 0 0 0 0 4286300819 4281580127 4283417461 4288273839 4288273839 4288011180 4281645664 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4289382836 0 0 0 0 0 0 0 0 0 0 0 0 0 4285514122 4281580127 4284139646 4288273839 4288273839 4287158178 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4288399017 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273839 4288273839 4286895518 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273839 4288273839 4286895518 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273839 4288273839 4286895519 4281315674 4281315674 4281315674 4281315674 4281315674 4281315674 4281315674 4281315674 4281315674 4281315674 4281448029 4281579871 4280984914 4281051220 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273839 4288141484 4286366611 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280786510 4281514078 4281514078 4280720974 4280852816 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273839 4287744932 4286366098 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280654924 4281513565 4281579871 4280852816 4280588362 4280852816 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273583 4287744932 4286366098 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280720461 4281447772 4281514334 4280984658 4280588362 4280588362 4280852816 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273583 4287744932 4286366098 4280588362 4280588362 4280588362 4280588362 4280588362 4280588362 4280588875 4281250649 4281514591 4281050707 4280588362 4280588362 4280588362 4280852816 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273583 4287744932 4286366098 4280588362 4280588362 4280588362 4280588362 4280588362 4280588619 4280988247 4281121371 4280854610 4280588362 4280588362 4280588362 4280588362 4280852816 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284336256 4288273583 4287744932 4286366098 4280588362 4280588362 4280588362 4280588362 4280588362 4280987734 4281121371 4280855379 4280588362 4280588362 4280588362 4280588362 4280588362 4280787022 4281580127 4281580127 4281580127 4288071333 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281580127 4284270719 4288076973 4287744932 4286366612 4280655693 4280655693 4280655693 4280655693 4280921428 4281121371 4280988503 4280655693 4280655693 4280655693 4280655693 4280655693 4280654411 4280721486 4281383773 4281514334 4281580127 4286890649 0 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281514335 4284074366 4288011436 4287744932 4286433429 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4280721999 4280721486 4281121371 4281317981 4281580127 4280659538 4289709494 0 0 0 0 0 0 0 0 0 0 0 0 4285317511 4281317980 4283943036 4288011436 4287744932 4286433429 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4280721999 4280721486 4281121371 4281121371 4281449053 4280003659 4282166368 0 0 0 0 0 0 0 0 0 0 0 0 4285186694 4281121371 4283943036 4288011436 4287744932 4286433429 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4280721999 4280721486 4281121371 4281121371 4281252700 4280003659 4279477571 4290628033 0 0 0 0 0 0 0 0 0 0 0 4284793219 4281121371 4283943036 4288011436 4287744932 4286433429 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4280721999 4280721486 4281121371 4281121371 4281121371 4280069452 4279281217 4286495121 0 0 0 0 0 0 0 0 0 0 0 4284662145 4281121371 4283943036 4288011436 4287877543 4286500248 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4280789074 4280854610 4281121371 4281121371 4281121371 4280069452 4279281217 4284789886 0 0 0 0 0 0 0 0 0 0 0 4284530815 4281121371 4283943036 4288011436 4288011436 4286699165 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4279938378 4279281217 4284659325 0 0 0 0 0 0 0 0 0 0 0 4283611251 4281121371 4283943036 4288011436 4288011436 4286699165 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121370 4279478083 4279281217 4285120131 0 0 0 0 0 0 0 0 0 0 0 4282494564 4280989785 4283943036 4288011436 4288011436 4286699165 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4280661076 4279281217 4279347779 4285579658 0 0 0 0 0 0 0 0 0 0 0 4282297441 4280791380 4284139902 4288011436 4288011436 4286699165 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281055321 4279478340 4279281217 4279612232 4287415966 0 0 0 0 0 0 0 0 0 0 0 4282363235 4283284850 4287026336 4288011437 4288011436 4286699165 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121371 4281121114 4281121114 4281121371 4281121371 4281121371 4281121371 4281121371 4281055577 4279741256 4279281217 4279479621 4280006222 4291284169 0 0 0 0 0 0 0 0 0 0 0 4282891117 4279675975 4284794244 4287419812 4287945644 4286699165 4280529234 4280529234 4280529234 4280792406 4281121371 4281121371 4280726613 4280529233 4280529233 4280660820 4281121371 4281121371 4281121371 4280923991 4279543876 4279281217 4279414085 4279678795 4283547510 0 0 0 0 0 0 0 0 0 0 0 0 4283022702 4282040679 4283023472 4282562665 4286632090 4286829725 4281776224 4280529233 4280529233 4280792406 4281121371 4281121371 4280726613 4280529233 4280529233 4280660820 4281252700 4282892912 4283154033 4279281217 4279347009 4279546183 4279678795 4280596565 4290759619 0 0 0 0 0 0 0 0 0 0 0 0 4286301330 4282303337 4287290277 4285911956 4282169957 4282759788 4285647246 4286172821 4284663426 4283614071 4283023985 4282564715 4282301287 4282694764 4283613558 4284991623 4286566553 4285056903 4281972065 4279479622 4279678282 4279678795 4280203088 4288661165 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287219614 4286962080 4287290277 4287290277 4282565741 4279480134 4280201037 4281972067 4283284849 4284138108 4284531841 4284597377 4284006522 4283022190 4281644126 4279873098 4279546183 4279678538 4279678795 4279678795 4280727895 4288989359 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4289776568 4286239126 4287290277 4282697327 4279613002 4279613002 4279613002 4279612746 4279612489 4279612232 4279612233 4279546696 4279612745 4279613002 4279678795 4279678795 4279678795 4279809869 4283481716 4290956485 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288859056 4283876474 4280006221 4279613002 4279613002 4279613002 4279678795 4279678795 4279678794 4279613002 4279613002 4279613002 4279678795 4280465491 4283744119 4289776057 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287139210 4285243773 4283346542 4282562921 4281842275 4281449054 4281316956 4281709918 4282430054 4284067958 4288661678 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 4288651167 4287401100 4287401100 4288322202 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 4288651167 4287401100 4287401100 4288322202 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 4288716960 4287401100 4287401100 4287598479 4291151301 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 4289638062 4287401100 4287401100 4287401100 4288059030 4291151301 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 4291414473 4287993237 4287401100 4287401100 4287401100 4287861651 4290953922 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 4290953922 4287861651 4287401100 4287401100 4287401100 4287664272 4290756543 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 4291085508 4288059030 4287401100 4287401100 4287401100 4287730065 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 4291282887 4288190616 4287401100 4287401100 4287401100 4288782753 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 4291282887 4287795858 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289638062 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 4294901760 4294901760 0 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4289967027 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290032820 4287401100 4287401100 4287401100 4289638062 0 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!LightDiodeMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 13:52'!
isDigital
^true! !

!LightDiodeMorph class methodsFor: 'connectors' stamp: 'Richo 9/1/2009 17:19'!
newConnector
^ (ArduinoWireMorph new) beOrthogonal: false;
				 beSmoothCurve: true;
				 lineColor: Color gray;
				 lineWidth: 4;
				 borderWidth: 1;
				 borderColor: Color gray; yourself! !

!LightDiodeMorph class methodsFor: 'connectors' stamp: 'Richo 9/1/2009 17:45'!
newConnectorFromMorph: m1 toMorph: m2 
^ (ArduinoWireMorph fromMorph: m1 toMorph: m2) beOrthogonal: false;
				 beSmoothCurve: true;
				 lineColor: Color gray;
				 lineWidth: 4;
				 borderWidth: 1;
				 borderColor: Color gray; yourself! !

!LightDiodeMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:59'!
attachmentPointBorderColor
	^ Color gray! !

!LightDiodeMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 12:59'!
attachmentPointCenter
	^ self center + (7 @ 37)! !

!LightDiodeMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:00'!
attachmentPointColor
	^ Color gray! !

!LightDiodeMorph methodsFor: 'value' stamp: 'Richo 9/8/2009 13:14'!
value
^[device value = 1] on: Error do: [false] ! !

!LightDiodeMorph methodsFor: 'value' stamp: 'Richo 9/8/2009 13:58'!
value: aBoolean
[device value: (aBoolean ifTrue: [1] ifFalse: [0])] on: Error do: []! !

AttachableDeviceMorph subclass: #PhotoresistorMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

PhotoresistorMorph class
	instanceVariableNames: 'form'!

!PhotoresistorMorph commentStamp: 'Richo 9/15/2009 13:02' prior: 0!
I am the Etoys of a LDR.!

PhotoresistorMorph class
	instanceVariableNames: 'form'!

!PhotoresistorMorph class methodsFor: 'viewer categories' stamp: 'Richo 9/14/2009 15:52'!
additionsToViewerCategories
	^ #(#(#'ldr' #(#(#slot #lightValue '' #Number #readOnly #Player #getLightValue #Player #unused))) )! !

!PhotoresistorMorph class methodsFor: 'parts bin' stamp: 'Richo 9/8/2009 16:15'!
defaultNameStemForInstances
^'Photoresistor'! !

!PhotoresistorMorph class methodsFor: 'parts bin' stamp: 'Richo 9/8/2009 16:14'!
descriptionForPartsBin
	"Answer a description for use in parts bins"

	^ self partName: 	'Photoresistor'
		categories:		{'Electronics' }
		documentation:	''! !

!PhotoresistorMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/11/2009 17:45'!
device
^Photoresistor ! !

!PhotoresistorMorph class methodsFor: 'form' stamp: 'Richo 9/8/2009 16:04'!
form
^form ifNil: [self initializeForm]! !

!PhotoresistorMorph class methodsFor: 'form' stamp: 'Richo 9/8/2009 16:03'!
initializeForm
^form := (Form
	extent: 58@31
	depth: 32
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279111182 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4278255873 4279111182 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279374354 4281348144 4284177243 4284966759 4285624689 4286348412 4286940549 4287466893 4287861651 4288256409 4288980132 4289572269 4289769648 4289638062 4289309097 4288716960 4288453788 4288059030 4287664272 4287203721 4286677377 4285953654 4285295724 4284506208 4281348144 4279374354 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4280229663 4278190081 4285493103 4288914082 4288117113 4287652193 4287254351 4286922559 4286984497 4287571751 4288027933 4287894034 4287761163 4287694342 4287694342 4287760649 4287696398 4287305238 4286717470 4286523689 4286854967 4287187016 4287519836 4287918192 4288581262 4285493103 4278190081 4280229663 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4283058762 4278190081 4278190081 4286348412 4287851371 4285727234 4286191897 4286787375 4287039753 4288690746 4289819507 4290151042 4290350220 4290483348 4290615705 4290615705 4290549398 4290417041 4290217863 4289952378 4288832355 4287252552 4286789174 4286391075 4285925898 4286323997 4286348412 4278190081 4278190081 4283058762 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190081 4278190081 4278190081 4287072135 4287254094 4286523689 4289243304 4291151301 4288358954 4289620072 4291479238 4291014318 4290615962 4290349706 4290151042 4290084992 4290217349 4290417041 4290749090 4291279803 4291611852 4291217094 4289309097 4288980132 4287983985 4285859334 4287072135 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4280821800 4278190081 4278190081 4278190081 4287795858 4286921531 4287053888 4291217094 4291611852 4289487201 4289413698 4291198333 4290801776 4288487970 4287959570 4288027162 4288093212 4287960598 4287760906 4287561728 4287561728 4287761163 4288690746 4291017659 4289177511 4288382598 4285726720 4287795858 4278190081 4278190081 4278190081 4280821800 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190081 4278190081 4278190081 4278190081 4288387995 4286523689 4288831327 4291611852 4291611852 4292530898 4293977573 4294110187 4294242801 4294177522 4292072403 4291611852 4291611852 4291611852 4291611852 4291478724 4290948268 4290350734 4287760906 4290283913 4290888129 4288780697 4285726720 4288387995 4278190081 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282729797 4278190081 4278190081 4278190081 4278255873 4288914339 4286716699 4289951864 4291611852 4291611852 4294111986 4294309365 4294309365 4294309365 4294177265 4292327094 4289288023 4288889667 4288624182 4288557875 4288690489 4289022281 4289420637 4287561728 4290881704 4291611852 4289769648 4285859077 4288914339 4278255873 4278190081 4278190081 4278190081 4282729797 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4279111182 4278190081 4278190081 4278190081 4278584838 4288980132 4287368975 4290283656 4291611852 4291611852 4294243572 4294309365 4294309365 4294309365 4293778909 4291661968 4289022281 4289420894 4289686636 4289752943 4289620072 4289287766 4288756282 4288889667 4291611852 4291611852 4290953922 4286124562 4288980132 4278584838 4278190081 4278190081 4278190081 4279111182 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190081 4278190081 4279111182 4279703319 4279176975 4289111718 4287562756 4290549141 4291611852 4291611852 4293322470 4294309365 4294309365 4294309365 4293778138 4290475124 4291146418 4291014318 4291279546 4291611595 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4286586655 4289111718 4279176975 4279703319 4279111182 4278190081 4278190081 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284637794 4278716424 4283585106 4285624689 4285624689 4285229931 4288387224 4287561728 4290682783 4291611852 4291611852 4291743438 4293190884 4294046193 4293848814 4291204501 4287561728 4287561728 4287561728 4287561728 4288092441 4291545802 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4287245356 4288387224 4285229931 4285624689 4285624689 4283585106 4278716424 4284637794 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287664272 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4282532418 4283321934 4285624689 4285624689 4285624689 4285624689 4286348412 4287569438 4290815654 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291412674 4290814626 4291147446 4291279803 4290615962 4287561728 4291146932 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4287640628 4286348412 4285624689 4285624689 4285624689 4285624689 4283321934 4282532418 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287664272 0 0 0 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4282269246 4285624689 4285624689 4285624689 4285624689 4285624689 4286414205 4287516495 4290947497 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4290881447 4289420637 4289420380 4289420380 4289089359 4287561728 4291345853 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4287642941 4286414205 4285624689 4285624689 4285624689 4285624689 4285624689 4282269246 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 0 4287532686 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4282203453 4285624689 4285624689 4285624689 4285624689 4285624689 4286282619 4287451473 4290947497 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4289354330 4288026391 4288823874 4288823874 4288823874 4289288280 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4287511869 4286282619 4285624689 4285624689 4285624689 4285624689 4285624689 4282203453 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287532686 0 0 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4282335039 4283782485 4285624689 4285624689 4285624689 4285624689 4286019447 4287505701 4290881190 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4289022795 4288956231 4291611595 4291611852 4291479238 4291280060 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4287247155 4286019447 4285624689 4285624689 4285624689 4285624689 4283782485 4282335039 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 4287401100 0 0 4287401100 4287401100 4287401100 4287401100 4287927444 4289440683 4289572269 4289572269 4289572269 4289572269 4284703587 4279111182 4284308829 4285624689 4285624689 4285493103 4287335050 4287430656 4290682526 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4289686636 4287561728 4287628035 4287694599 4287561728 4287760649 4291611338 4291611852 4291611852 4291611852 4291611852 4291611852 4291480266 4286655018 4287335050 4285493103 4285624689 4285624689 4284308829 4279111182 4284703587 4289572269 4289572269 4289572269 4289572269 4289440683 4287927444 4287401100 4287401100 4287401100 4287401100 0 0 4287401100 4287401100 4287401100 4287401100 4289374890 0 0 0 0 0 0 4278190081 4278321666 4279966491 4280558628 4279703319 4288980132 4286907910 4290417298 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611595 4291014318 4290615962 4290549141 4290284170 4287561728 4291147446 4291611852 4291611852 4291611852 4291611852 4291611852 4290690750 4286390818 4288980132 4279703319 4280558628 4279966491 4278321666 4278190081 0 0 0 0 0 0 4289374890 4287401100 4287401100 4287401100 4287401100 0 0 4287401100 4287401100 4287401100 4287401100 4289374890 0 0 0 0 0 0 4278716424 4278190081 4278190081 4278190081 4278584838 4288980132 4286255120 4290085763 4291611852 4291611852 4290682526 4288955974 4289487715 4289952121 4290217606 4290217863 4290084478 4289686636 4289022538 4287561728 4291214010 4291611852 4291611852 4291611852 4291611852 4291546059 4289374890 4286125847 4288980132 4278584838 4278190081 4278190081 4278190081 4278716424 0 0 0 0 0 0 4289374890 4287401100 4287401100 4287401100 4287401100 0 0 4287401100 4287401100 4287401100 4287401100 4289374890 0 0 0 0 0 0 4282006074 4278190081 4278190081 4278190081 4278321666 4288980132 4286258204 4288570725 4291611852 4291611852 4288690232 4288424490 4288756539 4288292390 4288092698 4288026648 4288225569 4288557618 4289022538 4289886071 4291611852 4291611852 4291611852 4291611852 4291611852 4290295992 4288980132 4285860105 4288980132 4278321666 4278190081 4278190081 4278190081 4282006074 0 0 0 0 0 0 4289374890 4287401100 4287401100 4287401100 4287401100 0 0 4287401100 4287401100 4287401100 4287401100 4289374890 0 0 0 0 0 0 0 4278190081 4278190081 4278190081 4278190081 4288453788 4286655789 4287188044 4290624957 4291611852 4288491054 4289221459 4291213496 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291479238 4290947497 4290881190 4290690750 4288980132 4288847518 4285726720 4288453788 4278190081 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 4289374890 4287401100 4287401100 4287401100 4287401100 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4280032284 4278190081 4278190081 4278190081 4287795858 4286922559 4286855224 4288980132 4290427578 4290217349 4287694342 4287561728 4287694599 4288093212 4288425004 4288624182 4288690232 4288557618 4288357926 4287894034 4287561985 4287561728 4286974217 4288913311 4288980132 4288515212 4285726720 4287795858 4278190081 4278190081 4278190081 4280032284 0 0 0 0 0 0 0 4289374890 4287401100 4287401100 4287401100 4287401100 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190081 4278190081 4278190081 4287137928 4287386708 4286391075 4288980132 4288980132 4289703855 4291150787 4291014318 4290549141 4290150785 4289819250 4289685865 4289619815 4289752429 4289952121 4290284170 4290485918 4289371292 4285792770 4288117113 4288980132 4288050806 4285858820 4287137928 4278190081 4278190081 4278190081 0 0 0 0 0 0 0 0 4289374890 4287401100 4287401100 4287401100 4287401100 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4281742902 4278190081 4278190081 4286414205 4287851885 4285858820 4286656046 4287054402 4287386708 4287718243 4288641144 4289695631 4290486689 4290948525 4291081139 4291147189 4290751917 4290027423 4289105036 4288182392 4287851628 4285859591 4286656303 4286855224 4286191897 4286257690 4286414205 4278190081 4278190081 4281742902 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 4279505940 4278190081 4285558896 4288780954 4287784550 4287320144 4286921788 4286589739 4286257947 4285992462 4285792770 4285726720 4285726720 4285792256 4285726720 4285726720 4285726720 4285726720 4285859848 4286125076 4286390818 4286722867 4287120966 4287519579 4288183677 4285558896 4278190081 4279505940 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 4278848010 4282137660 4285361517 4286151033 4286940549 4287598479 4288190616 4288651167 4288980132 4288980132 4288847775 4288780697 4288648340 4288648083 4288648854 4288846747 4288979618 4288980132 4288848546 4288453788 4287861651 4287269514 4286545791 4285822068 4282137660 4278848010 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 4278584838 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278321666 4278650631 4278913803 4279111182 4279374354 4279374354 4279308561 4279111182 4278848010 4278519045 4278255873 4278190081 4278190081 4278190081 4278190081 4278190081 4278584838 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!PhotoresistorMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 16:13'!
isAnalog
^true! !

!PhotoresistorMorph class methodsFor: 'connectors' stamp: 'Richo 9/8/2009 16:13'!
newConnector
^ (ArduinoWireMorph new) beOrthogonal: false;
				 beSmoothCurve: true;
				 lineColor: Color gray;
				 lineWidth: 4;
				 borderWidth: 1;
				 borderColor: Color gray; yourself! !

!PhotoresistorMorph class methodsFor: 'connectors' stamp: 'Richo 9/8/2009 16:13'!
newConnectorFromMorph: m1 toMorph: m2 
^ (ArduinoWireMorph fromMorph: m1 toMorph: m2) beOrthogonal: false;
				 beSmoothCurve: true;
				 lineColor: Color gray;
				 lineWidth: 4;
				 borderWidth: 1;
				 borderColor: Color gray; yourself! !

!PhotoresistorMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:00'!
attachmentPointBorderColor
^Color gray! !

!PhotoresistorMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:01'!
attachmentPointCenter
	^ self center + (26 @ 12)! !

!PhotoresistorMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:01'!
attachmentPointColor
	^ Color gray! !

!PhotoresistorMorph methodsFor: 'accessing' stamp: 'Richo 9/8/2009 16:16'!
value
	^ [device value] on: Error do: [-1]! !

AttachableDeviceMorph subclass: #PotentiometerMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

PotentiometerMorph class
	instanceVariableNames: 'form'!

!PotentiometerMorph commentStamp: 'Richo 9/15/2009 13:03' prior: 0!
I am the Etoys of a potentiometer.!

PotentiometerMorph class
	instanceVariableNames: 'form'!

!PotentiometerMorph class methodsFor: 'viewer categories' stamp: 'Richo 9/21/2009 13:07'!
additionsToViewerCategories
	^ #(#(#'potentiometer' #(#(#slot #value '' #Number #readOnly #Player #getPotentiometerValue #Player #unused))) )! !

!PotentiometerMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/11/2009 17:50'!
defaultNameStemForInstances
^'Potentiometer'! !

!PotentiometerMorph class methodsFor: 'parts bin' stamp: 'Richo 9/11/2009 17:51'!
descriptionForPartsBin
	"Answer a description for use in parts bins"

	^ self partName: 	'Potentiometer'
		categories:		{'Electronics' }
		documentation:	''! !

!PotentiometerMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/14/2009 16:00'!
device
^Potentiometer! !

!PotentiometerMorph class methodsFor: 'form' stamp: 'Richo 9/11/2009 17:43'!
form
^form ifNil: [self initializeForm]! !

!PotentiometerMorph class methodsFor: 'form' stamp: 'Richo 9/11/2009 17:43'!
initializeForm
^form := (Form
	extent: 64@119
	depth: 32
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4281742902 4279045389 4279045389 4279242768 4278979596 4279440147 4278979596 4279176975 4279505940 4278979596 4279637526 4278979596 4279308561 4279111182 4279176975 4279045389 4279111182 4283453520 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4281940281 4279111182 4279571733 4279374354 4280229663 4279176975 4281479730 4278979596 4280953386 4281019179 4278979596 4282335039 4279571733 4279703319 4280821800 4279111182 4280492835 4279242768 4279440147 4282400832 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284637794 4280427042 4280756007 4281216558 4281479730 4281479730 4282335039 4282335039 4281216558 4283453520 4283124555 4281348144 4283453520 4282927176 4281479730 4282400832 4281808695 4281545523 4281677109 4280624421 4281019179 4283387727 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284440415 4282006074 4280295456 4280953386 4281348144 4281808695 4283716692 4283321934 4278716424 4283519313 4284637794 4279505940 4283519313 4284703587 4280558628 4282400832 4283256141 4283256141 4283190348 4282137660 4282532418 4282137660 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4286479998 4286019447 4286019447 4281808695 4280492835 4279374354 4279834905 4280032284 4280295456 4281413937 4281216558 4278519045 4281282351 4281808695 4279111182 4281084972 4281545523 4279703319 4280427042 4280624421 4280558628 4280492835 4280098077 4280229663 4280032284 4280887593 4280492835 4280098077 4280361249 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4283585106 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279505940 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4280756007 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279242768 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282532418 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278979596 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282269246 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279505940 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4281150765 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279045389 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4283453520 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279308561 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4281150765 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279440147 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4281940281 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278913803 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4283058762 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279440147 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4280821800 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279176975 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282729797 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4279045389 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4283190348 4281808695 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281874488 4281808695 4282071867 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282466625 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4282992969 4283321934 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283782485 4281216558 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281216558 0 0 0 0 0 0 0 0 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4282071867 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4282795590 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 0 0 0 0 0 0 0 0 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4282006074 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4282795590 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 0 0 0 0 0 0 0 0 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4282598211 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283519313 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 0 0 0 0 0 0 0 0 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4283124555 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4284111450 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 0 0 0 0 0 0 0 0 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4282006074 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4282795590 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 0 0 0 0 0 0 0 0 4281808695 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4282664004 4283256141 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283453520 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 4281150765 0 0 0 0 0 0 0 0 4289901234 4285624689 4284111450 4284045657 4284045657 4284045657 4283519313 4283585106 4284045657 4284045657 4284111450 4285164138 4287664272 4285361517 4282598211 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282992969 4283058762 4282729797 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4282664004 4283519313 4287795858 4285953654 4284177243 4283979864 4283979864 4283782485 4283453520 4283782485 4283979864 4283979864 4283979864 4284637794 4288387995 0 0 0 0 0 0 4286414205 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 4283190348 0 0 0 0 4289440683 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4288585374 4287335307 4285032552 4285032552 4285032552 4285032552 4285032552 4285032552 4285032552 4285032552 4284703587 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4283585106 4284769380 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287664272 4287795858 0 0 0 0 4288914339 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288387995 4286479998 4286479998 4286479998 4286479998 4286479998 4286479998 4286479998 4286479998 4286479998 4286479998 4286479998 4286479998 4286677377 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4286874756 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284900966 4285690482 4285690482 4285690482 4285690482 4285690482 4285690482 4285690482 4285690482 4285690482 4285690482 4285427310 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284703587 4284835173 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288256409 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286347384 4286347384 4286347384 4286347384 4286216826 4286545791 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287730065 4287335307 4286216826 4286216826 4286216826 4286347384 4286347384 4286347384 4286347384 4286282362 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286282105 4286347384 4286347384 4286347384 4286282105 4286216826 4286216826 4286216826 4286216826 4286216826 4286216826 4286414205 0 0 0 0 4288519581 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4288570725 4292615453 4292289058 4292289058 4292615710 4289028192 4286940549 4287137928 4287137928 4287137928 4287137928 4287137928 4287137928 4287137928 4287137928 4287137928 4287137928 4287006342 4286874756 4286874756 4287723126 4292223779 4292289058 4292289058 4292419616 4290397509 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4286874756 4287201151 4291636525 4292289058 4292289058 4292289058 4291572017 4287005057 4286874756 4286874756 4286874756 4286874756 4286874756 4287006342 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 4294901760 4294901760 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293013295 4291901753 4291901753 4291901753 4293407796 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293207333 4292815145 4292815145 4292815145 4293404712 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293207333 4292815145 4292815145 4292815145 4293404712 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293207333 4292815145 4292815145 4292815145 4293404712 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!PotentiometerMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/11/2009 17:49'!
isAnalog
^true! !

!PotentiometerMorph class methodsFor: 'connectors' stamp: 'Richo 9/11/2009 17:49'!
newConnector
	^ ArduinoWireMorph new beOrthogonal: false;
		 beSmoothCurve: true;
		 lineColor: Color red;
		 lineWidth: 4;
		 borderWidth: 1;
		 borderColor: Color gray;
		 yourself! !

!PotentiometerMorph class methodsFor: 'connectors' stamp: 'Richo 9/11/2009 17:49'!
newConnectorFromMorph: m1 toMorph: m2 
	^ (ArduinoWireMorph fromMorph: m1 toMorph: m2) beOrthogonal: false;
		 beSmoothCurve: true;
		 lineColor: Color red;
		 lineWidth: 4;
		 borderWidth: 1;
		 borderColor: Color gray;
		 yourself! !

!PotentiometerMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:01'!
attachmentPointBorderColor
	^ Color gray! !

!PotentiometerMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:01'!
attachmentPointCenter
	^ self center + (1 @ 63)! !

!PotentiometerMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:01'!
attachmentPointColor
	^ Color red! !

!PotentiometerMorph methodsFor: 'accessing' stamp: 'Richo 9/14/2009 16:02'!
value
	^ [device value] on: Error do: [-1]! !

AttachableDeviceMorph subclass: #ServoMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Etoys-Devices'!

ServoMorph class
	instanceVariableNames: 'form'!

!ServoMorph commentStamp: 'Richo 9/15/2009 13:03' prior: 0!
I am the Etoys of a servo.!

ServoMorph class
	instanceVariableNames: 'form'!

!ServoMorph class methodsFor: 'viewer categories' stamp: 'Richo 9/14/2009 15:52'!
additionsToViewerCategories
^ #(
(#'servo' (
#(slot degrees '' Number readWrite Player getDegrees Player setDegrees:  )
))

)! !

!ServoMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/4/2009 18:11'!
defaultNameStemForInstances
^'Servo'! !

!ServoMorph class methodsFor: 'parts bin' stamp: 'Richo 8/24/2009 17:34'!
descriptionForPartsBin
	"Answer a description for use in parts bins"

	^ self partName: 	'Servo'
		categories:		{'Electronics' }
		documentation:	''! !

!ServoMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/11/2009 17:45'!
device
^Servo! !

!ServoMorph class methodsFor: 'form' stamp: 'Richo 9/1/2009 10:51'!
form

	^ form
		ifNil: [self initializeForm]! !

!ServoMorph class methodsFor: 'form' stamp: 'Richo 9/1/2009 10:51'!
initializeForm
	^ form := (Form
	extent: 159@156
	depth: 32
	fromArray: #( 0 0 0 0 0 0 0 0 0 4292203989 4293256677 4293980400 4294243572 4294243572 4293980400 4293454056 4292796126 4291940817 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291875024 4293914607 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294243572 4293059298 4291875024 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291940817 4294506744 4294967295 4294967295 4294967295 4294967295 4293980400 4293256677 4293059298 4293125091 4293717228 4294769916 4294967295 4294967295 4294901502 4293717228 4292269782 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293914607 4294967295 4294967295 4294506744 4292335575 0 0 0 0 0 0 0 4292006610 4293914607 4294967295 4294967295 4294967295 4294111986 4292598747 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291940817 4294967295 4294967295 4294440951 4291677645 0 0 0 0 0 0 0 0 0 0 4293454056 4294967295 4294967295 4294967295 4294967295 4294506744 4293059298 4291809231 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292532954 4294967295 4294967295 4292730333 0 0 0 0 0 0 0 0 0 0 0 4292006610 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294769916 4293519849 4292072403 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292598747 4294967295 4294967295 4294046193 0 0 0 0 0 0 0 0 0 0 0 4293125091 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4293914607 4292467161 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292072403 4294967295 4294967295 4294967295 4293848814 4291940817 0 0 0 0 0 0 0 4291677645 4293190884 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294309365 4292861919 4291677645 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294177779 4294967295 4294967295 4294967295 4294901502 4293914607 4293125091 4292664540 4292467161 4292532954 4292927712 4293651435 4294704123 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294638330 4293256677 4291875024 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292401368 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294835709 4293585642 4292138196 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292796126 4294901502 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4293980400 4292467161 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292269782 4294440951 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294243572 4292730333 4291677645 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291809231 4293848814 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294506744 4292993505 4291743438 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4293190884 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294638330 4293190884 4291809231 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292532954 4294769916 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294769916 4293322470 4291809231 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292072403 4294440951 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294769916 4293322470 4291809231 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291809231 4293980400 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294704123 4293125091 4291677645 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291677645 4293388263 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294177779 4290690750 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4288914339 4289638062 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292796126 4294835709 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4292467161 4288651167 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289572269 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292269782 4294638330 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294309365 4293519849 4293125091 4293125091 4293454056 4294177779 4294901502 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4293980400 4289309097 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289572269 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291940817 4294243572 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294704123 4292467161 4290361785 4288782753 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288585374 4290098613 4292203989 4294506744 4294967295 4294967295 4294967295 4294967295 4294440951 4289638062 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289572269 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290493371 4290427578 4291611852 4291743438 4293717228 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294901502 4292072403 4288782753 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288519581 4291546059 4294769916 4294967295 4294967295 4294967295 4294440951 4289243304 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289572269 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290493371 4288256409 4288256409 4289769648 4291546059 4291611852 4293125091 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294769916 4290230199 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289638062 4294440951 4294967295 4294967295 4294967295 4293783021 4288453788 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289572269 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290493371 4288256409 4288256409 4288256409 4288256409 4289177511 4291414473 4291611852 4292598747 4294769916 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4290953922 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4290098613 4294967295 4294967295 4294967295 4294967295 4291282887 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289572269 4291546059 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291085508 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288782753 4291085508 4291611852 4292138196 4294506744 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294440951 4288322202 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4293651435 4294967295 4294967295 4294967295 4294243572 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4290098613 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288519581 4290690750 4291611852 4291809231 4294046193 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4293059298 4288059030 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4291677645 4294967295 4294967295 4294967295 4294967295 4289309097 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288322202 4290164406 4291611852 4291677645 4293454056 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4292993505 4286019447 4288190616 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4286414205 4290427578 4294967295 4294967295 4294967295 4294967295 4290493371 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387734 4289700994 4289700994 4289700994 4289700994 4289700994 4289700994 4289700994 4288584852 4288781713 4289700994 4289700994 4289700994 4289700994 4289700994 4289700994 4289700994 4289700994 4288913040 4288453526 4289700994 4289700994 4289700994 4289700994 4289700994 4289700994 4289700994 4288519060 4288256409 4288256409 4289569668 4289700994 4289700994 4288256408 4288256409 4288387736 4289700994 4289700994 4289569670 4288256409 4288256409 4288584596 4289700994 4289700994 4289700994 4289700994 4289700994 4289175691 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289572269 4291546059 4291611852 4292796126 4294835709 4294967295 4294967295 4294967295 4294967295 4294967295 4294506744 4285098345 4285887861 4287993237 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288059030 4286151033 4284900966 4292532954 4294967295 4294967295 4294967295 4294967295 4290164406 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288913040 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4289635460 4290554486 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4291079790 4288978574 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4289503878 4288256409 4288256409 4294363196 4294954035 4294954035 4288387736 4288256409 4288650386 4294954035 4294954035 4294034753 4288256409 4288256409 4289700994 4294954035 4294954035 4294954035 4294954035 4294954035 4292458841 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288980132 4291282887 4291611852 4292269782 4294572537 4294967295 4294967295 4294967295 4294967295 4294967295 4289638062 4284900966 4285032552 4286479998 4287730065 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4287861651 4286611584 4285164138 4284900966 4287401100 4294901502 4294967295 4294967295 4294967295 4294572537 4289440683 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4291145580 4293575240 4294954035 4291670884 4289832321 4289832321 4289832321 4289832321 4289832321 4288584596 4290554486 4294954035 4294954035 4292852820 4289832321 4289832321 4289832321 4289832321 4289832321 4288913038 4288978574 4294954035 4294954035 4293969218 4289832321 4289832321 4291276906 4294954035 4293706310 4291539558 4288256409 4294363196 4294954035 4294954035 4288387736 4288256409 4288650386 4294954035 4294954035 4294034753 4288256409 4291736676 4293772101 4294954035 4291145582 4289832321 4289832321 4294100288 4294428732 4293378122 4288781714 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288651167 4290888129 4291611852 4291875024 4294111986 4294967295 4294967295 4294967295 4294967295 4294835709 4289045925 4284900966 4284900966 4284900966 4285427310 4286151033 4286743170 4287072135 4287203721 4287203721 4287072135 4286743170 4286151033 4285427310 4284900966 4284900966 4284900966 4287401100 4294309365 4294967295 4294967295 4294967295 4294967295 4292927712 4289374890 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4290948720 4293181006 4294954035 4291933536 4290226298 4290226298 4290226298 4289700994 4288256409 4288256409 4290554486 4294954035 4294954035 4292984144 4290226298 4290226298 4290226298 4290226300 4288256409 4288256409 4288978574 4294954035 4294954035 4293640776 4288256409 4288256409 4290160764 4294954035 4294954035 4292590168 4288256409 4292590168 4293903428 4294954035 4290357626 4290226298 4290554486 4294954035 4293772100 4292327515 4288256409 4292787284 4294954035 4294954035 4289963648 4288256409 4288256409 4293837892 4294954035 4294954035 4288913040 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288322202 4290361785 4291611852 4291677645 4293454056 4294967295 4294967295 4294967295 4294967295 4294967295 4292072403 4286808963 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4285953654 4290756543 4294835709 4294967295 4294967295 4294967295 4294967295 4293914607 4291611852 4288914339 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288913040 4294954035 4294954035 4294954035 4294954035 4294954035 4293181006 4288256409 4288256409 4290554486 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4294756918 4288256409 4288256409 4288978574 4294954035 4294954035 4293640776 4288256409 4288256409 4290160764 4294954035 4294954035 4292590168 4288256409 4288256409 4291211372 4294954035 4294954035 4294954035 4294954035 4294954035 4291014256 4288256409 4288256409 4292787284 4294954035 4294954035 4289963648 4288256409 4288256409 4293837892 4294954035 4294954035 4288913040 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289638062 4291546059 4291611852 4292664540 4294769916 4294967295 4294967295 4294967295 4294967295 4294901502 4292927712 4289769648 4287401100 4285690482 4284900966 4284900966 4284900966 4284900966 4285361517 4286940549 4289177511 4292138196 4294835709 4294967295 4294967295 4294967295 4294967295 4294967295 4293980400 4291743438 4291151301 4288322202 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387736 4289307017 4289307017 4289307017 4289307017 4293378122 4294691382 4293903426 4289438344 4290554486 4294954035 4294954035 4292590167 4289307017 4289307017 4289307017 4289307018 4288256409 4288256409 4288978574 4294954035 4294954035 4294756918 4293903426 4293903426 4294231614 4294954035 4290357624 4288913038 4288256409 4288256409 4291211372 4294954035 4294954035 4294954035 4294954035 4294954035 4291014256 4288256409 4288256409 4292787284 4294954035 4294954035 4289963648 4288256409 4288256409 4293837892 4294954035 4294954035 4288913040 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289045925 4291348680 4291611852 4292006610 4294111986 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294638330 4294046193 4293980400 4294440951 4294901502 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4293322470 4291677645 4291611852 4289374890 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289700996 4290751602 4290751602 4290751602 4290751602 4290751602 4293772100 4294297404 4292458841 4289109900 4290554486 4294954035 4294954035 4293246798 4290751602 4290751602 4290751602 4290751602 4290751602 4289307016 4288978574 4294954035 4294954035 4294494522 4292458841 4294297404 4294954035 4294954035 4291539558 4289898112 4288256409 4288256409 4290094973 4292458841 4294954035 4294954035 4294822709 4292458841 4289963647 4288256409 4288256409 4291079790 4292984144 4294954035 4291802210 4290751602 4290751602 4294297406 4294034753 4292458841 4288650387 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288585374 4290822336 4291611852 4291611852 4292664540 4294309365 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294243572 4292335575 4291611852 4291611852 4290032820 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4292064864 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4293181006 4288256409 4288256409 4290554486 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4294954035 4291079790 4288978574 4294954035 4294954035 4293640776 4288256409 4293181006 4294954035 4294954035 4294954035 4292590168 4288256409 4288256409 4288256409 4288256409 4294888500 4294954035 4294560057 4288256409 4288256409 4288256409 4288256409 4288256409 4289700994 4294954035 4294954035 4294954035 4294954035 4294954035 4292458841 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288322202 4290032820 4291611852 4291611852 4291611852 4292335575 4293519849 4294572537 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294901502 4293980400 4292532954 4291611852 4291611852 4291480266 4289572269 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288584852 4288781713 4288781713 4288781713 4288781713 4288781713 4288781713 4288650387 4288256409 4288256409 4288453526 4288781713 4288781713 4288781713 4288781713 4288781713 4288781713 4288781713 4288781713 4288519062 4288321944 4288781713 4288781713 4288650386 4288256409 4288650387 4288781713 4288781713 4288781713 4288584596 4288256409 4288256409 4288256409 4288256409 4288781713 4288781713 4288781714 4288256409 4288256409 4288256409 4288256409 4288256409 4288387735 4288781713 4288781713 4288781713 4288781713 4288781713 4288584596 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289045925 4290888129 4291611852 4291611852 4291611852 4291611852 4292138196 4292861919 4293519849 4293980400 4294309365 4294440951 4294440951 4294243572 4293914607 4293388263 4292664540 4291809231 4291611852 4291611852 4291546059 4290361785 4288651167 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289045925 4290361785 4291414473 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291611852 4291282887 4290098613 4288716960 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290888129 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288322202 4289111718 4289835441 4290493371 4291019715 4291348680 4291611852 4291611852 4291611852 4291414473 4291085508 4290559164 4289835441 4289045925 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290690750 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288322202 4288322202 4288322202 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4289835441 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288124823 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288124823 4285361517 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288059030 4285361517 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288059030 4285361517 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288059030 4285361517 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288124823 4285361517 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4284440415 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288124823 4285361517 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4286019447 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4289638062 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4286743170 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287335307 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288453788 4288651167 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4286611584 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287269514 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4286611584 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287269514 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4286611584 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287269514 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4286677377 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287335307 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4283124555 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4286019447 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4283124555 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4285887861 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4283124555 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4285887861 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4283124555 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4285887861 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4283124555 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4285953654 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4283124555 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4285953654 4288124823 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288190616 4283124555 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286611584 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288256409 4288387995 0 0 0 0 0 0 0 0 0 0 0 0 4286019447 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4282466625 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4282992969 4283256141 0 0 0 0 0 0 0 0 0 0 0 0 4285295724 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4282006074 0 0 0 0 0 0 0 0 0 0 0 0 4288585374 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4285756275 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4282269246 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4284966759 4285756275 4285756275 4285756275 4285756275 4285756275 4285756275 4286216826 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286743170 4286940549 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4289440574 4294309159 4293848643 4293322342 4292598670 4291875005 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4289572150 4294967040 4294967040 4294967040 4294967040 4294967040 4294309158 4293322339 4292269734 4291611851 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4289572150 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294374946 4293059188 4291809217 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4289505849 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294769675 4293322338 4291809215 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4289541686 4294905344 4294914304 4294925824 4294745611 4294761997 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294769678 4292993398 4291677642 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4289541686 4294901760 4294901760 4294901760 4294901760 4294901760 4294908160 4294928384 4294823434 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294243372 4292138157 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4289541686 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294912768 4294877958 4294966530 4294967040 4294967040 4294967040 4294967040 4294835464 4292796035 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4285938748 4288679695 4290712082 4293005071 4294771202 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294910720 4294817289 4294967040 4294967040 4294967040 4294967040 4294967040 4293322338 4291611851 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4281742902 4278190081 4278190081 4278190081 4278714368 4282253312 4288484886 4293857810 4294901760 4294901760 4294901760 4294901760 4294901760 4294921729 4294832650 4294967040 4294967040 4294967040 4294967040 4293585493 4291611851 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4281742902 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278321152 4284159510 4293207333 4294901760 4294901760 4294901760 4294901760 4294907648 4294628370 4294967040 4294967040 4294967040 4294967040 4293388126 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4281940281 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278255616 4287577662 4294578963 4294901760 4294901760 4294901760 4294903552 4294493211 4294967040 4294967040 4294967040 4294967040 4292927614 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 4291217094 4289440683 4286808963 4283190348 4278913803 4278190081 4278190081 4278190081 4278190081 4278190081 4283579452 4294061614 4294901760 4294901760 4294901760 4294902784 4294365478 4294967040 4294967040 4294967040 4294901254 4292203945 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 4291019715 4285756275 4279242768 4278190081 4278190081 4278190081 4278190081 4283582793 4293998391 4294901760 4294901760 4294901760 4294839300 4294372388 4294967040 4294967040 4294967040 4294309159 4291677641 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 4290624957 4282335039 4278190081 4278190081 4278190081 4278190081 4286542450 4294320931 4294901760 4294901760 4294901760 4294264361 4294769676 4294967040 4294967040 4294967040 4292993399 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 4291480266 4283585106 4278190081 4278190081 4278190081 4278716424 4290877592 4294837509 4294901760 4294901760 4294901760 4293507414 4294967040 4294967040 4294967040 4294638098 4291743427 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 4291480266 4281940281 4278190081 4278190081 4278190081 4283124555 4293354082 4294901760 4294901760 4294901760 4294127662 4294309159 4294967040 4294967040 4294967040 4292993400 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 4290164406 4278782217 4278190081 4278190081 4278321666 4290291623 4294773258 4294901760 4294901760 4294901760 4293051764 4294967040 4294967040 4294967040 4294374946 4291611851 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 4284506208 4278190081 4278190081 4278190081 4284769380 4293547092 4294901760 4294901760 4294901760 4293289828 4294572313 4294967040 4294967040 4294967040 4292269734 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 4290032820 4278190081 4278190081 4278190081 4280163870 4292385948 4294901760 4294901760 4294901760 4294191658 4293388130 4294967040 4294967040 4294967040 4293256552 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 4281084972 4278190081 4278190081 4278190081 4289900463 4294708493 4294901760 4294901760 4294902274 4292464793 4294967040 4294967040 4294967040 4294177585 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 4284506208 4278190081 4278190081 4278190081 4286808963 4293933883 4294901760 4294901760 4294901760 4292386459 4294835466 4294967040 4294967040 4294835463 4291677641 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 4287137928 4278190081 4278190081 4278190081 4284374622 4293353825 4294901760 4294901760 4294901760 4292836990 4294177586 4294967040 4294967040 4294967040 4292072366 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 4289111718 4278190081 4278190081 4278190081 4282532418 4292902526 4294901760 4294901760 4294901760 4293289317 4293651282 4294967040 4294967040 4294967040 4292598673 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 4290493371 4278190081 4278190081 4278190081 4281216558 4292514450 4294901760 4294901760 4294901760 4293547092 4293256553 4294967040 4294967040 4294967040 4292927613 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4287993237 0 0 0 0 0 0 0 0 0 0 0 4291282887 4278190081 4278190081 4278190081 4280361249 4292321183 4294901760 4294901760 4294901760 4293740359 4292993400 4294967040 4294967040 4294967040 4293124974 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288651167 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4284900966 4288059030 0 0 0 0 0 0 0 0 0 0 0 0 4278255873 4278190081 4278190081 4279900698 4292257446 4294901760 4294901760 4294901760 4293870146 4292861823 4294967040 4294967040 4294967040 4293256552 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4282729797 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4284900966 4285756275 4290822336 0 0 0 0 0 0 0 0 0 0 0 4291480266 4278190081 4278190081 4278190081 4280032284 4292257189 4294901760 4294901760 4294901760 4293804610 4292861824 4294967040 4294967040 4294967040 4293256552 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4282729797 4278190081 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4284900966 4285756275 4290822336 0 0 0 0 0 0 0 0 0 0 0 0 4290690750 4278190081 4278190081 4278190081 4280756007 4292386205 4294901760 4294901760 4294901760 4293740616 4292927612 4294967040 4294967040 4294967040 4293190762 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4282729797 4278190081 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4284900966 4285756275 4290822336 0 0 0 0 0 0 0 0 0 0 0 0 0 4289111718 4278190081 4278190081 4278190081 4282137660 4292643723 4294901760 4294901760 4294901760 4293482070 4293059187 4294967040 4294967040 4294967040 4293059186 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4282729797 4278190081 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4284900966 4285756275 4290822336 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4286743170 4278190081 4278190081 4278190081 4284111450 4293030771 4294901760 4294901760 4294901760 4293224552 4293256551 4294967040 4294967040 4294967040 4292927612 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4282729797 4278190081 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4284900966 4285756275 4290756543 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4283650899 4278190081 4278190081 4278190081 4286743170 4293612114 4294901760 4294901760 4294901760 4292772739 4293519702 4294967040 4294967040 4294967040 4292664458 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4282729797 4278190081 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286085240 4285756275 4290756543 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291546059 4279769112 4278190081 4278190081 4278190081 4290032820 4294256680 4294901760 4294901760 4294901760 4292256418 4293914433 4294967040 4294967040 4294967040 4292401308 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4282729797 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4281545523 4286479998 4290756543 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288322202 4278190081 4278190081 4278190081 4280558628 4291805119 4294836738 4294901760 4294901760 4294836995 4291741382 4294309160 4294967040 4294967040 4294967040 4292072369 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291414473 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4289901234 4290953922 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282729797 4278190081 4278190081 4278190081 4285295724 4292708231 4294901760 4294901760 4294901760 4294192172 4291611851 4294769674 4294967040 4294967040 4294967042 4291677640 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4289506476 4278321666 4278190081 4278190081 4278453252 4290361785 4293804867 4294901760 4294901760 4294901760 4293353825 4292006580 4294967040 4294967040 4294967040 4294506523 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282269246 4278190081 4278190081 4278190081 4283321934 4291870141 4294837509 4294901760 4294901760 4294901760 4292386462 4292664461 4294967040 4294967040 4294967040 4293980220 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4287532686 4278190081 4278190081 4278190081 4278453252 4289835441 4293160558 4294901760 4294901760 4294901760 4294514455 4291611338 4293388130 4294967040 4294967040 4294967040 4293322338 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290427578 4279374354 4278190081 4278190081 4278190081 4284243036 4291675846 4294579734 4294901760 4294901760 4294901760 4293353825 4291611852 4294111794 4294967040 4294967040 4294967040 4292664458 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291480266 4281808695 4278190081 4278190081 4278190081 4279637526 4290953922 4293031542 4294901760 4294901760 4294901760 4294902274 4292063922 4291743428 4294901253 4294967040 4294967040 4294967040 4291940790 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284243036 4278190081 4278190081 4278190081 4278190081 4287993237 4291805633 4294643985 4294901760 4294901760 4294901760 4293804867 4291611852 4292598673 4294967040 4294967040 4294967040 4294506524 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4285953654 4278190081 4278190081 4278190081 4278190081 4284374622 4291611852 4293417819 4294901760 4294901760 4294901760 4294901760 4292191910 4291611852 4293585492 4294967040 4294967040 4294967040 4293585490 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4286808963 4278255873 4278190081 4278190081 4278190081 4281611316 4291414473 4292257446 4294836738 4294901760 4294901760 4294901760 4293805381 0 4291611850 4294638101 4294967040 4294967040 4294967040 4292664460 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4286940549 4278321666 4278190081 4278190081 4278190081 4280163870 4290624957 4291676103 4294256423 4294901760 4294901760 4294901760 4294837766 4292063922 0 4292401308 4294967040 4294967040 4294967040 4294901254 4291743426 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4286479998 4278321666 4278190081 4278190081 4278190081 4279440147 4289835441 4291611852 4293288546 4294901760 4294901760 4294901760 4294901760 4293289574 0 0 4293585491 4294967040 4294967040 4294967040 4293980222 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4285558896 4278190081 4278190081 4278190081 4278190081 4279111182 4289243304 4291611852 4292385434 4294902274 4294901760 4294901760 4294901760 4294385696 4291675846 0 4291743430 4294769677 4294967040 4294967040 4294967040 4292796036 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291480266 4284308829 4278190081 4278190081 4278190081 4278190081 4279176975 4289111718 4291611852 4291869884 4294579734 4294901760 4294901760 4294901760 4294836738 4292321697 0 0 4292796038 4294967040 4294967040 4294967040 4294835465 4291743427 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4291217094 4282729797 4278190081 4278190081 4278190081 4278190081 4279440147 4289309097 0 4291611338 4293933626 4294901760 4294901760 4294901760 4294901760 4293224038 0 0 0 4294046006 4294967040 4294967040 4294967040 4293717069 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290493371 4281216558 4278190081 4278190081 4278190081 4278190081 4279966491 4289769648 0 0 4293224295 4294901760 4294901760 4294901760 4294901760 4294128178 4291676617 0 0 4292072367 4294967040 4294967040 4294967040 4294967040 4292401307 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4289440683 4279900698 4278190081 4278190081 4278190081 4278190081 4280821800 4290361785 0 0 4292514707 4294902017 4294901760 4294901760 4294901760 4294644242 4291933878 0 0 0 4293453918 4294967040 4294967040 4294967040 4294440737 4291611851 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288256409 4279045389 4278190081 4278190081 4278190081 4278190081 4282137660 4290953922 0 0 4291998900 4294643214 4294901760 4294901760 4294901760 4294836738 4292450970 0 0 0 4291743430 4294703887 4294967040 4294967040 4294967040 4293059188 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4286940549 4278453252 4278190081 4278190081 4278190081 4278190081 4283848278 4291414473 0 0 4291676103 4294192172 4294901760 4294901760 4294901760 4294901760 4293031028 0 0 0 0 4292796035 4294967040 4294967040 4294967040 4294835465 4291809216 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4285756275 4278190081 4278190081 4278190081 4278190081 4278321666 4285822068 0 0 0 0 4293418333 4294901760 4294901760 4294901760 4294901760 4293676108 4291611595 0 0 0 0 4294177586 4294967040 4294967040 4294967040 4293585491 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4285098345 4278190081 4278190081 4278190081 4278190081 4278716424 4287532686 0 0 0 0 4292515478 4294901760 4294901760 4294901760 4294901760 4294257194 4291741382 0 0 0 0 4292072367 4294967040 4294967040 4294967040 4294967040 4292203945 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4285229931 4278190081 4278190081 4278190081 4278190081 4279374354 4288914339 0 0 0 0 4291805890 4294514455 4294901760 4294901760 4294901760 4294643728 4291999157 0 0 0 0 0 4293322341 4294967040 4294967040 4294967040 4294177584 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4286348412 4278190081 4278190081 4278190081 4278190081 4280098077 4289835441 0 0 0 0 0 4293483098 4294901760 4294901760 4294901760 4294902017 4292514964 0 0 0 0 0 4291611851 4294440735 4294967040 4294967040 4294967040 4292861824 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4288387995 4278387459 4278190081 4278190081 4278190081 4280361249 4290361785 0 0 0 0 0 4292128173 4294836738 4294901760 4294901760 4294901760 4293418590 0 0 0 0 0 0 4292138155 4294967040 4294967040 4294967040 4294835464 4291743426 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290822336 4279637526 4278190081 4278190081 4278190081 4280163870 4290427578 0 0 0 0 0 0 4293741130 4294901760 4294901760 4294901760 4294385953 4291675846 0 0 0 0 0 0 4293124977 4294967040 4294967040 4294967040 4293848646 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4284111450 4278190081 4278190081 4278190081 4279242768 4289901234 0 0 0 0 0 0 4291934649 4294836995 4294901760 4294901760 4294901760 4292450456 0 0 0 0 0 0 0 4293914431 4294967040 4294967040 4294967040 4292796036 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4290427578 4278584838 4278190081 4278190081 4278190081 4287730065 0 0 0 0 0 0 0 4293031028 4294901760 4294901760 4294901760 4294063413 0 0 0 0 0 0 0 0 4294638102 4294967040 4294967040 4294967040 4291940793 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4285953654 4278190081 4278190081 4278190081 4282269246 0 0 0 0 0 0 0 0 4293933883 4294901760 4294901760 4294901760 4292708745 0 0 0 0 0 0 0 4291809218 4294967040 4294967040 4294967040 4294572311 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4282729797 4278190081 4278190081 4278190081 4287795858 0 0 0 0 0 0 0 0 4294579734 4294901760 4294901760 4294902017 4291805890 0 0 0 0 0 0 0 4292138157 4294967040 4294967040 4294967040 4294111797 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4281348144 4278190081 4278190081 4278190081 4290295992 0 0 0 0 0 0 0 0 4294836995 4294901760 4294901760 4294579734 0 0 0 0 0 0 0 0 4292335522 4294967040 4294967040 4294967040 4293848645 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 4278190081 0 0 0 0 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 4294901760 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4294901760 4294901760 0 0 0 0 0 0 0 0 0 4292335519 4294967040 4294967040 4294967040 4293782857 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!ServoMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 9/8/2009 13:52'!
isDigital
^true! !

!ServoMorph class methodsFor: 'connectors' stamp: 'Richo 9/1/2009 15:55'!
newConnector
^ (ArduinoWireMorph new) beOrthogonal: false;
				 beSmoothCurve: true;
				 lineColor: Color yellow;
				 lineWidth: 5;
				 borderWidth: 1;
				 borderColor: Color gray; yourself! !

!ServoMorph class methodsFor: 'connectors' stamp: 'Richo 9/1/2009 15:55'!
newConnectorFromMorph: m1 toMorph: m2
^ (ArduinoWireMorph fromMorph: m1 toMorph: m2) beOrthogonal: false;
				 beSmoothCurve: true;
				 lineColor: Color yellow;
				 lineWidth: 5;
				 borderWidth: 1;
				 borderColor: Color gray; yourself! !

!ServoMorph methodsFor: 'accessing' stamp: 'Richo 9/8/2009 13:11'!
angle
^device angle! !

!ServoMorph methodsFor: 'accessing' stamp: 'Richo 9/8/2009 13:11'!
angle: degrees
[device angle: degrees] on: Error do: []! !

!ServoMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:02'!
attachmentPointBorderColor
	^ Color gray! !

!ServoMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:02'!
attachmentPointCenter
	^ self center + (69 @ 78)! !

!ServoMorph methodsFor: 'attachment point' stamp: 'Richo 9/15/2009 13:02'!
attachmentPointColor
	^ Color yellow! !
ArduinoMorph initialize!
